
# line 2 "pars.yacc"

/* $Id: pars.yacc,v 1.3 1994/07/23 03:33:48 pturner Exp pturner $
 * 
 * evaluate expressions, commands, parameter files
 * 
 */

#define PARS			/* to overide some defines in defines.h */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <ctype.h>
#include <sys/param.h>

#include "globals.h"

#ifndef M_PI
#     define M_PI  3.14159265358979323846
#endif

#ifndef TRUE
#     define TRUE 1
#endif

#ifndef FALSE
#     define FALSE 0
#endif

double result, resx, resy;	/* return value if expression */
double nonl_parms[10];

double drand48(void);
long lrand48(void);
double erf(double arg); /* doesn't seem to be in ANSI C */
double erfc(double arg); /* doesn't seem to be in ANSI C */
double rnorm(double mean, double sdev);
double fx(double x);
double normp(double b, double *s);
double invnorm(double p);
double invt(double p, int n);
double *getvptr(int gno, int setno, int v);
double vmin(double *x, int n);
double vmax(double *x, int n);
void yyerror(char *s);

static int interr;

static double *freelist[100]; 	/* temporary vectors */
static int fcnt;		/* number allocated */

int naxis = 0;	/* current axis */
int curline, curbox, curstring, curleg, curgrid;

int gotbatch, gotparams, gotread; /* these guys attempt to avoid reentrancy problems */
int readtype, readsrc;
char batchfile[256], paramfile[256], readfile[256];

static char f_string[512];	/* buffer for string to parse */
static int pos = 0;
static double *aa, *bb, *cc, *dd, *xx, *yy;
static int setindex, lxy, ls;
static int setsetno;
static int whichgraph;
static int whichset;

extern int change_gno;
extern int change_type;


# line 73 "pars.yacc"
typedef union  {
    double val;
    long ival;
    double *ptr;
    long func;
    long pset;
    char *str;
} YYSTYPE;
# define ABS 257
# define ACOS 258
# define ASIN 259
# define ATAN 260
# define ATAN2 261
# define CEIL 262
# define COS 263
# define DEG 264
# define DX 265
# define DY 266
# define ERF 267
# define ERFC 268
# define EXP 269
# define FLOOR 270
# define HYPOT 271
# define INDEX 272
# define INT 273
# define INVN 274
# define INVT 275
# define IRAND 276
# define LGAMMA 277
# define LN 278
# define LOG 279
# define LOGISTIC 280
# define MAXP 281
# define MINP 282
# define MOD 283
# define NORM 284
# define NORMP 285
# define PI 286
# define RAD 287
# define RAND 288
# define RNORM 289
# define SETNO 290
# define SIN 291
# define SQR 292
# define SQRT 293
# define TAN 294
# define INUM 295
# define VX1 296
# define VX2 297
# define VY1 298
# define VY2 299
# define WX1 300
# define WX2 301
# define WY1 302
# define WY2 303
# define DELAYP 304
# define DOUBLEBUFFER 305
# define DOWN 306
# define ABSOLUTE 307
# define ABORT 308
# define ACTIVATE 309
# define ACTIVE 310
# define ALT 311
# define ALTERNATE 312
# define ALTXAXIS 313
# define ALTYAXIS 314
# define ANGLE 315
# define ANNOTATE 316
# define APPEND 317
# define AREA 318
# define ARROW 319
# define AUTO 320
# define AUTOSCALE 321
# define AUTOTICKS 322
# define AVG 323
# define AXIS 324
# define AXES 325
# define BACKBUFFER 326
# define BACKGROUND 327
# define BAR 328
# define BATCH 329
# define BLOCK 330
# define BIN 331
# define BOTH 332
# define BOTTOM 333
# define BOX 334
# define BOXPLOT 335
# define CD 336
# define CELLS 337
# define CENTER 338
# define CHAR 339
# define CHRSTR 340
# define CLEAR 341
# define CLICK 342
# define CMAP 343
# define COLOR 344
# define COMMENT 345
# define COPY 346
# define CYCLE 347
# define DECIMAL 348
# define DEF 349
# define DEFAULT 350
# define DELETE 351
# define DEVICE 352
# define DFT 353
# define DIFFERENCE 354
# define DISK 355
# define DRAW2 356
# define DROP 357
# define DXDX 358
# define DXP 359
# define DYDY 360
# define DYP 361
# define ECHO 362
# define EDIT 363
# define ELSE 364
# define END 365
# define ERRORBAR 366
# define EXIT 367
# define EXPONENTIAL 368
# define FALSEP 369
# define FFT 370
# define FILEP 371
# define FILL 372
# define FIND 373
# define FIXEDPOINT 374
# define FLUSH 375
# define FOCUS 376
# define FOLLOWS 377
# define FONTP 378
# define FOREGROUND 379
# define FORMAT 380
# define FRONTBUFFER 381
# define FRAMEP 382
# define GETP 383
# define GRAPH 384
# define GRAPHNO 385
# define GRAPHS 386
# define GRAPHTYPE 387
# define GRID 388
# define HARDCOPY 389
# define HBAR 390
# define HBOXPLOT 391
# define HGAP 392
# define HIDDEN 393
# define HORIZONTAL 394
# define HPGLL 395
# define HPGLP 396
# define HISTO 397
# define IF 398
# define IGNORE 399
# define IHL 400
# define IMAGE 401
# define IN 402
# define INIT 403
# define INITGRAPHICS 404
# define INOUT 405
# define INTEGRATE 406
# define INTERP 407
# define INVDFT 408
# define INVFFT 409
# define JUST 410
# define KILL 411
# define LABEL 412
# define LAYOUT 413
# define LEAVE 414
# define LEAVEGRAPHICS 415
# define LEFT 416
# define LEGEND 417
# define LENGTH 418
# define LEVEL 419
# define LEVELS 420
# define LINE 421
# define LINESTYLE 422
# define LINETO 423
# define LINEWIDTH 424
# define LINK 425
# define LOAD 426
# define LOCATOR 427
# define LOCTYPE 428
# define LOGX 429
# define LOGY 430
# define LOGXY 431
# define MAJOR 432
# define MIFL 433
# define MIFP 434
# define MINOR 435
# define MISSINGP 436
# define MOVE 437
# define MOVE2 438
# define MOVETO 439
# define NEGATE 440
# define NO 441
# define NONE 442
# define NORMAL 443
# define NXY 444
# define OFF 445
# define OFFSETX 446
# define OFFSETY 447
# define ON 448
# define OP 449
# define ORIENT 450
# define OUT 451
# define PAGE 452
# define PARA 453
# define PARALLEL 454
# define PARAMETERS 455
# define PARAMS 456
# define PATTERN 457
# define PERIMETER 458
# define PERP 459
# define PERPENDICULAR 460
# define PIE 461
# define PIPE 462
# define PLACE 463
# define POINT 464
# define POLAR 465
# define POWER 466
# define PREC 467
# define PREPEND 468
# define PRINT 469
# define PS 470
# define PSCOLORP 471
# define PSMONOP 472
# define PSCOLORL 473
# define PSMONOL 474
# define PUSH 475
# define POP 476
# define PUTP 477
# define RAWSPICE 478
# define READ 479
# define REDRAW 480
# define REGRESS 481
# define REGNUM 482
# define REGIONS 483
# define RENDER 484
# define REVERSE 485
# define RIGHT 486
# define RISER 487
# define ROT 488
# define RUNAVG 489
# define RUNMED 490
# define RUNSTD 491
# define RUNMIN 492
# define RUNMAX 493
# define SAMPLE 494
# define SAVEALL 495
# define SCALE 496
# define SCIENTIFIC 497
# define SET 498
# define SETNUM 499
# define SETS 500
# define SIGN 501
# define SIZE 502
# define SKIP 503
# define SLEEP 504
# define SLICE 505
# define SOURCE 506
# define SPEC 507
# define SPECIFIED 508
# define SPECTRUM 509
# define STACK 510
# define STACKEDBAR 511
# define STACKEDHBAR 512
# define STACKEDLINE 513
# define STAGGER 514
# define START 515
# define STARTTYPE 516
# define STATUS 517
# define STOP 518
# define STRING 519
# define SUBTITLE 520
# define SWAPBUFFER 521
# define SYMBOL 522
# define TICKP 523
# define TICKLABEL 524
# define TICKMARKS 525
# define TITLE 526
# define TO 527
# define TOP 528
# define TRUEP 529
# define TYPE 530
# define UP 531
# define VELOCITY 532
# define VERTICAL 533
# define VGAP 534
# define VIEW 535
# define WITH 536
# define WORLD 537
# define WRITE 538
# define X 539
# define X0 540
# define X1 541
# define XAXES 542
# define XAXIS 543
# define XCOR 544
# define XMAX 545
# define XMIN 546
# define XY 547
# define XYARC 548
# define XYBOX 549
# define XYBOXPLOT 550
# define XYFIXED 551
# define XYHILO 552
# define XYRT 553
# define XYSEG 554
# define XYSTRING 555
# define XYDX 556
# define XYDY 557
# define XYDXDX 558
# define XYDYDY 559
# define XYDXDY 560
# define XYX2Y2 561
# define XYXX 562
# define XYYY 563
# define XYZ 564
# define XYZW 565
# define XYUV 566
# define Y 567
# define Y0 568
# define Y1 569
# define Y2 570
# define Y3 571
# define Y4 572
# define Y5 573
# define YAXES 574
# define YAXIS 575
# define YES 576
# define YMAX 577
# define YMIN 578
# define ZEROXAXIS 579
# define ZEROYAXIS 580
# define ABOVE 581
# define BELOW 582
# define POLYI 583
# define POLYO 584
# define GENERAL 585
# define DDMMYY 586
# define MMDDYY 587
# define MMYY 588
# define MMDD 589
# define MONTHDAY 590
# define DAYMONTH 591
# define MONTHS 592
# define MONTHL 593
# define DAYOFWEEKS 594
# define DAYOFWEEKL 595
# define DAYOFYEAR 596
# define HMS 597
# define MMDDHMS 598
# define MMDDYYHMS 599
# define DEGREESLON 600
# define DEGREESMMLON 601
# define DEGREESMMSSLON 602
# define MMSSLON 603
# define DEGREESLAT 604
# define DEGREESMMLAT 605
# define DEGREESMMSSLAT 606
# define MMSSLAT 607
# define DOT 608
# define STAR 609
# define PLUS 610
# define CROSS 611
# define CIRCLE 612
# define SQUARE 613
# define DIAMOND 614
# define TRIANGLE1 615
# define TRIANGLE2 616
# define TRIANGLE3 617
# define TRIANGLE4 618
# define SPLINE 619
# define LANDSCAPE 620
# define PORTRAIT 621
# define FREE 622
# define FIXED 623
# define STATUSBAR 624
# define LOCATORBAR 625
# define TOOLBAR 626
# define VAR 627
# define NUMBER 628
# define FITPARM 629
# define OR 630
# define AND 631
# define GT 632
# define LT 633
# define LE 634
# define GE 635
# define EQ 636
# define NE 637
# define UMINUS 638
# define NOT 639
#define yyclearin yychar = -1
#define yyerrok yyerrflag = 0
extern int yychar;
extern int yyerrflag;
#ifndef YYMAXDEPTH
#define YYMAXDEPTH 150
#endif
YYSTYPE yylval, yyval;
typedef int yytabelem;
# define YYERRCODE 256

# line 3700 "pars.yacc"


void fixupstr(char *val)
{
    int vl = strlen(val);
    lowtoupper(val);
    val[vl + 1] = 0;
    val[vl] = '\n';
}

void scanner(char *s, double *x, double *y, int len, double *a, double *b, double *c, double *d, int lenscr, int i, int setno, int *errpos)
{
    interr = 0;
    whichgraph = cg;
    whichset = setno;
    if (s[0] == '#') {
	return;
    }
    pos = 0;
    aa = a;
    bb = b;
    cc = c;
    dd = d;
    xx = x;
    yy = y;
    lxy = len;
    ls = lenscr;
    setindex = i + 1;
    curset = setsetno = setno;
    strcpy(f_string, s);
    fcnt = 0;
    yyparse();
    *errpos = interr;
    for (i = 0; i < fcnt; i++) {
	cfree(freelist[i]);
	freelist[i] = NULL;
    }
}

void runbatch(char *bfile)
{
    double x, y, a, b, c, d;
    int i, setno, errpos, lcnt = 1;
    char stext[256];
    FILE *fp;
    if (strcmp("stdin", bfile)) {
	fp = fopen(bfile, "r");
    }
    else {
	fp = stdin;
    }
    if (fp == NULL) {
        fprintf(stderr, "Error opening batch file \"%s\"\n", bfile);
        exit(1);
    }
    while(fgets(stext, 255, fp) != NULL) {
        if (stext[0] == '#') {
            continue;
        }
	if (strlen(stext) == 0) {
	    continue;
	}
        lowtoupper(stext);
/* TODO check on 0, 0 here for index and setno */
        scanner(stext, &x, &y, 1, ax, bx, cx, dx, 1, 0, 0, &errpos);
        stext[0] = 0;
        if (gotparams && paramfile[0]) {
            if (!getparms(cg, paramfile)) {
            }
            gotparams = 0;
        } else if (gotread && readfile[0]) {
            if (getdata(cg, readfile, readsrc, readtype)) {
                drawgraph();
            }
            gotread = 0;
        }
    }
    if (fp != stdin) {
	fclose(fp);
    }
}

#define MAXFUN 383

int maxparms = MAXFUN;
int maxfunc = MAXFUN;

symtab_entry key[] = {
	"A", VAR,
	"A0", FITPARM,
	"A1", FITPARM,
	"A2", FITPARM,
	"A3", FITPARM,
	"A4", FITPARM,
	"A5", FITPARM,
	"A6", FITPARM,
	"A7", FITPARM,
	"A8", FITPARM,
	"A9", FITPARM,
	"ABORT", ABORT,
	"ABOVE", ABOVE,
	"ABS", ABS,
	"ABSOLUTE", ABSOLUTE,
	"ACOS", ACOS,
	"ACTIVATE", ACTIVATE,
	"ACTIVE", ACTIVE,
	"ALT", ALT,
	"ALTERNATE", ALTERNATE,
	"ALTXAXIS", ALTXAXIS,
	"ALTYAXIS", ALTYAXIS,
	"AND", AND,
	"ANGLE", ANGLE,
	"ANNOTATE", ANNOTATE,
	"APPEND", APPEND,
	"AREA", AREA,
	"ARROW", ARROW,
	"ASIN", ASIN,
	"ATAN", ATAN,
	"ATAN2", ATAN2,
	"AUTO", AUTO,
	"AUTOSCALE", AUTOSCALE,
	"AUTOTICKS", AUTOTICKS,
	"AVG", AVG,
	"AXES", AXES,
	"AXIS", AXIS,
	"B", VAR,
	"BACKBUFFER", BACKBUFFER,
	"BACKGROUND", BACKGROUND,
	"BAR", BAR,
	"BATCH", BATCH,
	"BELOW", BELOW,
	"BIN", BIN,
	"BLOCK", BLOCK,
	"BOTH", BOTH,
	"BOTTOM", BOTTOM,
	"BOX", BOX,
	"BOXPLOT", BOXPLOT,
	"C", VAR,
	"CD", CD,
	"CEIL", CEIL,
	"CELLS", CELLS,
	"CENTER", CENTER,
	"CHAR", CHAR,
	"CHRSTR", CHRSTR,
	"CLEAR", CLEAR,
	"CLICK", CLICK,
	"CMAP", CMAP,
	"CO", COLOR,
	"COLOR", COLOR,
	"COMMENT", COMMENT,
	"COPY", COPY,
	"COS", COS,
	"CYCLE", CYCLE,
	"D", VAR,
	"DAYMONTH", DAYMONTH,
	"DAYOFWEEKL", DAYOFWEEKL,
	"DAYOFWEEKS", DAYOFWEEKS,
	"DAYOFYEAR", DAYOFYEAR,
	"DDMMYY", DDMMYY,
	"DECIMAL", DECIMAL,
	"DEF", DEF,
	"DEFAULT", DEFAULT,
	"DEG", DEG,
	"DEGREESLAT", DEGREESLAT,
	"DEGREESLON", DEGREESLON,
	"DEGREESMMLAT", DEGREESMMLAT,
	"DEGREESMMLON", DEGREESMMLON,
	"DEGREESMMSSLAT", DEGREESMMSSLAT,
	"DEGREESMMSSLON", DEGREESMMSSLON,
	"DELAY", DELAYP,
	"DELETE", DELETE,
	"DEVICE", DEVICE,
	"DFT", DFT,
	"DIFF", DIFFERENCE,
	"DIFFERENCE", DIFFERENCE,
	"DISK", DISK,
	"DOUBLEBUFFER", DOUBLEBUFFER,
	"DOWN", DOWN,
	"DRAW2", DRAW2,
	"DROP", DROP,
	"DX", DX,
	"DXDX", DXDX,
	"DY", DY,
	"DYDY", DYDY,
	"ECHO", ECHO,
	"EDIT", EDIT,
	"ELSE", ELSE,
	"END", END,
	"EQ", EQ,
	"ER", ERRORBAR,
	"ERF", ERF,
	"ERFC", ERFC,
	"ERRORBAR", ERRORBAR,
	"EXIT", EXIT,
	"EXP", EXP,
	"EXPONENTIAL", EXPONENTIAL,
	"FALSE", FALSEP,
	"FFT", FFT,
	"FILE", FILEP,
	"FILL", FILL,
	"FIND", FIND,
	"FIXED", FIXED,
	"FIXEDPOINT", FIXEDPOINT,
	"FLOOR", FLOOR,
	"FLUSH", FLUSH,
	"FOCUS", FOCUS,
	"FOLLOWS", FOLLOWS,
	"FONT", FONTP,
	"FOREGROUND", FOREGROUND,
	"FORMAT", FORMAT,
	"FRAME", FRAMEP,
	"FREE", FREE,
	"FRONTBUFFER", FRONTBUFFER,
	"GE", GE,
	"GENERAL", GENERAL,
	"GETP", GETP,
	"GRAPH", GRAPH,
	"GRAPHS", GRAPHS,
	"GRAPHTYPE", GRAPHTYPE,
	"GRID", GRID,
	"GT", GT,
	"HARDCOPY", HARDCOPY,
	"HBAR", HBAR,
	"HBOXPLOT", HBOXPLOT,
	"HGAP", HGAP,
	"HIDDEN", HIDDEN,
	"HISTO", HISTO,
	"HMS", HMS,
	"HORIZONTAL", HORIZONTAL,
	"HPGLL", HPGLL,
	"HPGLP", HPGLP,
	"HYPOT", HYPOT,
	"IF", IF,
	"IGNORE", IGNORE,
	"IHL", IHL,
	"IMAGE", IMAGE,
	"IN", IN,
	"INDEX", INDEX,
	"INIT", INIT,
	"INITGRAPHICS", INITGRAPHICS,
	"INOUT", INOUT,
	"INT", INT,
	"INTEGRATE", INT,
	"INTERP", INTERP,
	"INUM", INUM,
	"INVDFT", INVDFT,
	"INVFFT", INVFFT,
	"INVN", INVN,
	"INVT", INVT,
	"IRAND", IRAND,
	"JUST", JUST,
	"KILL", KILL,
	"LABEL", LABEL,
	"LANDSCAPE", LANDSCAPE,
	"LAYOUT", LAYOUT,
	"LE", LE,
	"LEAVE", LEAVE,
	"LEAVEGRAPHICS", LEAVEGRAPHICS,
	"LEFT", LEFT,
	"LEGEND", LEGEND,
	"LENGTH", LENGTH,
	"LEVEL", LEVEL,
	"LEVELS", LEVELS,
	"LGAMMA", LGAMMA,
	"LINE", LINE,
	"LINESTYLE", LINESTYLE,
	"LINETO", LINETO,
	"LINEWIDTH", LINEWIDTH,
	"LINK", LINK,
	"LN", LN,
	"LOAD", LOAD,
	"LOCATOR", LOCATOR,
	"LOCATORBAR", LOCATORBAR,
	"LOCTYPE", LOCTYPE,
	"LOG", LOG,
	"LOGISTIC", LOGISTIC,
	"LOGX", LOGX,
	"LOGXY", LOGXY,
	"LOGY", LOGY,
	"LS", LINESTYLE,
	"LT", LT,
	"LW", LINEWIDTH,
	"MAJOR", MAJOR,
	"MAX", MAXP,
	"MIFL", MIFL,
	"MIFP", MIFP,
	"MIN", MINP,
	"MINOR", MINOR,
	"MISSING", MISSINGP,
	"MMDD", MMDD,
	"MMDDHMS", MMDDHMS,
	"MMDDYY", MMDDYY,
	"MMDDYYHMS", MMDDYYHMS,
	"MMSSLAT", MMSSLAT,
	"MMSSLON", MMSSLON,
	"MMYY", MMYY,
	"MOD", MOD,
	"MONTHDAY", MONTHDAY,
	"MONTHL", MONTHL,
	"MONTHS", MONTHS,
	"MOVE", MOVE,
	"MOVE2", MOVE2,
	"MOVETO", MOVETO,
	"NE", NE,
	"NEGATE", NEGATE,
	"NO", NO,
	"NONE", NONE,
	"NORM", NORM,
	"NORMAL", NORMAL,
	"NORMP", NORMP,
	"NOT", NOT,
	"NUMBER", NUMBER,
	"NXY", NXY,
	"OFF", OFF,
	"OFFSETX", OFFSETX,
	"OFFSETY", OFFSETY,
	"ON", ON,
	"OP", OP,
	"OR", OR,
	"ORIENT", ORIENT,
	"OUT", OUT,
	"PAGE", PAGE,
	"PARA", PARA,
	"PARALLEL", PARALLEL,
	"PARAMETERS", PARAMETERS,
	"PARAMS", PARAMS,
	"PATTERN", PATTERN,
	"PERIMETER", PERIMETER,
	"PERP", PERP,
	"PERPENDICULAR", PERPENDICULAR,
	"PI", PI,
	"PIE", PIE,
	"PIPE", PIPE,
	"PLACE", PLACE,
	"POINT", POINT,
	"POLAR", POLAR,
	"POLYI", POLYI,
	"POLYO", POLYO,
	"POP", POP,
	"PORTRAIT", PORTRAIT,
	"POWER", POWER,
	"PREC", PREC,
	"PREPEND", PREPEND,
	"PRINT", PRINT,
	"PS", PS,
	"PSCOLORL", PSCOLORL,
	"PSCOLORP", PSCOLORP,
	"PSMONOL", PSMONOL,
	"PSMONOP", PSMONOP,
	"PUSH", PUSH,
	"PUTP", PUTP,
	"RAD", RAD,
	"RAND", RAND,
	"RAWSPICE", RAWSPICE,
	"READ", READ,
	"REDRAW", REDRAW,
	"REGRESS", REGRESS,
	"RENDER", RENDER,
	"REVERSE", REVERSE,
	"RIGHT", RIGHT,
	"RISER", RISER,
	"RNORM", RNORM,
	"ROT", ROT,
	"RUNAVG", RUNAVG,
	"RUNMAX", RUNMAX,
	"RUNMED", RUNMED,
	"RUNMIN", RUNMIN,
	"RUNSTD", RUNSTD,
	"SAMPLE", SAMPLE,
	"SAVEALL", SAVEALL,
	"SCALE", SCALE,
	"SCIENTIFIC", SCIENTIFIC,
	"SET", SET,
	"SETNO", SETNO,
	"SETS", SETS,
	"SIGN", SIGN,
	"SIN", SIN,
	"SIZE", SIZE,
	"SKIP", SKIP,
	"SLEEP", SLEEP,
	"SLICE", SLICE,
	"SOURCE", SOURCE,
	"SPEC", SPEC,
	"SPECIFIED", SPECIFIED,
	"SPECTRUM", SPECTRUM,
	"SPLINE", SPLINE,
	"SQR", SQR,
	"SQRT", SQRT,
	"STACK", STACK,
	"STACKEDBAR", STACKEDBAR,
	"STACKEDHBAR", STACKEDHBAR,
	"STACKEDLINE", STACKEDLINE,
	"STAGGER", STAGGER,
	"START", START,
	"STARTTYPE", STARTTYPE,
	"STATUS", STATUS,
	"STATUSBAR", STATUSBAR,
	"STOP", STOP,
	"STRING", STRING,
	"SUBTITLE", SUBTITLE,
	"SWAPBUFFER", SWAPBUFFER,
	"SYMBOL", SYMBOL,
	"TAN", TAN,
	"TICK", TICKP,
	"TICKLABEL", TICKLABEL,
	"TICKMARKS", TICKMARKS,
	"TITLE", TITLE,
	"TO", TO,
	"TOOLBAR", TOOLBAR,
	"TOP", TOP,
	"TRUE", TRUEP,
	"TYPE", TYPE,
	"UP", UP,
	"VAR", VAR,
	"VELOCITY", VELOCITY,
	"VERTICAL", VERTICAL,
	"VGAP", VGAP,
	"VIEW", VIEW,
	"VX1", VX1,
	"VX2", VX2,
	"VY1", VY1,
	"VY2", VY2,
	"WITH", WITH,
	"WORLD", WORLD,
	"WRITE", WRITE,
	"WX1", WX1,
	"WX2", WX2,
	"WY1", WY1,
	"WY2", WY2,
	"X", X,
	"X0", X0,
	"X1", X1,
	"XAXES", XAXES,
	"XAXIS", XAXIS,
	"XCOR", XCOR,
	"XMAX", XMAX,
	"XMIN", XMIN,
	"XY", XY,
	"XYARC", XYARC,
	"XYBOX", XYBOX,
	"XYBOXPLOT", XYBOXPLOT,
	"XYDX", XYDX,
	"XYDXDX", XYDXDX,
	"XYDXDY", XYDXDY,
	"XYDY", XYDY,
	"XYDYDY", XYDYDY,
	"XYFIXED", XYFIXED,
	"XYHILO", XYHILO,
	"XYRT", XYRT,
	"XYSEG", XYSEG,
	"XYSTRING", XYSTRING,
	"XYUV", XYUV,
	"XYX2Y2", XYX2Y2,
	"XYXX", XYXX,
	"XYYY", XYYY,
	"XYZ", XYZ,
	"XYZW", XYZW,
	"Y", Y,
	"Y0", Y0,
	"Y1", Y1,
	"Y2", Y2,
	"Y3", Y3,
	"Y4", Y4,
	"Y5", Y5,
	"YAXES", YAXES,
	"YAXIS", YAXIS,
	"YES", YES,
	"YMAX", YMAX,
	"YMIN", YMIN,
	"ZEROXAXIS", ZEROXAXIS,
	"ZEROYAXIS", ZEROYAXIS,
};

int findf(symtab_entry *key, char *s, int tlen)
{

    int low, high, mid;

    low = 0;
    high = tlen - 1;
    while (low <= high) {
	mid = (low + high) / 2;
	if (strcmp(s, key[mid].s) < 0) {
	    high = mid - 1;
	} else {
	    if (strcmp(s, key[mid].s) > 0) {
		low = mid + 1;
	    } else {
		return (mid);
	    }
	}
    }
    return (-1);
}

int getcharstr(void)
{
    if (pos >= strlen(f_string))
	 return EOF;
    return (f_string[pos++]);
}

void ungetchstr(void)
{
    if (pos > 0)
	pos--;
}

int yylex(void)
{
    int c, i;
    int found;
    static char s[256];
    char sbuf[256];
    char *str;

    while ((c = getcharstr()) == ' ' || c == '\t');
    if (c == EOF) {
	return (0);
    }
    if (c == '"') {
	i = 0;
	while ((c = getcharstr()) != '"' && c != EOF) {
	    if (c == '\\') {
		int ctmp;
		ctmp = getcharstr();
		if (ctmp != '"') {
		    ungetchstr();
		}
		else {
		    c = ctmp;
		}
	    }
	    s[i] = c;
	    i++;
	}
	if (c == EOF) {
	    sprintf(sbuf, "Nonterminating string\n");
	    yyerror(sbuf);
	    return 0;
	}
	s[i] = '\0';
	str = (char *) malloc(strlen(s) + 1);
	strcpy(str, s);
	yylval.str = str;
	return CHRSTR;
    }
    if (c == '.' || isdigit(c)) {
	char stmp[80];
	double d;
	int i, gotdot = 0;

	i = 0;
	while (c == '.' || isdigit(c)) {
	    if (c == '.') {
		if (gotdot) {
		    yyerror("Reading number, too many dots");
	    	    return 0;
		} else {
		    gotdot = 1;
		}
	    }
	    stmp[i++] = c;
	    c = getcharstr();
	}
	if (c == 'E' || c == 'e') {
	    stmp[i++] = c;
	    c = getcharstr();
	    if (c == '+' || c == '-') {
		stmp[i++] = c;
		c = getcharstr();
	    }
	    while (isdigit(c)) {
		stmp[i++] = c;
		c = getcharstr();
	    }
	}
	if (gotdot && i == 1) {
	    ungetchstr();
	    return '.';
	}
	stmp[i] = '\0';
	ungetchstr();
	sscanf(stmp, "%lf", &d);
	yylval.val = d;
	return NUMBER;
    }
/* graphs, sets, regions resp. */
    if (c == 'G' || c == 'S' || c == 'R') {
	char stmp[80];
	double d;
	int i = 0, ctmp = c, gn, sn, rn;
	c = getcharstr();
	while (isdigit(c)) {
	    stmp[i++] = c;
	    c = getcharstr();
	}
	if (i == 0) {
	    c = ctmp;
	    ungetchstr();
	} else {
	    ungetchstr();
	    if (ctmp == 'G') {
	        stmp[i] = '\0';
		gn = atoi(stmp);
		if (gn >= 0 && gn < maxgraph) {
		    yylval.ival = gn;
		    whichgraph = gn;
		    return GRAPHNO;
		}
	    } else if (ctmp == 'S') {
	        stmp[i] = '\0';
		sn = atoi(stmp);
		if (sn >= 0 && sn < g[cg].maxplot) {
		    lxy = getsetlength(cg, sn);
		    yylval.ival = sn;
		    whichset = sn;
		    return SETNUM;
		}
	    } else if (ctmp == 'R') {
	        stmp[i] = '\0';
		rn = atoi(stmp);
		if (rn >= 0 && rn < MAXREGION) {
		    yylval.ival = rn;
		    return REGNUM;
		}
	    }
	}
    }
    if (isalpha(c)) {
	char *p = sbuf;
	int gno = -1, setno = -1, xy = -1, elno = -1;

	do {
	    *p++ = c;
	} while ((c = getcharstr()) != EOF && isalnum(c));
	ungetchstr();
	*p = '\0';
        if (debuglevel == 2) {
	    printf("->%s<-\n", sbuf);
	}
	if ((found = findf(key, sbuf, MAXFUN)) >= 0) {
	    if (key[found].type == VAR) {
		switch (sbuf[0]) {
		case 'A':
		    yylval.ptr = aa;
		    return VAR;
		case 'B':
		    yylval.ptr = bb;
		    return VAR;
		case 'C':
		    yylval.ptr = cc;
		    return VAR;
		case 'D':
		    yylval.ptr = dd;
		    return VAR;
		}
	    }
	    else if (key[found].type == FITPARM) {
		int index = sbuf[1] - '0';
		yylval.val = nonl_parms[index];
		return FITPARM;
	    }
	    else { /* set up special cases */
		switch (key[found].type) {
		case XAXIS:
		    naxis = 0;
		    break;
		case YAXIS:
		    naxis = 1;
		    break;
		case ZEROXAXIS:
		    naxis = 2;
		    break;
		case ZEROYAXIS:
		    naxis = 3;
		    break;
		case ALTXAXIS:
		    naxis = 4;
		    break;
		case ALTYAXIS:
		    naxis = 5;
		    break;
		case AXES:
		    naxis = 6;
		    break;
		case XAXES:
		    naxis = 7;
		    break;
		case YAXES:
		    naxis = 8;
		    break;
		case GRAPHS:
		    yylval.ival = -1;
		    whichgraph = -1;
		    return GRAPHS;
		    break;
		case SETS:
		    yylval.ival = -1;
		    whichset = -1;
		    return SETS;
		    break;
		default:
		    break;
		}
	    }
	    yylval.func = key[found].type;
	    return key[found].type;
	} else {
	    strcat(sbuf, ": No such function or variable");
	    yyerror(sbuf);
	    return 0;
	}
    }
    switch (c) {
    case '>':
	return follow('=', GE, GT);
    case '<':
	return follow('=', LE, LT);
    case '=':
	return follow('=', EQ, '=');
    case '!':
	return follow('=', NE, NOT);
    case '|':
	return follow('|', OR, '|');
    case '&':
	return follow('&', AND, '&');
    case '\n':
	return '\n';
    default:
	return c;
    }
}

int follow(int expect, int ifyes, int ifno)
{
    int c = getcharstr();

    if (c == expect) {
	return ifyes;
    }
    ungetchstr();
    return ifno;
}

void yyerror(char *s)
{
    int i;
    char buf[256];
    sprintf(buf, "Error: %s: %s", s, f_string);
    i = strlen(buf);
    buf[i - 1] = 0;
    errwin(buf);
    interr = 1;
}

#define C1 0.1978977093962766
#define C2 0.1352915131768107

double rnorm(double mean, double sdev)
{
    double u = drand48();

    return mean + sdev * (pow(u, C2) - pow(1.0 - u, C2)) / C1;
}

double fx(double x)
{
    return 1.0 / sqrt(2.0 * M_PI) * exp(-x * x * 0.5);
}

double normp(double b, double *s)
{
    double sum, dx, a = -8.0, fx(double x);
    int i, n = 48;

    sum = fx(a) + fx(b);
    dx = (b - a) / n;
    for (i = 1; i <= ((n - 1) / 2); i++)
	sum = sum + 4.0 * fx(a + (2.0 * i - 1.0) * dx) + 2.0 * fx(a + 2.0 * i * dx);
    sum = sum + 4.0 * fx(b - dx);
    *s = fx(b);
    return sum * dx / 3.0;
}

double invnorm(double p)
{
    double s, x, z, temp, normp(double b, double *s);

    if (p > 0.5)
	x = 1.0 - p;
    else
	x = p;
    s = sqrt(-2.0 * log(x));
    x = ((-7.49101 * s - 448.047) * s - 1266.846);
    x = x / (((s + 109.8371) * s + 748.189) * s + 498.003) + s;
    if (p < 0.5)
	x = -x;
    z = p - normp(x, &s);
    z = z / s;
    s = x * x;
    return (((((((((720.0 * s + 2556.0) * s + 1740.0) * s + 127.0) * z / 7.0 +
		 ((120.0 * s + 326.0) * s + 127.0) * x) * z / 6.0 + (24 * s + 46.0) * s + 7.0) * z / 40.0 +
	       (0.75 * s + 0.875) * x) * z + s + 0.5) * z / 3.0 + x * 0.5) * z + 1.0) * z + x + 0.832e-24 * x;
}

double invt(double p, int n)
{
    double sign, temp, a, b, c, d, x, y;

    sign = 1.0;
    if (p < 0.5) {
	p = 1.0 - p;
	sign = -1.0;
    }
    p = (1 - p) * 2;
    if (n == 2) {
	temp = sqrt(2.0 / (p * (2.0 - p)) - 2.0);
	temp = sign * temp;
	return temp;
    } else if (n == 1) {
	p = p * M_PI / 2.0;
	return sign * cos(p) / sin(p);
    } else {
	a = 1.0 / (n - 0.5);
	b = 48.0 / (a * a);
	c = ((20700 * a / b - 98.0) * a - 16.0) * a + 96.36;
	d = ((94.5 / (b + c) - 3.0) / b + 1.0) * sqrt(a * M_PI / 2.0) * n;
	x = d * p;
	y = exp((2.0 / n) * log(x));
	if (y > (0.05 + a)) {
	    x = invnorm(p * 0.5);
	    y = x * x;
	    if (n < 5)
		c = c + 0.3 * (n - 4.5) * (x + 0.6);
	    c = (((0.05 * d * x - 5.0) * x - 7.0) * x - 2.0) * x + b + c;
	    y = (((((0.4 * y + 6.3) * y + 36.0) * y + 94.5) / c - y - 3.0) / b + 1.0) * x;
	    y = a * y * y;
	    if (y > 0.002)
		y = exp(y) - 1.0;
	    else
		y = 0.5 * y * y + y;
	} else
	    y = ((1.0 / (((n + 0.6) / (n * y) - 0.089 * d - 0.822) * (n + 2.0) * 3.0) + 0.5 / (n + 4.0)) * y - 1.0) * (n + 1.0) / (n + 2.0) + 1.0 / y;
	return sign * sqrt(n * y);
    }
}

/*
 * return a pointer to the array given by v
 */
double *getvptr(int gno, int setno, int v)
{
    switch (v) {
    case X:
    case X0:
	return g[gno].p[setno].ex[0];
	break;
    case Y:
    case Y0:
	return g[gno].p[setno].ex[1];
	break;
    case Y1:
	return g[gno].p[setno].ex[2];
	break;
    case Y2:
	return g[gno].p[setno].ex[3];
	break;
    case Y3:
	return g[gno].p[setno].ex[4];
	break;
    case Y4:
	return g[gno].p[setno].ex[5];
	break;
    case Y5:
	return g[gno].p[setno].ex[6];
	break;
    }
    return NULL;
}
yytabelem yyexca[] ={
-1, 1,
	0, -1,
	-2, 0,
-1, 28,
	37, 638,
	-2, 566,
-1, 44,
	37, 662,
	-2, 575,
-1, 45,
	37, 663,
	-2, 576,
-1, 59,
	37, 677,
	-2, 591,
-1, 60,
	37, 678,
	-2, 592,
-1, 61,
	37, 679,
	-2, 593,
-1, 271,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 694,
-1, 281,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 696,
-1, 572,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 538,
-1, 574,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 542,
-1, 576,
	37, 627,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 546,
-1, 578,
	37, 628,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 550,
-1, 580,
	37, 630,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 554,
-1, 584,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 686,
-1, 585,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 687,
-1, 586,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 688,
-1, 587,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 689,
-1, 588,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 690,
-1, 589,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 691,
-1, 593,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 541,
-1, 595,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 545,
-1, 597,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 549,
-1, 599,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 553,
-1, 600,
	10, 537,
	44, 537,
	41, 537,
	58, 537,
	-2, 556,
-1, 604,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 603,
-1, 605,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 604,
-1, 606,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 605,
-1, 607,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 606,
-1, 608,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 607,
-1, 609,
	632, 0,
	633, 0,
	634, 0,
	635, 0,
	636, 0,
	637, 0,
	-2, 608,
-1, 1056,
	37, 631,
	-2, 558,
-1, 1087,
	37, 667,
	-2, 581,
-1, 1423,
	37, 643,
	-2, 574,
-1, 1424,
	37, 666,
	-2, 579,
-1, 1437,
	37, 680,
	-2, 597,
	};
# define YYNPROD 697
# define YYLAST 8081
yytabelem yyact[]={

   603,     5,  1317,  1010,   971,  1230,   354,  1252,   924,   429,
   901,   194,   192,  1106,   193,   837,   195,   394,   853,  1011,
  1510,  1276,  1509,  1496,  1465,  1462,  1445,  1443,  1440,  1415,
  1404,  1403,   197,  1402,   972,  1399,  1392,  1391,  1390,  1389,
  1387,  1386,  1385,   838,  1384,  1383,  1376,  1375,  1372,  1371,
   181,  1370,  1340,  1339,   973,   750,   748,  1521,   749,  1325,
   751,  1313,  1307,   196,  1301,  1300,  1298,   181,   271,   279,
   281,  1297,   750,   748,  1519,   749,   182,   751,  1295,  1294,
   181,  1292,   300,   344,   345,   750,   748,  1517,   749,  1291,
   751,  1288,  1287,   182,  1286,  1285,  1284,   357,   358,  1283,
   428,  1282,   361,  1281,  1272,  1271,   182,   752,  1270,  1268,
  1267,  1257,   181,  1256,  1251,  1243,  1238,   750,   748,  1229,
   749,  1228,   751,  1227,   752,  1225,   436,   445,   454,  1204,
   469,   474,  1012,  1202,  1200,   501,  1199,   752,   182,  1198,
   852,   836,  1194,  1191,  1190,   181,  1189,  1188,  1186,  1185,
   750,   748,   974,   749,  1183,   751,  1182,  1145,   302,    15,
  1121,  1052,  1051,  1049,  1028,  1027,  1026,  1025,  1024,   752,
  1023,   182,  1013,  1007,   970,   965,   964,   572,   574,   576,
   578,   580,   582,   583,   584,   585,   586,   587,   588,   589,
   590,   591,   963,   593,   595,   597,   599,   600,   961,   181,
   897,  1508,   752,   896,   750,   748,  1501,   749,  1277,   751,
   895,  1009,   894,   893,   612,   614,   615,   617,   892,   620,
   891,   890,   889,   879,   878,   182,   273,   273,   273,   877,
   876,   636,   637,   872,   871,   618,   870,   869,   667,   668,
   868,   670,   673,   675,   677,   679,   681,   683,   685,   687,
   689,   691,   693,   696,   698,   699,   752,   703,   705,   707,
   709,   711,   713,   715,   717,   719,   721,   723,   725,   727,
   729,   975,   976,   977,   978,   979,   980,   981,   982,   983,
   984,   985,   986,   987,   988,   989,   990,   991,   992,   993,
   994,   995,   996,   997,   867,   866,   865,   864,   863,   862,
   861,   850,   849,  1008,   848,   845,   844,   843,   842,   841,
   835,   834,   833,   826,  1245,   825,   824,   818,   804,   799,
   181,   798,   797,   796,   746,   750,   748,  1500,   749,  1278,
   751,   739,   701,   666,   665,   273,   273,   273,   273,   273,
   664,   621,   785,   786,   787,   559,   182,   360,   359,   348,
   790,   273,   273,   273,   273,   273,   273,   273,   273,   273,
   273,   273,   273,   273,   273,   347,   346,   286,   378,   695,
     6,   387,   549,   273,   426,   273,   823,   752,   822,   622,
   743,   744,   742,   745,  1248,   967,   660,  1368,   397,  1367,
   802,   800,   794,  1280,  1398,  1269,  1396,   356,   669,   273,
   273,   273,   273,   273,   273,   273,   273,   273,   273,   273,
   273,   273,   273,   273,   385,   273,   273,   273,   273,   273,
   273,   273,   273,   273,   273,   273,   273,   273,   273,  1029,
   819,   888,   356,   854,   851,   144,   146,   270,   278,   280,
   813,   815,   846,  1014,   873,   656,   386,  1017,  1498,  1016,
  1497,  1169,   181,  1241,  1168,  1236,   661,   750,   748,  1499,
   749,  1167,   751,   145,   147,   148,   149,   150,   151,   152,
  1166,   856,   857,   858,   859,   181,  1011,   810,   182,  1494,
   750,   748,   821,   749,   809,   751,   808,   807,   181,   350,
   806,   652,   805,   750,   748,   369,   749,  1250,   751,   353,
   517,   182,   282,   886,   887,   423,   425,   561,   373,   752,
  1275,  1046,  1018,  1045,   182,  1449,  1274,   231,   220,  1448,
   230,  1165,   793,  1249,  1366,   560,   899,   285,  1479,   352,
  1447,   792,   752,  1409,   181,   969,  1400,   182,   998,   750,
   748,  1492,   749,  1019,   751,   752,   573,   575,   577,   579,
   581,   658,   659,   662,   663,  1015,   231,   355,   635,   230,
   182,  1306,   592,   594,   596,   598,   601,   602,   604,   605,
   606,   607,   608,   609,   610,   611,  1255,   231,   653,   814,
   230,  1397,   371,  1395,   613,   395,   616,   351,  1247,  1012,
   563,   752,   355,  1246,   395,  1203,  1178,  1177,  1515,   205,
   204,   198,   199,   200,   201,   202,   203,   349,   222,   232,
   671,   672,   674,   676,   678,   680,   682,   684,   686,   688,
   690,   692,   372,   697,   700,  1164,   702,   704,   706,   708,
   710,   712,   714,   716,   718,   720,   722,   724,   726,   728,
  1242,   655,  1237,   190,   189,   183,   184,   185,   186,   187,
   188,   466,   731,  1163,  1254,  1050,   465,  1048,   654,  1035,
   190,   189,   183,   184,   185,   186,   187,   188,  1196,   297,
   298,   299,  1021,   190,   189,   183,   184,   185,   186,   187,
   188,   194,   192,  1100,   193,  1020,   195,  1235,  1232,   181,
   467,   847,   396,  1493,   750,   748,   370,   749,  1047,   751,
   817,   396,   197,   388,   390,   190,   189,   183,   184,   185,
   186,   187,   188,   431,   812,   182,   434,   443,   452,   137,
  1011,   816,   811,   395,  1253,   494,   510,   522,   791,   395,
   531,  1116,  1117,   196,   463,   696,   464,   427,   190,   189,
   183,   184,   185,   186,   187,   188,   752,   828,  1122,  1123,
  1124,  1125,  1126,  1127,   363,   292,  1130,  1131,  1132,  1133,
  1134,  1135,  1136,  1137,  1138,  1139,  1140,  1141,  1142,  1143,
  1144,  1233,  1146,  1147,  1148,  1149,  1150,  1151,  1152,  1153,
  1154,  1155,  1156,  1157,  1158,  1159,   362,   376,   377,  1160,
  1161,   136,   190,   189,   183,   184,   185,   186,   187,   188,
   432,   181,   284,   283,   521,   730,   750,   748,   619,   749,
   197,   751,   562,   231,   634,  1506,   230,  1261,   651,  1320,
  1319,  1181,  1320,  1319,  1044,  1481,  1414,   182,   182,   219,
   396,  1463,  1184,  1012,   468,   624,   396,   239,   197,   366,
  1187,  1234,   181,   489,  1304,   830,  1303,   750,   748,  1489,
   749,   295,   751,   491,   290,  1311,  1192,  1491,   752,   752,
   829,  1193,   287,  1414,  1318,   294,  1480,   231,   182,   196,
   230,  1474,  1310,   738,  1055,   164,   165,   181,  1413,  1041,
  1358,  1356,  1514,  1231,   754,  1197,  1201,   168,   520,   430,
   364,  1118,  1042,   273,  1120,   803,   182,   217,   433,   752,
   296,   374,   375,   182,  1207,  1214,  1220,  1221,  1412,  1223,
  1224,  1205,  1128,   190,   189,   183,   184,   185,   186,   187,
   188,   231,   968,  1022,   230,   490,   367,   180,   216,   832,
  1040,  1043,  1240,  1244,   180,   293,   218,   958,   840,  1263,
  1265,   181,  1258,   801,   795,  1039,   750,   748,  1488,   749,
  1262,   751,  1040,  1260,   753,   181,   144,   146,   215,  1279,
   750,   748,  1487,   749,   214,   751,   181,   182,   221,   735,
   733,   750,   748,  1486,   749,  1038,   751,   732,   875,  1475,
   291,   182,   570,   571,   145,   147,   148,   149,   150,   151,
   152,   874,   182,  1411,   213,   624,  1080,  1355,   752,   518,
   519,   732,  1290,  1401,   365,  1293,  1357,  1289,  1328,  1273,
  1239,   966,   752,  1296,  1179,   959,  1176,   960,  1175,  1174,
  1173,  1299,  1172,   752,   368,  1171,  1170,   484,  1037,   740,
  1513,   487,  1308,  1477,  1456,  1453,  1452,  1312,   231,  1314,
  1316,   230,  1321,  1451,  1324,   190,   189,   183,   184,   185,
   186,   187,   188,  1327,  1330,  1331,  1332,  1425,  1424,   479,
  1322,   493,   492,   482,  1362,   485,  1334,  1087,   190,   189,
   183,   184,   185,   186,   187,   188,   784,   289,   783,  1336,
  1338,   522,   189,   183,   184,   185,   186,   187,   188,   782,
   781,   880,   780,   779,   643,  1341,  1342,   480,  1344,   623,
  1346,   649,  1348,   778,   169,   162,   898,  1350,  1352,   902,
   925,   488,   957,   777,   776,   962,   144,   146,   775,   626,
   627,   628,   629,   630,   631,   632,   633,   190,   189,   183,
   184,   185,   186,   187,   188,   234,   170,   163,   774,   212,
   773,   166,   167,   483,   145,   147,   148,   149,   150,   151,
   152,   211,   772,   194,   771,   529,   644,   650,   195,   181,
  1030,   770,   956,  1365,   750,   748,   769,   749,   181,   751,
   768,  1369,   767,   750,   197,  1373,  1374,   766,   751,   765,
   527,  1377,   764,   763,   516,   182,   762,   393,   761,   486,
   760,   273,   759,   758,   182,   640,   641,   642,   273,   757,
  1382,   514,   756,   228,  1326,   196,   755,   734,   384,   383,
   382,   381,   237,   235,   380,   236,   752,   379,   269,   268,
   267,   481,   392,   273,   266,   752,   265,   264,   263,   515,
   389,   647,   262,   261,   260,   259,   231,   273,   273,   230,
  1394,   181,   258,   224,   210,  1478,   750,   748,   257,   749,
   256,   751,   255,   524,   254,   273,   253,   273,   526,   273,
   525,   252,   251,   250,   528,   273,   273,   182,   249,   205,
   204,   198,   199,   200,   201,   202,   203,   645,   646,   512,
   248,   513,   190,   189,   183,   184,   185,   186,   187,   188,
   231,   247,   246,   230,   181,   245,   227,   209,   752,   178,
   244,   243,   231,   242,   179,   230,  1405,   241,   240,   947,
   208,  1406,  1407,   639,   207,   225,   206,   648,   174,   173,
   182,   233,  1129,   172,   194,   192,   923,   193,   558,   195,
  1416,   181,   523,   900,   223,  1476,   750,   748,   238,   749,
   530,   751,    12,   391,   558,   197,   557,    11,     9,     1,
   741,   180,   556,   555,   107,   106,  1438,   182,   827,   538,
     7,  1442,   557,    10,  1444,   139,   638,   231,   556,   555,
   230,   657,     8,   288,  1259,   911,   196,     4,     3,  1458,
  1459,  1460,  1461,     2,     0,     0,     0,   511,   752,     0,
   554,   553,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,  1309,     0,     0,     0,   554,   553,     0,  1315,
     0,  1464,     0,  1466,  1468,     0,     0,  1469,  1470,     0,
    68,     0,   229,     0,     0,    69,     0,  1471,  1472,   551,
     0,   552,     0,     0,  1333,   190,   189,   183,   184,   185,
   186,   187,   188,   882,     0,   551,     0,   552,  1335,  1337,
     0,  1482,   226,     0,     0,  1483,  1484,     0,  1485,     0,
     0,     0,     0,     0,  1490,     0,  1343,     0,  1345,     0,
  1347,   881,  1195,     0,     0,  1495,  1349,  1351,     0,     0,
     0,     0,     0,     0,   550,     0,     0,  1502,  1503,  1504,
  1505,   902,     0,  1507,  1206,  1213,     0,     0,  1222,     0,
   181,     0,  1511,  1226,     0,   750,   748,  1512,   749,     0,
   751,     0,     0,     0,   925,  1439,  1516,  1441,  1518,     0,
  1520,   883,  1522,   884,     0,     0,   182,     0,     0,     0,
     0,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,   231,     0,     0,   230,   190,   189,
   183,   184,   185,   186,   187,   188,  1473,   752,     0,   190,
   189,   183,   184,   185,   186,   187,   188,     0,   181,     0,
     0,     0,   273,   750,   748,  1457,   749,   181,   751,     0,
     0,     0,   750,   748,  1455,   749,     0,   751,     0,     0,
     0,     0,     0,     0,   182,   626,   627,   628,   629,   630,
   631,   632,   633,   182,     0,     0,     0,     0,     0,  1302,
     0,   626,   627,   628,   629,   630,   631,   632,   633,     0,
     0,     0,     0,     0,     0,   752,     0,     0,     0,     0,
     0,     0,     0,  1323,   752,     0,    13,    21,    22,    23,
    24,    25,    26,    27,    28,    42,    43,    29,    30,    31,
    32,    33,    44,    46,    47,    48,    49,    50,    51,    52,
    53,    54,    55,    56,    57,    58,    59,    60,    61,    62,
    45,    63,    64,    65,    66,     0,    34,    35,    36,    37,
    38,    39,    40,    41,    94,    89,     0,     0,    95,    99,
     0,     0,     0,   164,   165,     0,     0,     0,     0,     0,
    71,   111,     0,     0,     0,   168,    91,    74,     0,     0,
   117,     0,     0,     0,   125,     0,    72,     0,     0,     0,
     0,   124,     0,    75,    84,     0,   100,   122,     0,     0,
   128,     0,   141,   158,   110,     0,    81,  1436,   194,   192,
     0,   193,    73,   195,     0,     0,     0,    76,     0,     0,
   159,     0,     0,     0,     0,   103,   113,     0,     0,   197,
     0,    90,   135,    96,     0,    17,   133,     0,     0,   142,
     0,     0,     0,     0,     0,     0,     0,   109,     0,     0,
     0,   118,   568,  1467,     0,     0,     0,   564,   160,   161,
   196,   102,     0,     0,     0,     0,     0,   134,  1119,     0,
     0,   126,    86,  1388,    85,    88,   104,   112,   342,     0,
  1393,     0,     0,   343,   625,     0,     0,   101,    82,   181,
     0,   567,     0,     0,   750,   748,  1454,   749,     0,   751,
     0,   569,    77,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,   182,     0,     0,     0,   140,
   143,     0,     0,     0,     0,   120,   121,    97,     0,   116,
    70,   105,    18,     0,     0,   566,     0,   565,     0,   153,
   155,   154,   157,   156,     0,   119,   752,     0,     0,    16,
   171,     0,     0,     0,    93,     0,   114,   181,   231,     0,
   123,   230,   750,   748,  1450,   749,     0,   751,     0,   127,
   132,    92,    83,     0,     0,     0,   131,     0,     0,     0,
   115,     0,   138,   182,     0,   130,    98,   129,    87,   144,
   146,     0,   169,   162,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   752,     0,     0,   145,   147,   148,
   149,   150,   151,   152,   170,   163,   181,     0,     0,   166,
   167,   750,   748,  1446,   749,   181,   751,     0,     0,  1437,
   178,   176,     0,   177,     0,   179,     0,     0,     0,     0,
     0,     0,   182,     0,     0,     0,     0,     0,     0,     0,
     0,   182,     0,     0,     0,     0,     0,     0,     0,   108,
     0,     0,     0,     0,    78,    80,    79,    14,    19,    20,
     0,     0,     0,   752,     0,     0,     0,     0,     0,    67,
     0,     0,   180,     0,     0,   305,   306,   307,   308,   309,
   310,   311,   312,    42,    43,   313,   314,   315,   316,   317,
   318,   320,   321,   322,   323,   324,   325,   326,   327,   328,
   329,   330,   331,   332,   333,   334,   335,   336,   319,   337,
   338,   339,   340,     0,    34,    35,    36,    37,    38,    39,
    40,    41,     0,     0,   952,   948,     0,     0,     0,   954,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,   500,     0,     0,     0,     0,   504,     0,     0,
     0,     0,   508,   953,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   181,     0,   342,     0,  1435,   178,   176,
   343,   177,   181,   179,     0,     0,  1433,   750,   748,     0,
   749,     0,   751,     0,     0,   951,   505,     0,   949,   182,
     0,     0,     0,   304,     0,     0,     0,     0,   182,   955,
   498,   190,   189,   183,   184,   185,   186,   187,   188,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
   180,   496,     0,     0,     0,     0,   499,     0,     0,   752,
   506,     0,   507,     0,     0,   181,   495,     0,   950,  1431,
   750,   748,     0,   749,   181,   751,     0,     0,  1429,   750,
   748,     0,   749,   231,   751,     0,   230,   181,     0,     0,
     0,   182,   750,   748,  1427,   749,     0,   751,   194,   192,
   182,   193,     0,   195,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   182,     0,     0,     0,     0,     0,   197,
   277,     0,   752,     0,     0,     0,     0,     0,     0,     0,
     0,   752,     0,     0,     0,     0,     0,   303,     0,     0,
     0,     0,     0,     0,   752,     0,     0,     0,     0,     0,
   196,     0,     0,     0,     0,     0,     0,   509,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   497,     0,     0,     0,     0,   144,   146,   502,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   205,   204,   198,   199,
   200,   201,   202,   203,     0,   145,   147,   503,   149,   150,
   151,   152,   305,   306,   307,   308,   309,   310,   311,   312,
    42,    43,   313,   314,   315,   316,   317,   318,   320,   321,
   322,   323,   324,   325,   326,   327,   328,   329,   330,   331,
   332,   333,   334,   335,   336,   319,   337,   338,   339,   340,
     0,    34,    35,    36,    37,    38,    39,    40,    41,   972,
     0,     0,     0,     0,     0,   301,    19,    20,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   341,     0,   973,
     0,     0,   190,   189,   183,   184,   185,   186,   187,   188,
     0,     0,     0,     0,   461,     0,     0,     0,     0,   457,
     0,     0,     0,     0,   462,     0,     0,     0,     0,     0,
   181,     0,   342,     0,  1423,   178,   176,   343,   177,   181,
   179,     0,     0,     0,   750,   748,  1426,   749,     0,   751,
     0,     0,     0,   459,     0,     0,   182,     0,   181,     0,
   453,     0,  1421,   178,   176,   182,   177,     0,   179,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
     0,     0,     0,     0,   182,   460,     0,   180,     0,     0,
     0,     0,     0,     0,     0,     0,   752,   974,     0,   456,
     0,     0,     0,   455,     0,     0,     0,     0,   181,     0,
     0,     0,  1419,   750,   748,   180,   749,     0,   751,     0,
   231,   181,     0,   230,     0,     0,   750,   748,  1417,   749,
     0,   751,     0,     0,   182,     0,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,   182,   190,   189,
   183,   184,   185,   186,   187,   188,     0,   277,     0,     0,
     0,     0,     0,   458,     0,   752,     0,     0,     0,     0,
     0,     0,     0,     0,   303,     0,     0,     0,   752,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   342,     0,     0,     0,     0,   343,     0,     0,     0,     0,
     0,     0,     0,     0,   144,   146,   975,   976,   977,   978,
   979,   980,   981,   982,   983,   984,   985,   986,   987,   988,
   989,   990,   991,   992,   993,   994,   995,   996,   997,     0,
     0,     0,   145,   147,   148,   149,   150,   151,   152,   305,
   306,   307,   308,   309,   310,   311,   312,    42,    43,   313,
   314,   315,   316,   317,   318,   320,   321,   322,   323,   324,
   325,   326,   327,   328,   329,   330,   331,   332,   333,   334,
   335,   336,   319,   337,   338,   339,   340,     0,    34,    35,
    36,    37,    38,    39,    40,    41,     0,     0,     0,     0,
     0,     0,   301,    19,    20,     0,   190,   189,   183,   184,
   185,   186,   187,   188,   341,   190,   189,   183,   184,   185,
   186,   187,   188,     0,     0,     0,     0,     0,     0,     0,
  1000,  1002,     0,     0,     0,     0,  1004,     0,     0,   181,
     0,     0,     0,     0,   750,   748,  1410,   749,     0,   751,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   999,   182,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   304,   190,   189,
   183,   184,   185,   186,   187,   188,     0,   190,   189,   183,
   184,   185,   186,   187,   188,     0,   752,     0,     0,     0,
   190,   189,   183,   184,   185,   186,   187,   188,   198,   199,
   200,   201,   202,   203,  1006,     0,  1005,   305,   306,   307,
   308,   309,   310,   311,   312,    42,    43,   313,   314,   315,
   316,   317,   318,   320,   321,   322,   323,   324,   325,   326,
   327,   328,   329,   330,   331,   332,   333,   334,   335,   336,
   319,   337,   338,   339,   340,     0,    34,    35,    36,    37,
    38,    39,    40,    41,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   277,     0,     0,     0,     0,   450,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   303,     0,     0,  1001,  1003,     0,     0,     0,     0,
     0,     0,     0,     0,   449,     0,     0,     0,     0,   451,
     0,     0,     0,     0,     0,   181,     0,   342,     0,     0,
   750,   748,   343,   749,     0,   751,     0,     0,   181,     0,
     0,   144,   146,   750,   748,  1381,   749,     0,   751,     0,
     0,   182,     0,     0,     0,   444,     0,   181,     0,     0,
     0,  1115,   750,   748,   182,   749,     0,   751,     0,   145,
   147,   148,   149,   150,   151,   152,     0,     0,     0,     0,
     0,  1408,   752,   182,     0,     0,     0,     0,     0,   418,
     0,     0,   448,     0,   447,   752,     0,     0,   446,     0,
   181,     0,     0,     0,     0,   750,   748,  1380,   749,     0,
   751,     0,     0,     0,   752,   231,     0,     0,   230,     0,
     0,     0,     0,     0,     0,     0,   182,     0,     0,   301,
    19,    20,     0,   190,   189,   183,   184,   185,   186,   187,
   188,   341,   190,   189,   183,   184,   185,   186,   187,   188,
     0,     0,   277,     0,     0,     0,     0,   752,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,   303,
     0,     0,     0,     0,     0,   181,     0,     0,     0,     0,
   750,   748,  1379,   749,     0,   751,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   182,   417,     0,     0,     0,     0,     0,     0,   144,
   146,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,   752,     0,     0,     0,   419,   145,   147,   148,
   149,   150,   151,   152,   305,   306,   307,   308,   309,   310,
   311,   312,    42,    43,   313,   314,   315,   316,   317,   318,
   320,   321,   322,   323,   324,   325,   326,   327,   328,   329,
   330,   331,   332,   333,   334,   335,   336,   319,   337,   338,
   339,   340,     0,    34,    35,    36,    37,    38,    39,    40,
    41,     0,     0,     0,     0,     0,     0,   301,    19,    20,
     0,     0,     0,     0,     0,   398,   399,   400,   401,   341,
   402,   403,   404,   405,   406,   407,   408,   409,   410,   411,
   412,   413,   414,   415,   416,     0,     0,     0,     0,     0,
     0,   440,     0,     0,     0,     0,   442,     0,     0,     0,
     0,     0,   181,     0,   342,     0,  1113,   750,   748,   343,
   749,     0,   751,     0,     0,   181,     0,     0,     0,   441,
   750,   748,  1378,   749,     0,   751,     0,     0,   182,     0,
     0,     0,   435,     0,     0,     0,     0,   181,     0,     0,
     0,   182,   750,   748,  1364,   749,     0,   751,     0,     0,
     0,     0,     0,     0,     0,     0,   181,     0,     0,   752,
  1111,   750,   748,   182,   749,     0,   751,     0,     0,   438,
     0,   439,   752,     0,     0,   437,     0,     0,     0,     0,
     0,     0,   182,     0,     0,     0,     0,     0,     0,     0,
     0,   181,   231,     0,   752,   230,   750,   748,  1363,   749,
     0,   751,   190,   189,   183,   184,   185,   186,   187,   188,
     0,     0,     0,   752,     0,     0,     0,   182,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   277,
     0,     0,     0,     0,     0,     0,     0,   181,     0,     0,
     0,  1109,   750,   748,     0,   749,   303,   751,   752,   181,
     0,     0,     0,  1105,   750,   748,     0,   749,     0,   751,
     0,     0,     0,   182,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   182,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   144,   146,     0,     0,
     0,     0,     0,     0,   752,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   752,     0,     0,     0,
     0,     0,     0,     0,   145,   147,   148,   149,   150,   151,
   152,   305,   306,   307,   308,   309,   310,   311,   312,    42,
    43,   313,   314,   315,   316,   317,   318,   320,   321,   322,
   323,   324,   325,   326,   327,   328,   329,   330,   331,   332,
   333,   334,   335,   336,   319,   337,   338,   339,   340,     0,
    34,    35,    36,    37,    38,    39,    40,    41,     0,     0,
     0,     0,     0,     0,   301,    19,    20,     0,   190,   189,
   183,   184,   185,   186,   187,   188,   341,     0,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,     0,     0,     0,     0,     0,     0,     0,  1216,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,   181,
     0,   342,     0,  1103,   750,   748,   343,   749,     0,   751,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   182,     0,     0,     0,   304,
     0,     0,  1219,   190,   189,   183,   184,   185,   186,   187,
   188,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   752,     0,     0,     0,
     0,     0,     0,     0,     0,     0,  1218,     0,  1217,     0,
     0,   181,     0,     0,     0,     0,   750,   748,  1101,   749,
   181,   751,     0,     0,     0,   750,   748,  1099,   749,   231,
   751,     0,   230,     0,     0,     0,     0,   182,     0,     0,
     0,     0,     0,     0,     0,     0,   182,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   277,     0,   752,     0,
     0,     0,     0,     0,     0,     0,     0,   752,     0,     0,
     0,     0,     0,   303,     0,     0,  1215,   181,     0,     0,
     0,     0,   750,   748,  1097,   749,     0,   751,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   182,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   144,   146,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   752,     0,     0,     0,     0,     0,
     0,   145,   147,   148,   149,   150,   151,   152,   305,   306,
   307,   308,   309,   310,   311,   312,    42,    43,   313,   314,
   315,   316,   317,   318,   320,   321,   322,   323,   324,   325,
   326,   327,   328,   329,   330,   331,   332,   333,   334,   335,
   336,   319,   337,   338,   339,   340,     0,    34,    35,    36,
    37,    38,    39,    40,    41,     0,     0,     0,     0,     0,
     0,   301,    19,    20,     0,   190,   189,   183,   184,   185,
   186,   187,   188,   341,     0,   421,   422,   418,   190,   189,
   183,   184,   185,   186,   187,   188,   420,     0,     0,     0,
     0,     0,     0,     0,     0,  1209,     0,     0,     0,     0,
   190,   189,   183,   184,   185,   186,   187,   188,   342,     0,
     0,     0,     0,   343,     0,     0,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   304,     0,   181,  1212,
     0,     0,     0,   750,   748,  1095,   749,   424,   751,     0,
     0,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,   182,     0,   181,     0,     0,     0,
  1093,   750,   748,  1211,   749,  1210,   751,     0,     0,     0,
     0,     0,     0,   342,     0,     0,     0,     0,   343,     0,
   417,     0,   182,     0,     0,   752,   231,     0,     0,   230,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
     0,     0,   190,   189,   183,   184,   185,   186,   187,   188,
     0,     0,     0,   752,   419,     0,     0,     0,     0,     0,
     0,     0,     0,   277,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   303,     0,     0,  1208,     0,     0,   181,     0,   342,     0,
  1091,   750,   748,   343,   749,     0,   751,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   182,     0,     0,     0,     0,     0,     0,     0,
   144,   146,     0,   398,   399,   400,   401,     0,   402,   403,
   404,   405,   406,   407,   408,   409,   410,   411,   412,   413,
   414,   415,   416,   752,     0,     0,     0,     0,   145,   147,
   148,   149,   150,   151,   152,   305,   306,   307,   308,   309,
   310,   311,   312,    42,    43,   313,   314,   315,   316,   317,
   318,   320,   321,   322,   323,   324,   325,   326,   327,   328,
   329,   330,   331,   332,   333,   334,   335,   336,   319,   337,
   338,   339,   340,     0,    34,    35,    36,    37,    38,    39,
    40,    41,     0,     0,     0,     0,     0,     0,   301,    19,
    20,     0,   190,   189,   183,   184,   185,   186,   187,   188,
   341,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   305,   306,   307,   308,   309,   310,   311,   312,    42,    43,
   313,   314,   315,   316,   317,   318,   320,   321,   322,   323,
   324,   325,   326,   327,   328,   329,   330,   331,   332,   333,
   334,   335,   336,   319,   337,   338,   339,   340,     0,    34,
    35,    36,    37,    38,    39,    40,    41,     0,     0,     0,
     0,     0,     0,   304,   190,   189,   183,   184,   185,   186,
   187,   188,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,     0,     0,     0,   305,   306,   307,   308,   309,
   310,   311,   312,    42,    43,   313,   314,   315,   316,   317,
   318,   320,   321,   322,   323,   324,   325,   326,   327,   328,
   329,   330,   331,   332,   333,   334,   335,   336,   319,   337,
   338,   339,   340,     0,    34,    35,    36,    37,    38,    39,
    40,    41,     0,     0,     0,     0,     0,     0,   304,     0,
   190,   189,   183,   184,   185,   186,   187,   188,   181,     0,
     0,     0,  1089,   750,   748,     0,   749,   181,   751,     0,
   277,     0,   750,   748,  1361,   749,     0,   751,     0,     0,
   181,     0,     0,     0,   182,   750,   748,   303,   749,     0,
   751,     0,     0,   182,     0,   342,     0,     0,     0,     0,
   343,     0,     0,     0,     0,     0,   182,     0,     0,     0,
     0,     0,   181,     0,     0,   752,  1084,   750,   748,     0,
   749,     0,   751,   304,   752,     0,     0,   144,   146,     0,
     0,     0,     0,   476,   475,     0,  1354,   752,   182,     0,
     0,     0,   181,     0,     0,   277,  1082,   750,   748,     0,
   749,     0,   751,     0,     0,   145,   147,   148,   149,   150,
   151,   152,   303,     0,     0,   478,   477,     0,   182,   752,
   342,     0,  1434,   194,   192,   343,   193,     0,   195,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   197,     0,     0,     0,     0,   752,
     0,     0,   144,   146,     0,     0,     0,     0,   471,   470,
     0,     0,     0,     0,     0,   301,    19,    20,     0,     0,
   277,     0,     0,     0,     0,   196,     0,   341,     0,     0,
   145,   147,   148,   149,   150,   151,   152,   303,     0,     0,
   473,   472,     0,     0,     0,    68,     0,     0,     0,     0,
    69,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,     0,     0,     0,     0,     0,     0,     0,  1266,     0,
     0,     0,     0,     0,     0,     0,     0,   144,   146,   190,
   189,   183,   184,   185,   186,   187,   188,     0,     0,     0,
   301,    19,    20,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   341,     0,     0,   145,   147,   148,   149,   150,
   151,   152,   305,   306,   307,   308,   309,   310,   311,   312,
    42,    43,   313,   314,   315,   316,   317,   318,   320,   321,
   322,   323,   324,   325,   326,   327,   328,   329,   330,   331,
   332,   333,   334,   335,   336,   319,   337,   338,   339,   340,
     0,    34,    35,    36,    37,    38,    39,    40,    41,     0,
     0,     0,     0,     0,     0,   301,    19,    20,     0,   190,
   189,   183,   184,   185,   186,   187,   188,   341,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   305,   306,   307,
   308,   309,   310,   311,   312,    42,    43,   313,   314,   315,
   316,   317,   318,   320,   321,   322,   323,   324,   325,   326,
   327,   328,   329,   330,   331,   332,   333,   334,   335,   336,
   319,   337,   338,   339,   340,     0,    34,    35,    36,    37,
    38,    39,    40,    41,     0,     0,     0,     0,     0,     0,
   304,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,    21,    22,    23,    24,    25,    26,    27,    28,
    42,    43,    29,    30,    31,    32,    33,    44,   276,    47,
    48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
    58,    59,    60,    61,    62,    45,    63,    64,    65,    66,
     0,    34,    35,    36,    37,    38,    39,    40,    41,     0,
     0,     0,   181,     0,     0,   304,     0,   750,   748,  1360,
   749,   181,   751,     0,     0,  1077,   750,   748,     0,   749,
     0,   751,     0,     0,     0,   181,     0,   277,   182,  1075,
   750,   748,     0,   749,     0,   751,     0,   182,     0,     0,
     0,     0,     0,     0,   303,     0,     0,     0,     0,     0,
   181,   182,    68,     0,  1073,   750,   748,    69,   749,   752,
   751,     0,     0,     0,   181,     0,     0,     0,   752,   750,
   748,  1065,   749,   181,   751,  1264,   182,  1071,   750,   748,
   275,   749,   752,   751,   144,   146,     0,     0,     0,     0,
   182,     0,     0,     0,     0,     0,     0,     0,     0,   182,
     0,     0,   277,     0,     0,     0,     0,   752,     0,     0,
     0,     0,   145,   147,   148,   149,   150,   151,   152,   303,
     0,   752,     0,   181,     0,     0,     0,  1069,   750,   748,
   752,   749,     0,   751,     0,     0,     0,     0,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,   182,
   190,   189,   183,   184,   185,   186,   187,   188,     0,   144,
   146,     0,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,   301,    19,    20,     0,     0,   277,     0,     0,
   752,     0,     0,     0,   341,     0,     0,   145,   147,   148,
   149,   150,   151,   152,   274,   190,   189,   183,   184,   185,
   186,   187,   188,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   190,   189,   183,   184,   185,
   186,   187,   188,     0,   144,   146,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   301,    19,    20,
     0,   205,   204,   198,   199,   200,   201,   202,   203,   341,
     0,     0,   145,   147,   148,   149,   150,   151,   152,    21,
    22,    23,    24,    25,    26,    27,    28,    42,    43,    29,
    30,    31,    32,    33,    44,   276,    47,    48,    49,    50,
    51,    52,    53,    54,    55,    56,    57,    58,    59,    60,
    61,    62,    45,    63,    64,    65,    66,     0,    34,    35,
    36,    37,    38,    39,    40,    41,     0,     0,     0,     0,
     0,   181,   272,    19,    20,  1067,   750,   748,     0,   749,
     0,   751,   181,     0,    67,     0,  1063,   750,   748,     0,
   749,     0,   751,     0,   181,     0,     0,   182,  1061,   750,
   748,     0,   749,     0,   751,   181,     0,     0,   182,  1059,
   750,   748,     0,   749,     0,   751,     0,   181,     0,     0,
   182,  1359,   750,   748,     0,   749,     0,   751,   752,     0,
   181,   182,     0,     0,     0,   750,   748,     0,   749,   752,
   751,     0,     0,   182,     0,     0,     0,   275,     0,     0,
     0,   752,     0,   181,     0,     0,   182,     0,   750,   748,
  1329,   749,   752,   751,     0,   181,     0,     0,     0,     0,
   750,   748,  1305,   749,   752,   751,     0,     0,     0,   182,
   194,   192,  1098,   193,     0,   195,  1353,   752,   181,     0,
     0,   182,     0,   750,   748,  1180,   749,   181,   751,     0,
     0,   197,   750,   748,  1162,   749,     0,   751,     0,     0,
   752,   181,     0,     0,   182,   737,   750,   748,     0,   749,
   181,   751,   752,   182,  1115,   178,   176,     0,   177,     0,
   179,     0,   196,     0,     0,     0,     0,   182,     0,     0,
     0,     0,     0,   181,   277,   752,   182,  1113,   178,   176,
     0,   177,   181,   179,   752,     0,  1111,   178,   176,     0,
   177,   694,   179,     0,     0,     0,   181,     0,   752,   182,
  1109,   178,   176,     0,   177,     0,   179,   180,   182,   181,
     0,     0,     0,     0,   178,   176,  1107,   177,     0,   179,
     0,     0,   182,     0,     0,     0,     0,     0,     0,     0,
   180,   144,   146,     0,     0,   182,     0,     0,     0,   180,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   180,     0,     0,     0,     0,     0,   145,
   147,   148,   149,   150,   151,   152,   180,     0,     0,     0,
     0,     0,     0,     0,     0,   190,   189,   183,   184,   185,
   186,   187,   188,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,     0,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,   181,     0,     0,     0,
  1105,   178,   176,     0,   177,     0,   179,     0,     0,   272,
    19,    20,     0,   190,   189,   183,   184,   185,   186,   187,
   188,    67,   182,     0,     0,     0,     0,   190,   189,   183,
   184,   185,   186,   187,   188,     0,   190,   189,   183,   184,
   185,   186,   187,   188,   181,     0,     0,     0,  1103,   178,
   176,     0,   177,   180,   179,   181,     0,     0,     0,     0,
   178,   176,  1101,   177,     0,   179,     0,     0,   181,     0,
   182,     0,     0,   178,   176,  1099,   177,     0,   179,     0,
     0,   182,     0,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,   182,     0,     0,   181,     0,     0,
     0,   180,   178,   176,  1097,   177,     0,   179,   181,     0,
     0,     0,   180,   178,   176,  1095,   177,     0,   179,     0,
     0,     0,   181,   182,     0,   180,  1093,   178,   176,     0,
   177,   181,   179,     0,   182,  1091,   178,   176,     0,   177,
     0,   179,     0,     0,     0,   181,     0,     0,   182,  1089,
   178,   176,     0,   177,   180,   179,   181,   182,     0,     0,
     0,   178,   176,  1085,   177,   180,   179,     0,   181,     0,
     0,   182,  1084,   178,   176,     0,   177,     0,   179,   180,
     0,   181,   182,     0,     0,  1082,   178,   176,   180,   177,
   181,   179,     0,     0,   182,   178,   176,  1079,   177,     0,
   179,     0,   180,     0,   181,     0,     0,   182,  1077,   178,
   176,     0,   177,   180,   179,     0,   182,     0,   181,     0,
     0,     0,  1075,   178,   176,   180,   177,     0,   179,     0,
   182,     0,     0,     0,     0,     0,     0,     0,   180,     0,
     0,     0,     0,     0,   182,     0,   181,   180,     0,     0,
  1073,   178,   176,     0,   177,     0,   179,     0,     0,     0,
     0,   180,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   182,     0,     0,   180,     0,     0,     0,     0,
     0,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,   190,   189,   183,   184,   185,
   186,   187,   188,   180,     0,     0,     0,   190,   189,   183,
   184,   185,   186,   187,   188,     0,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,     0,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
     0,     0,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,     0,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,   205,   204,
   198,   199,   200,   201,   202,   203,     0,     0,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
     0,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,   190,   189,   183,   184,   185,
   186,   187,   188,     0,     0,     0,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,     0,     0,     0,
     0,     0,   190,   189,   183,   184,   185,   186,   187,   188,
   181,     0,     0,     0,  1071,   178,   176,     0,   177,   181,
   179,     0,     0,  1069,   178,   176,     0,   177,     0,   179,
     0,     0,     0,   181,     0,     0,   182,  1067,   178,   176,
     0,   177,     0,   179,     0,   182,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   181,     0,     0,     0,   182,
   178,   176,  1065,   177,     0,   179,     0,   180,     0,   181,
     0,     0,     0,  1063,   178,   176,   180,   177,     0,   179,
     0,   182,     0,   181,     0,     0,     0,  1061,   178,   176,
   180,   177,     0,   179,     0,   182,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,     0,     0,   182,
   181,     0,   180,     0,  1059,   178,   176,     0,   177,     0,
   179,     0,     0,     0,     0,     0,   180,     0,     0,   181,
     0,     0,     0,  1056,   178,   176,   182,   177,     0,   179,
   180,     0,     0,     0,     0,     0,     0,   190,   189,   183,
   184,   185,   186,   187,   188,   182,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,   180,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,     0,     0,     0,     0,     0,   180,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,     0,     0,     0,     0,   190,   189,   183,   184,   185,
   186,   187,   188,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,     0,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,     0,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,     0,     0,     0,     0,     0,   190,   189,   183,
   184,   185,   186,   187,   188,     0,     0,     0,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
     0,   181,     0,     0,     0,     0,   750,   748,  1054,   749,
     0,   751,     0,     0,     0,     0,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,   182,   181,     0,
     0,     0,     0,   750,   748,  1053,   749,   181,   751,     0,
     0,     0,   750,   748,  1036,   749,     0,   751,     0,     0,
     0,   181,     0,     0,   182,     0,   750,   748,   752,   749,
   181,   751,     0,   182,     0,   750,   748,     0,   749,     0,
   751,     0,     0,     0,   181,     0,     0,   182,     0,   750,
   748,     0,   749,   181,   751,   752,   182,     0,   750,   748,
   885,   749,     0,   751,   752,  1031,   181,     0,     0,     0,
   182,   750,   748,   860,   749,     0,   751,  1034,   752,   182,
     0,     0,     0,   181,     0,     0,  1033,   752,   750,   748,
   855,   749,   182,   751,     0,     0,     0,     0,   181,     0,
     0,   752,     0,   750,   748,   839,   749,   181,   751,   182,
   752,     0,   750,   748,   831,   749,     0,   751,     0,     0,
   181,     0,     0,   752,   182,   750,   748,   820,   749,     0,
   751,   181,     0,   182,     0,     0,   750,   748,   789,   749,
   752,   751,   181,     0,     0,     0,   182,   750,   748,   788,
   749,     0,   751,   181,     0,   752,     0,   182,   750,   748,
   747,   749,     0,   751,   752,   181,     0,     0,   182,   737,
   178,   176,     0,   177,     0,   179,   175,   752,     0,   182,
     0,     0,     0,  1432,   194,   192,     0,   193,   752,   195,
     0,   182,     0,     0,     0,     0,     0,     0,     0,   752,
     0,     0,     0,   181,     0,   197,     0,     0,   178,   176,
   752,   177,     0,   179,     0,     0,     0,     0,     0,     0,
     0,     0,   180,     0,     0,   181,     0,     0,     0,   182,
   750,   748,     0,   749,     0,   751,   196,     0,     0,     0,
     0,     0,     0,   190,   189,   183,   184,   185,   186,   187,
   188,   182,   190,   189,   183,   184,   185,   186,   187,   188,
   180,     0,     0,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,   181,     0,     0,     0,     0,
   178,   176,   752,   177,     0,   179,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,     0,     0,
     0,   182,   190,   189,   183,   184,   185,   186,   187,   188,
     0,     0,     0,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,     0,     0,     0,     0,  1430,
   194,   192,   180,   193,     0,   195,     0,     0,     0,     0,
     0,     0,     0,   190,   189,   183,   184,   185,   186,   187,
   188,   197,  1428,   194,   192,     0,   193,     0,   195,     0,
     0,     0,   190,   189,   183,   184,   185,   186,   187,   188,
     0,  1422,   194,   192,   197,   193,     0,   195,     0,  1420,
   194,   192,   196,   193,     0,   195,     0,     0,  1418,   194,
   192,     0,   193,   197,   195,     0,  1114,   194,   192,     0,
   193,   197,   195,     0,     0,   196,     0,  1112,   194,   192,
   197,   193,     0,   195,     0,  1110,   194,   192,   197,   193,
     0,   195,     0,     0,   196,     0,     0,     0,     0,   197,
     0,     0,   196,     0,  1108,   194,   192,   197,   193,     0,
   195,   196,  1104,   194,   192,     0,   193,     0,   195,   196,
     0,  1102,   194,   192,     0,   193,   197,   195,     0,     0,
   196,     0,     0,     0,   197,     0,     0,     0,   196,   194,
   192,  1096,   193,   197,   195,     0,     0,   194,   192,  1094,
   193,     0,   195,     0,     0,     0,     0,   196,     0,     0,
   197,   194,   192,  1086,   193,   196,   195,     0,   197,     0,
     0,  1092,   194,   192,   196,   193,     0,   195,     0,  1090,
   194,   192,   197,   193,     0,   195,     0,     0,     0,     0,
     0,   196,     0,   197,  1088,   194,   192,     0,   193,   196,
   195,   197,     0,  1083,   194,   192,     0,   193,     0,   195,
     0,     0,     0,   196,     0,     0,   197,     0,     0,     0,
     0,     0,     0,     0,   196,   197,     0,  1081,   194,   192,
     0,   193,   196,   195,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,     0,     0,   196,     0,   197,
     0,     0,     0,     0,     0,     0,   196,     0,     0,     0,
     0,   190,   189,   183,   184,   185,   186,   187,   188,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
   196,     0,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,   190,   189,   183,   184,   185,   186,   187,
   188,     0,     0,     0,     0,     0,     0,   190,   189,   183,
   184,   185,   186,   187,   188,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,     0,     0,     0,     0,   190,
   189,   183,   184,   185,   186,   187,   188,     0,     0,   194,
   192,  1078,   193,     0,   195,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,     0,     0,     0,     0,     0,
   197,   190,   189,   183,   184,   185,   186,   187,   188,     0,
   190,   189,   183,   184,   185,   186,   187,   188,     0,     0,
     0,     0,     0,   190,   189,   183,   184,   185,   186,   187,
   188,   196,     0,     0,   190,   189,   183,   184,   185,   186,
   187,   188,     0,     0,     0,   190,   189,   183,   184,   185,
   186,   187,   188,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,     0,     0,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,     0,     0,
     0,     0,   205,   204,   198,   199,   200,   201,   202,   203,
     0,     0,  1076,   194,   192,     0,   193,     0,   195,     0,
     0,     0,     0,     0,     0,     0,   190,   189,   183,   184,
   185,   186,   187,   188,   197,  1074,   194,   192,     0,   193,
     0,   195,     0,     0,     0,     0,     0,     0,   190,   189,
   183,   184,   185,   186,   187,   188,     0,   197,  1072,   194,
   192,     0,   193,     0,   195,   196,     0,  1070,   194,   192,
     0,   193,     0,   195,     0,  1068,   194,   192,     0,   193,
   197,   195,     0,     0,     0,     0,     0,     0,   196,   197,
  1066,   194,   192,     0,   193,     0,   195,   197,   190,   189,
   183,   184,   185,   186,   187,   188,     0,     0,     0,     0,
     0,   196,   197,   194,   192,  1064,   193,     0,   195,     0,
   196,     0,     0,     0,     0,     0,     0,     0,   196,     0,
     0,     0,     0,     0,   197,  1062,   194,   192,     0,   193,
     0,   195,     0,   196,     0,     0,     0,     0,   205,   204,
   198,   199,   200,   201,   202,   203,     0,   197,     0,     0,
     0,     0,     0,     0,     0,   196,     0,     0,     0,     0,
     0,   205,   204,   198,   199,   200,   201,   202,   203,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   196,     0,
   205,   204,   198,   199,   200,   201,   202,   203,   205,   204,
   198,   199,   200,   201,   202,   203,     0,   205,   204,   198,
   199,   200,   201,   202,   203,   205,   204,   198,   199,   200,
   201,   202,   203,     0,     0,     0,   205,   204,   198,   199,
   200,   201,   202,   203,   205,   204,   198,   199,   200,   201,
   202,   203,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   205,   204,   198,   199,   200,   201,   202,
   203,   205,   204,   198,   199,   200,   201,   202,   203,     0,
   205,   204,   198,   199,   200,   201,   202,   203,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   205,   204,   198,
   199,   200,   201,   202,   203,   205,   204,   198,   199,   200,
   201,   202,   203,     0,     0,     0,     0,     0,     0,   205,
   204,   198,   199,   200,   201,   202,   203,     0,     0,     0,
   205,   204,   198,   199,   200,   201,   202,   203,   205,   204,
   198,   199,   200,   201,   202,   203,     0,     0,     0,     0,
     0,     0,     0,   205,   204,   198,   199,   200,   201,   202,
   203,     0,   205,   204,   198,   199,   200,   201,   202,   203,
     0,     0,  1060,   194,   192,     0,   193,     0,   195,     0,
     0,     0,     0,     0,     0,     0,   205,   204,   198,   199,
   200,   201,   202,   203,   197,  1058,   194,   192,     0,   193,
     0,   195,     0,     0,  1057,   194,   192,     0,   193,   191,
   195,     0,     0,   194,   192,     0,   193,   197,   195,     0,
     0,     0,     0,     0,     0,   196,   197,     0,     0,  1032,
     0,   736,   194,   192,   197,   193,     0,   195,     0,     0,
     0,   194,   192,     0,   193,     0,   195,     0,   196,     0,
     0,     0,     0,   197,     0,   194,   192,   196,   193,     0,
   195,     0,   197,     0,     0,   196,   194,   192,     0,   193,
     0,   195,     0,     0,     0,     0,   197,     0,     0,     0,
   181,     0,     0,     0,   196,   750,   748,   197,   749,     0,
   751,     0,     0,   196,     0,     0,     0,   205,   204,   198,
   199,   200,   201,   202,   203,     0,   182,   196,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   196,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   752,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   912,     0,   909,
   908,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   907,
     0,   205,   204,   198,   199,   200,   201,   202,   203,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   922,     0,     0,     0,   205,   204,   198,   199,   200,   201,
   202,   203,   914,     0,     0,     0,     0,     0,   910,     0,
     0,     0,     0,     0,     0,     0,     0,   205,   204,   198,
   199,   200,   201,   202,   203,     0,   205,   204,   198,   199,
   200,   201,   202,   203,   205,   204,   198,   199,   200,   201,
   202,   203,     0,     0,     0,     0,     0,     0,     0,   205,
   204,   198,   199,   200,   201,   202,   203,   932,     0,   929,
   920,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   205,   204,   198,   199,   200,   201,   202,   203,     0,
     0,   942,   915,     0,     0,     0,   944,     0,     0,     0,
   903,   547,   543,   904,   205,   204,   198,   199,   200,   201,
   202,   203,     0,   231,   905,   906,   230,   916,     0,   921,
     0,     0,     0,   541,     0,     0,     0,     0,     0,   539,
   943,     0,   928,     0,     0,   546,     0,   536,     0,     0,
     0,     0,     0,     0,   941,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   532,     0,     0,     0,
     0,     0,   933,     0,     0,   931,     0,     0,     0,     0,
   913,     0,     0,     0,     0,   918,   945,     0,     0,   544,
     0,   545,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   534,     0,     0,     0,   231,   917,     0,
   230,   936,   231,     0,     0,   230,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   927,
   930,     0,     0,     0,   535,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   937,     0,   934,     0,     0,     0,   548,
   540,     0,     0,     0,     0,     0,   935,   938,     0,     0,
   939,     0,     0,     0,     0,     0,     0,     0,     0,   537,
     0,     0,   926,     0,     0,     0,   940,   533,     0,     0,
     0,     0,     0,     0,     0,     0,   919,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   542,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   205,   204,   198,   199,   200,   201,   202,   203,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   205,   204,   198,   199,   200,   201,
   202,   203,     0,   205,   204,   198,   199,   200,   201,   202,
   203,   205,   204,   198,   199,   200,   201,   202,   203,     0,
   946,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   205,   204,   198,   199,   200,   201,   202,   203,     0,   205,
   204,   198,   199,   200,   201,   202,   203,     0,     0,     0,
     0,     0,     0,   205,   204,   198,   199,   200,   201,   202,
   203,     0,     0,     0,     0,   204,   198,   199,   200,   201,
   202,   203,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   183,   184,   185,   186,   187,
   188 };
yytabelem yypact[]={

  1380, -1000,  1313,  1309,  1308,  6406,  7399,  1306,  1304,  1300,
  1287,  1234,  1141,  1129,   903,   867,   472,   922,   791, -1000,
 -1000,  1268,  1267,  1263,  1261,  1260,  1255,  1252, -1000,  1251,
  1240,  1228,  1223,  1222, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  1221,  1216,  1214,  1212,
  1210,  1208,  1202,  1195,  1194,  1193,  1192,  1188,  1187, -1000,
 -1000, -1000,  1186,  1184,  1180,  1179,  1178,  4455,  4455,  4455,
 -1000,    22,   463,   462,   183,  -261, -1000,   449,    72,    72,
    72,  4380,  4380,  4380,  -262,  -263,  -279,    88,    47,    63,
    63,    63, -1000,  -280,  -281,    63,   446,   414,   505,    -4,
   197,   123,   402, -1000,  -259,  1177,  1174,  1171,  1170,  1169,
  1168,  -128,    72,   845,   230,  2658,  3516,  2658,  -173,   397,
 -1000, -1000, -1000,  -528,   379,  2887,  2570,  2085,   312,  3913,
  3838,   719,   687,   562,  1768,   857,   476, -1000,   836,  7387,
   957,  -283,   173,    83, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  1443,  1443,
  1443, -1000, -1000, -1000, -1000, -1000,  4455,  4455,  4455,  4455,
  4455,  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,
  4380, -1000,  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,
  4455,  4455,  4455,  4455,  4455,  4455, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000,  4380,  4455,  4380,  4455,   368,  4380,  -287,
   577,  1315, -1000,    72,    28,    63,   766,   111,   -55, -1000,
 -1000, -1000, -1000,   -30,  -288,  -294,  -295,  4380,  4380,  -104,
  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,
  4455,  4455,  4772,  4455,  4455,  -296,  4455,  4455,  4455,  4455,
  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,  4455,
   747,   474,   714,   561,   931,   924,  1167,   923,  7390,  6368,
   747,   474,    72, -1000, -1000,  -297,   985,  -240, -1000, -1000,
  -304, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
  6356,   714,   561,   908,   838,  1166,  1162,  1159,  1153,  1152,
  1150,  1148, -1000,  1146,  1143,  1142,  1139,  1137, -1000, -1000,
  1132,  1130,  1126,  1121,  1114,  1112,  1100,  1098,  1078,  1074,
  1073,  1063,  1053, -1000, -1000, -1000,  1052,  1050,  1049,  1038,
  1036,  4380,  4380,  4380,  6345,  6334, -1000, -1000, -1000,  4380,
   388,   151,  -135,    72, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  -305,  -306,  -307,  -309,
  -136,   897,  -137,   849, -1000, -1000, -1000, -1000,  -310,    -7,
    -9,   -12,   -13,   -15,   -22, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000,   382,   374,   239,   381,   360,  -311, -1000, -1000,  4380,
 -1000, -1000, -1000, -1000, -1000,   838,  6323,  -159,  -312,  -313,
  -315,   403, -1000, -1000,   838,  6310,  -159,  -316,  -317,  -318,
  -487, -1000, -1000,   838,  6301,  -159,  -319,  -320,  -321,  -322,
  -323,   -60,   351,  -324,  -326,  -327,   -68,  -488,   -69,  6286,
  4380,  4380,  4380,  4380,  6269,  -328,  -329,  -330,  -331, -1000,
  -332,  -333,  -334,  -388, -1000,  -391,  -392,  -394,  -395,   -56,
   476, -1000, -1000, -1000, -1000,  -159,  -398,  -399,  -404,  -405,
  1099,  6256,  4380,  4380,   -71,  -406,  -407,  -408,  -410,  -415,
 -1000,  -416,  -418,  -425,  -428,    72,   182, -1000,  7298,  7382,
  1735,   593, -1000,  -430,    72,  -436,  -452,  -453,  -159,  -145,
 -1000, -1000, -1000,  2658,  4380,  -454,  2041,  2402,  -455,  -325,
  -456,    25,  4380,   345, -1000, -1000, -1000, -1000, -1000,   332,
   973, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
  -458,  -460, -1000, -1000,  -461,  -462,  -463,  -464,   -73,    72,
 -1000, -1000,  1257,  1111,  1257,  1111,   833,   775,   833,   775,
   833,   775,   765,  6247,  1122,  1122,  1122,  1122,  1122,  1122,
  7443,   451,  1111,  1257,  1111,  1257,   775,   840,   775,   840,
   840,   775,  7371,  6478,  1282,  1282,  1282,  1282,  1282,  1282,
  2186,  7424,  6233,  7413,  6478,  6224,  7413,  6478,   319, -1000,
  6210,   984,   884,   818, -1000,   467, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000,   191, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000,  2041,  -465,  4380,  -466,  -467, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000,  6201,  6174,   813,
  5972,  7363,  7354,  5953,  7331,  5926,  7104,  5912,  7081,  5898,
  7059,  5876,  7044,  5862,  7036,  5853,  7027,  5599,  7004,  5571,
  6981,  5557,  6867,  5543,   955,  6756,  5534,  6732,  5521,  5509,
  6689,  1026,  6723,  5498,  6708,  5484,  6700,  5475,  6675,  5461,
  6667,  5450,  5148,  5421,   639,  5408,  6650,  5397,  6641,  5349,
   -31,  5252,  6633,  5239,  6614,  5225,  6606,  5216,  6595,  5193,
  4380,  4380,   417,  1299,  4455,  -104, -1000, -1000, -1000, -1000,
  -468, -1000, -1000, -1000, -1000, -1000, -1000,  4380,  4380,  4380,
  4380,  4380,  4380,   417,   823,  4380,  4380,  4380,  4380,  4380,
  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,
  -471,  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,  4380,
  4380,  4380,  4380,  4380,  4380,   474,  5184,   474,  4380,  4380,
  5170, -1000,   313,   285,   136, -1000, -1000, -1000, -1000, -1000,
   -29,   -38,   -45,   -48,   982,   981,   978,   976,   975,   974,
   972, -1000, -1000,   257, -1000,   256, -1000, -1000,   970,  5161,
  4380, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  -472,  -474,
 -1000,  4380, -1000, -1000, -1000, -1000, -1000,  -479,  -480,  4380,
 -1000, -1000, -1000, -1000, -1000, -1000,  -481, -1000, -1000, -1000,
 -1000,  -482, -1000,  -484,  -485,  4380,  6428,  6428,  6428,  6428,
  4380, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000,  -486, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000,   132,  -489,  -492,  -494,  4380,  6428,  6428,  -495, -1000,
 -1000, -1000, -1000,   255, -1000, -1000, -1000, -1000, -1000,  -499,
  7298, -1000, -1000,  3521,  3204,  4380,  4380,    72,  4380,  4380,
  -503, -1000,    72,  -505,  -507,  -509,   355,   135,  -512,   966,
 -1000, -1000, -1000,  7382, -1000, -1000,   133,  -513,  -314,   253,
   248,   -10,  -514,   238,  -515,  -517,   355,   510,  4305,  3988,
  -518,  -519,  -107,  -520,  -523,  -524,   965, -1000, -1000,    57,
  -299,   238,  -109,  -525,  -527,  -529, -1000, -1000,  -532,  -533,
  -534, -1000, -1000, -1000, -1000, -1000, -1000,  -536, -1000,  6428,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  6428,  -537,
    63,  4380,  -539,  -547,  4380,  -549,  -550, -1000, -1000,   376,
  -557, -1000, -1000, -1000,  -562,   355,  -563,  -564,   422,  5138,
 -1000, -1000,   221, -1000, -1000, -1000, -1000, -1000, -1000,  -566,
 -1000,  4380,  4455,   811,   794, -1000,  4380,  -567,  4380,  4455,
   541,  4380,   368,  4380,  -569,  -104, -1000, -1000,  2041,   964,
  5126, -1000, -1000,  4380,  4380,  4380, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000,  4455,  4380, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  4455,  4455,
 -1000, -1000, -1000, -1000, -1000,  -575,  -576, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000,  4380,  4380,  4455,  4380,  4455,  4380,
  4455,  4380, -1000, -1000, -1000, -1000,  4455,  4455, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  5103,  4293,   906,   835,
 -1000,   962,  6428,  1131,  1131,   765,   765,   765,   906,   834,
  5090,  5078,  5067,  5055,  4787,  5044,  4846,  4796,  4773,  4748,
  4734,  4725,  4355,  4325,  4280,  1023,  4271,  3989,  3899,  3871,
  3670,  3603,  3594,  3522,  3352,  3294,  3340,  3259,  3205,  2920,
  6428,  3240,  4380, -1000,   144, -1000, -1000,  -138, -1000,  -140,
  4380,  -577,  -579,  -580,  4380,  4380,  -581, -1000, -1000,  -582,
  4380,  3218, -1000, -1000,  3038, -1000, -1000,  6428, -1000, -1000,
 -1000, -1000,  2963,  2901, -1000, -1000,   376,  -583, -1000, -1000,
 -1000,  6428, -1000, -1000, -1000, -1000, -1000,  6428,  -584,  -586,
  -587,  -588,    72, -1000,  6428,  -589,  -590,  -591,  -592,    72,
  6428,  6428, -1000,  6428,  6428, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  4380,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000,  6428,    76,  6428,    74, -1000, -1000,  -593,
 -1000, -1000, -1000,   196, -1000, -1000, -1000, -1000,   959, -1000,
  -595, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
  6428, -1000, -1000,  6428, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000,  -597,  -598,  4380, -1000, -1000,  6428,  7413,
  4380,  4380,  6428, -1000,  2888,  7413,  6478, -1000, -1000, -1000,
 -1000,  6428,   193, -1000,  2712,   949,   817, -1000,  -599,  4380,
  2494,  6428,  6428,  6587,  2481,  6578,  2431,  6570,  2403,  1017,
  1016,  2412,  2180,  6551,  2167,  6528,  2158,  6382,  2095,  4381,
  2086,  1696,  1928, -1000, -1000,  4380,  -104,  -600,  -104, -1000,
  4380,  -601, -1000,  4380,  -602,  1919,   190,   134,   130,  1850,
  1002,   995,   994,  1782,  1540,   993, -1000,  1531,  4380,  4380,
  4380,  4380, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000,  6428, -1000, -1000, -1000, -1000, -1000,
 -1000,  -603, -1000, -1000, -1000,  6428,  6428,  6428,   770, -1000,
  4380,  -604,  4380,  4455,   538, -1000,  6428,  4380, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  4380,  4380, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  1463,   780,
   935,   780,  1294,   992,  1204, -1000,   188, -1000,   820,   779,
  4380, -1000, -1000, -1000,  4380,  4380, -1000,  4380,   929,   918,
   904,   805, -1000,  4380,  6428, -1000,   764,  7413,  6478, -1000,
   497,   652,   438, -1000,  4380,  -605, -1000, -1000, -1000, -1000,
   -49,   -51,  6428,   415,   283,   162,  4380,  4380,  4380,  4380,
  6428,   754,  4380, -1000, -1000,   108, -1000, -1000, -1000,  -606,
  -608,  4380,  6428,  6428,  6428,  6428,  4380,  6428, -1000,   989,
   841,    75,  6428, -1000, -1000,  4380,    43,  4380,    30,  4380,
    13,  4380,  6428 };
yytabelem yypgo[]={

     0,     0,   369,  1383,  1378,  1377,   158,   590,     3,     6,
   482,     4,  1375,  1374,     7,     5,  1373,   372,  1372,  1371,
  1366,  1365,  1363,  1360,  1359,  1358,    17,   388,  1355,  1354,
     2,  1350,  1349,  1348,  1347,  1342,  1340,   791,   500,   719,
   812,  1333,  1326,  1309,  1162,    10,     8 };
yytabelem yyr1[]={

     0,    32,    32,    32,    32,    32,    32,    32,    32,    32,
    32,    32,    32,    32,    35,    35,    35,    35,    35,    35,
    35,    17,    17,    17,    17,    17,    17,    17,    17,    18,
    18,    18,    18,    18,    18,    18,    18,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
    23,    22,    22,    22,    22,    22,    22,    22,    27,    27,
    27,    27,    27,    27,    27,    27,    27,    27,    27,    27,
    27,    27,    27,    27,    27,    27,    27,    27,    27,    27,
    20,    20,    20,    20,    20,    20,    20,    20,    20,    20,
    20,    20,    31,    31,    31,    31,    19,    19,    19,    19,
    19,    19,    34,    36,    36,    36,    36,    36,    36,    36,
    36,    36,    36,    36,    36,    36,    36,    36,    36,    36,
    36,    36,    36,    36,    36,    36,    36,    36,    36,    36,
    36,    36,    33,    33,    33,    33,    33,    33,    37,    37,
    37,    37,    37,    37,    39,    39,    39,    40,    40,    40,
    40,    40,    40,    40,    38,    38,    38,    38,    38,    41,
    41,    45,    45,    45,    45,    45,    45,    45,    45,    45,
    45,    45,    45,    45,    45,    45,    45,    45,    45,    45,
    45,    45,    45,    45,    45,    45,    45,    45,    45,    45,
    45,    45,    42,    42,    46,    46,    46,    46,    46,    46,
    46,    46,    46,    46,    46,    46,    46,    46,    46,    46,
    46,    46,    46,    46,    46,    46,    46,    46,    46,    46,
    46,    46,    46,    46,    43,    43,    43,    43,    43,    43,
    43,    43,    43,    43,    43,    44,    44,    44,    44,    21,
    21,    21,    21,    21,    21,    24,    24,    24,    24,    24,
     7,     7,     8,     8,    28,    28,    28,    28,    28,    29,
    29,    29,    29,    26,    26,    25,    25,    25,    15,    15,
    15,    15,    15,    14,    14,    14,    30,    30,     9,     9,
    12,    12,    12,    11,    11,    11,    11,    11,    11,    11,
    11,    11,    11,    11,    11,    11,    11,    11,    11,    11,
    11,    11,    11,    11,    11,    11,    11,    11,    11,    13,
    13,    13,    16,    16,    16,    16,    16,    16,    10,    10,
     6,     6,     6,     6,     6,     6,     6,     6,     6,     3,
     3,     3,     3,     3,     5,     4,     4,     4,     4,     4,
     4,     4,     4,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1 };
yytabelem yyr2[]={

     0,     0,     4,     4,     4,     5,     5,     4,     4,     4,
     4,     4,     4,     5,     7,     9,     7,     5,     7,     3,
     7,     3,     3,     3,     3,     3,     3,     3,     3,     5,
     7,     7,     7,     7,    19,    11,     9,     3,     7,     5,
     5,     7,    17,     3,     7,     5,     5,     5,     9,     9,
    13,     5,     5,     5,    15,     5,     5,     7,     7,     5,
     5,     5,     3,     5,     5,     5,     5,     5,     5,     5,
     9,    13,     7,    11,     7,    11,    15,    11,    15,     9,
    17,     9,    17,     5,     5,     5,     5,     3,    15,    13,
    13,    13,    21,    21,    13,     9,     3,     5,     5,     5,
     5,     5,     5,     5,     5,     5,     5,     5,     5,     7,
     7,     9,     7,     7,     9,     7,     7,    11,     5,     9,
     9,    13,     5,     3,     3,     3,     5,    35,     5,     5,
     5,     7,     5,     5,    17,     7,     7,     7,     7,     7,
     9,     9,     5,     5,     7,     5,     5,     5,    17,     7,
     7,     7,     7,     7,     9,     9,     5,     5,     5,     7,
     5,     5,     9,     7,     7,     7,     7,     7,     7,     9,
     7,     7,     7,     7,     9,     7,     9,     9,    17,     7,
     7,     7,     7,    17,     7,     7,     7,     7,     5,     7,
     7,     7,     7,     5,     7,     7,     7,     7,     9,     5,
     7,     7,     7,     7,     7,     7,     9,    11,    11,     9,
     9,     9,     9,     7,     7,     9,     7,     7,     7,     7,
     9,     5,     7,     7,     7,     7,     7,     9,     5,     7,
     9,     9,     7,     7,     7,     7,    11,    13,    13,     9,
     9,     7,     7,     7,     7,     7,     7,     9,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     2,     2,     2,     2,
     2,     2,     4,     3,     3,     5,     5,     5,     5,     5,
     7,     7,     7,     7,     7,     7,     7,     7,     5,     5,
     7,     7,     5,     7,     7,     7,     7,     7,     9,     9,
     9,     5,     2,     4,     2,     4,     6,     4,     2,     2,
     2,     2,     2,     2,     4,     4,     4,     3,     5,     5,
     5,     5,     7,     5,     4,     4,     4,     4,     3,     2,
     4,     3,     5,     5,     5,     5,     5,     5,     5,     5,
     5,     5,     3,     5,     5,     7,     7,     5,     5,     7,
     7,     7,     7,     7,     7,     7,     7,     5,     5,     5,
     5,     7,     2,     4,     3,     5,     5,     5,     5,     5,
     5,     5,     5,     5,     5,     5,     5,     5,     5,     5,
     5,     5,     5,     7,     7,     7,     7,     5,     5,     7,
     5,     5,     5,     7,     3,     5,     5,     5,     5,     9,
     5,     7,     5,     5,     5,     3,     5,     5,     5,     7,
     3,     3,     5,     5,     5,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,    13,
    13,    17,    11,    21,    11,     7,     7,    11,    15,     7,
     7,    11,    15,     3,     3,     7,    11,     3,     7,     7,
     7,     7,     7,     7,     7,     7,     7,     7,     7,     7,
     7,     7,     7,     7,     7,     7,     7,     7,     9,     9,
     9,     9,     9,    13,     9,     9,     3,     9,     9,     9,
     9,    13,    13,    13,    13,     3,     3,     9,     9,    13,
    13,     9,     9,     9,     9,    17,    13,    13,    13,     9,
     9,     3,     3,     3,    13,    13,    13,    13,     9,     9,
     9,     9,    11,     7,     7,     7,     7,     7,     7,     7,
     7,     5,     7,     5,     2,     3,     9,     7,     9,    13,
    17,    11,    15,     7,    11,     7,     7,     7,     7,     7,
     7,     9,     9,     9,     9,    13,     9,     9,     3,     9,
     9,     9,     9,    13,     7,     7,     7,     7,     7,     7,
     7,     7,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     9,     9,    13,     9,     9,     9,
     9,    17,    13,    13,    13,     9,     9,     3,     3,     3,
    13,     9,     9,     9,     9,    11,     7,     7,     7,     7,
     7,     7,     7,     7,     5,     7,     5 };
yytabelem yychk[]={

 -1000,   -32,    -3,    -4,    -5,    -1,    -2,   -23,   -18,   -33,
   -22,   -34,   -35,   256,   627,    -6,   499,   385,   482,   628,
   629,   257,   258,   259,   260,   261,   262,   263,   264,   267,
   268,   269,   270,   271,   296,   297,   298,   299,   300,   301,
   302,   303,   265,   266,   272,   290,   273,   274,   275,   276,
   277,   278,   279,   280,   281,   282,   283,   284,   285,   286,
   287,   288,   289,   291,   292,   293,   294,   639,    40,    45,
   480,   320,   336,   362,   327,   343,   367,   452,   624,   626,
   625,   356,   438,   522,   344,   424,   422,   538,   425,   305,
   381,   326,   521,   504,   304,   308,   383,   477,   536,   309,
   346,   437,   411,   375,   426,   481,   -28,   -29,   619,   397,
   354,   321,   427,   376,   506,   530,   479,   330,   401,   495,
   475,   476,   347,   510,   341,   334,   421,   519,   350,   537,
   535,   526,   520,   386,   417,   382,   -37,   -39,   532,   -21,
   469,   352,   389,   470,   539,   567,   540,   568,   569,   570,
   571,   572,   573,   489,   491,   490,   493,   492,   353,   370,
   408,   409,   543,   575,   313,   314,   579,   580,   325,   542,
   574,   500,    10,    10,    10,    10,    43,    45,    42,    47,
    94,    37,    63,   632,   633,   634,   635,   636,   637,   631,
   630,    10,    43,    45,    42,    47,    94,    63,   632,   633,
   634,   635,   636,   637,   631,   630,    10,    10,    10,    10,
    10,    10,    10,    91,    61,    91,    61,   425,   464,   357,
    46,    46,    -7,   412,   321,   393,   530,   374,   281,   500,
   448,   445,    -7,   530,   344,   422,   424,   421,   547,    46,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    -2,    -1,   627,    -6,   499,   385,   273,   482,    -2,    -1,
    -2,    -1,   480,   340,   340,   344,   628,   413,   -16,   628,
   405,   531,   306,   486,   416,   402,   451,    -7,    -7,    -7,
    -1,   627,    -6,   499,   385,   257,   258,   259,   260,   261,
   262,   263,   264,   267,   268,   269,   270,   271,   272,   290,
   273,   274,   275,   276,   277,   278,   279,   280,   281,   282,
   283,   284,   285,   286,   287,   288,   289,   291,   292,   293,
   294,   639,    40,    45,    -1,    -1,   628,   628,   628,   519,
   401,   499,   482,   452,    -9,   529,   369,    -9,    -9,   628,
   628,    -9,   340,   340,   385,   499,   334,   421,   519,   499,
   499,   385,   499,   385,   499,   500,   385,   386,   627,    40,
    40,    40,    40,    40,    40,   542,   574,   499,    -7,   385,
    -7,   498,   377,   342,   -26,   355,   462,   -27,   547,   548,
   549,   550,   552,   553,   554,   555,   556,   557,   558,   559,
   560,   561,   562,   563,   564,   565,   566,   444,   331,   478,
   340,   329,   330,   -27,   401,   -27,   547,   340,   628,   537,
   510,   334,   421,   519,    -7,   385,    -1,   428,   422,   424,
   344,   372,   349,    -7,   385,    -1,   428,   424,   422,   344,
   319,   349,    -7,   385,    -1,   428,   424,   344,   488,   378,
   410,   339,   349,   422,   424,   344,   339,   378,   522,    -1,
   546,   545,   578,   577,    -1,   546,   545,   578,   577,   340,
   378,   502,   344,   424,   340,   378,   502,   344,   424,   281,
   -37,   -39,   500,   499,    -7,   428,   413,   534,   392,   418,
   334,    -1,   541,   569,   339,   378,   422,   424,   344,   519,
    -7,   530,   422,   424,   344,   372,   327,   -38,   523,   524,
   412,   328,    -7,   496,   417,   424,   422,   344,   428,   319,
   -36,    -7,   399,   530,   436,   467,   380,   522,   -24,   372,
   503,   366,   564,   345,   422,   424,   378,   344,   502,   -17,
   527,   472,   474,   434,   433,   396,   395,   389,   371,   628,
   352,   424,   -40,    -7,   344,   424,   422,   378,   339,   388,
   -40,   -40,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
    -1,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,
    -1,    -2,    -2,    -1,    -2,    -2,    -2,    -2,    -2,    -2,
    -2,    -2,    -1,    -2,    -1,    -1,    -2,    -1,   -26,    -7,
    -1,   628,    -6,   522,   418,   499,   296,   297,   298,   299,
   300,   301,   302,   303,    -7,   530,    -9,    -9,   -20,   547,
   429,   430,   431,   328,   390,   511,   512,   465,   551,   335,
   391,    -7,   380,   467,   547,   530,   500,   -19,   581,   582,
   416,   486,   583,   584,   628,   628,   628,    -1,    -1,    -6,
    -1,    -2,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,
    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,
    -2,    -1,    -2,    -1,   499,    -2,    -1,    -2,    -1,    -1,
    -2,   628,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,
    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,
    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,
    91,    91,    46,    46,    40,    46,    41,    41,    -7,   628,
    44,   -31,   622,   620,   621,   623,   628,    44,    43,    45,
    42,    47,    94,    46,    46,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    -1,    -1,    -1,    44,    44,
    -1,   340,   380,   371,   527,    -7,   628,   628,   628,   628,
   527,    46,   527,    46,   628,   499,   499,   499,   499,   499,
   499,   340,   340,   -26,   340,   -26,   340,   340,   628,    -1,
    44,   -10,   537,   535,   628,   628,   628,   -25,   344,   457,
   442,    44,   -10,   628,   628,   628,   628,   502,   530,    44,
   -10,   628,   628,   628,   628,   628,   502,   340,   628,   628,
   628,   502,   628,   506,   502,    44,    -1,    -1,    -1,    -1,
    44,   628,   628,   628,   628,   628,   628,   628,   628,   628,
   628,   628,   628,   500,   -38,   -10,   628,   628,   628,   628,
    -7,   372,   344,   422,   424,    44,    -1,    -1,   502,   628,
   628,   628,   628,   628,   628,   628,   628,   628,    -7,   344,
   -41,   -45,    -7,   432,   435,   446,   447,   311,   282,   281,
   350,   -12,   279,   502,   344,   424,   449,   530,   507,   628,
   402,   451,   332,   -42,   -46,    -7,   530,   467,   380,   317,
   468,   413,   315,   410,   503,   514,   449,   501,   515,   518,
   534,   392,   339,   378,   344,   424,   628,   -43,   340,   413,
   463,   410,   339,   378,   344,   424,   -44,    -7,   344,   422,
   424,   628,    -7,   628,   628,   628,   -10,   530,   -27,    -1,
   628,   -11,   348,   368,   466,   585,   586,   587,   588,   589,
   590,   591,   592,   593,   594,   595,   596,   597,   598,   599,
   600,   601,   602,   603,   604,   605,   606,   607,    -1,   372,
   338,   502,   339,   503,   344,   424,   422,   628,   628,   536,
    -8,   344,   457,   628,   418,   530,   424,   422,   487,    -1,
   340,   340,   -17,   628,   628,   628,   628,   628,   628,   502,
    -7,    58,    58,    93,    93,   340,    44,    44,    91,    61,
    46,    61,   425,   464,   357,    46,   320,   507,   -11,   628,
    -1,   628,   628,    44,    44,    61,    41,    41,    41,    41,
    41,    41,    41,    41,    44,    44,    41,    41,    41,    41,
    41,    41,    41,    41,    41,    41,    41,    41,    44,    44,
    41,    41,    41,    41,    41,    44,    44,    41,    41,    41,
    41,    41,    41,    41,    44,    44,    44,    44,    44,    44,
    44,    44,    41,    41,    41,    41,    44,    44,    41,    41,
    41,    41,    41,    41,    41,    41,    -1,    -1,    -6,   499,
    -6,   628,    -1,    -1,    -1,    -1,    -1,    -1,    -6,   499,
    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    -1,   628,    -1,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
    -1,    -1,    44,   340,   340,   385,   499,   499,   499,   499,
    44,    44,    44,    44,    44,    44,    44,   340,   340,    44,
    44,    -1,   628,   628,    -1,   628,   628,    -1,   628,   628,
   628,   628,    -1,    -1,   628,    -7,   536,    -8,   628,   628,
   628,    -1,   628,   340,   628,   -45,    -7,    -1,   502,   344,
   424,   422,   388,    -7,    -1,   502,   344,   424,   422,   388,
    -1,    -1,    -7,    -1,    -1,   628,    -7,   628,   628,   628,
   -15,   528,   333,   416,   486,   332,   320,   507,   628,    44,
   -46,   320,   507,   628,   -11,   628,   340,   340,   394,   533,
   507,   628,   -14,   486,   416,   338,   628,   628,   -15,   -13,
   443,   307,   440,    -1,   530,    -1,   530,   628,   628,   502,
   628,   628,   628,    44,   459,   453,   320,   507,   628,   -14,
   502,   628,   628,   628,   628,   628,   628,   628,   628,    -9,
    -1,   628,   628,    -1,   628,   628,    -8,   628,   628,   -15,
   628,   628,    -7,   424,   422,    44,   340,   628,    -1,    -2,
    61,    61,    -1,   628,    -1,    -2,    -1,   -30,   323,   282,
   281,    -1,   -26,    -7,    -1,   628,    -6,   -11,    44,    44,
    -1,    -1,    -1,    -2,    -1,    -2,    -1,    -2,    -1,   628,
   628,    -1,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    93,    93,    91,    46,    44,    46,    41,
    44,    44,    41,    44,    44,    -1,   380,   527,   527,    -1,
   628,   628,   628,    -1,    -1,   628,   628,    -1,    44,    44,
    44,    44,    -8,   628,   628,   628,   628,   628,    -7,   628,
   628,   628,   628,    -7,    -1,   507,   320,   507,   320,   628,
   340,    44,   628,   628,   628,    -1,    -1,    -1,    93,   340,
    44,    44,    91,    61,    46,   628,    -1,    44,    41,    41,
    41,    41,    41,    41,    41,    41,    44,    44,    41,    41,
    41,    41,    41,    41,    41,    41,    41,    41,    -1,    -6,
   628,    -6,    -1,   628,    -1,   628,    44,   340,   385,   385,
    44,    41,    41,    41,    44,    44,    41,    44,    -1,    -1,
    -1,    -1,   628,    61,    -1,   628,    -1,    -2,    -1,   -30,
    -1,    -1,    -1,    93,    91,    44,    41,    41,    41,   340,
    46,    46,    -1,    -1,    -1,    -1,    44,    44,    44,    44,
    -1,    93,    44,    41,    41,    -1,   628,   499,   499,    44,
    44,    44,    -1,    -1,    -1,    -1,    61,    -1,    93,   628,
   628,    -1,    -1,    41,    41,   523,    -1,    44,    -1,    44,
    -1,    44,    -1 };
yytabelem yydef[]={

     1,    -2,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   533,   534,   430,     0,     0,   614,
   615,     0,     0,     0,     0,     0,     0,     0,    -2,     0,
     0,     0,     0,     0,   652,   653,   654,   655,   656,   657,
   658,   659,   660,   661,    -2,    -2,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,    -2,
    -2,    -2,     0,     0,     0,     0,     0,     0,     0,     0,
    37,     0,     0,     0,     0,     0,    43,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,    62,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,    87,     0,     0,     0,     0,     0,     0,
     0,    96,     0,     0,     0,     0,     0,     0,     0,     0,
   123,   124,   125,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   322,   324,     0,     0,
     0,     0,    19,     0,   510,   511,   512,   513,   514,   515,
   516,   517,   518,   444,   445,   446,   447,   448,   449,   450,
   451,   452,   328,   329,   330,   331,   332,   333,     0,     0,
     0,   431,     2,     3,     4,     5,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     6,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     7,     8,     9,    10,
    11,    12,    13,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   228,     0,     0,     0,     0,     0,     0,   432,
   440,   441,    29,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   611,    -2,   533,   534,     0,     0,     0,     0,     0,     0,
   613,    -2,     0,    39,    40,     0,     0,     0,    55,    56,
     0,   502,   503,   504,   505,   506,   507,    45,    46,    47,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   638,     0,     0,     0,     0,     0,   662,   663,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   677,   678,   679,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,    51,    52,    53,     0,
     0,   118,     0,     0,    59,   468,   469,    60,    61,    63,
    64,    65,    66,    67,    68,    69,   130,   143,   158,     0,
     0,     0,     0,     0,    83,    84,    85,    86,     0,     0,
     0,     0,     0,     0,     0,    97,    98,    99,   100,   101,
   102,   103,   104,   105,   106,   453,   454,   107,   248,   249,
   250,   251,   252,   253,   254,   255,   256,   257,   258,   259,
   260,   261,   262,   263,   264,   265,   266,   267,   268,   269,
   108,     0,     0,     0,     0,     0,     0,   122,   126,     0,
   128,   129,   145,   157,   132,   133,     0,     0,     0,     0,
     0,     0,   142,   146,   147,     0,     0,     0,     0,     0,
     0,   156,   160,   161,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   188,
     0,     0,     0,     0,   193,     0,     0,     0,     0,     0,
   325,   327,   433,   434,   199,     0,     0,     0,     0,     0,
     0,     0,     0,   514,     0,     0,     0,     0,     0,     0,
   221,     0,     0,     0,     0,     0,     0,   323,     0,     0,
     0,     0,   348,     0,     0,     0,     0,     0,     0,     0,
   292,   293,   294,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   435,   436,   437,   438,   439,     0,
     0,    21,    22,    23,    24,    25,    26,    27,    28,    17,
     0,     0,   334,   337,     0,     0,     0,     0,     0,     0,
   335,   336,    -2,   540,    -2,   544,    -2,   548,    -2,   552,
    -2,   555,   629,     0,    -2,    -2,    -2,    -2,    -2,    -2,
   692,   693,   539,    -2,   543,    -2,   547,    -2,   551,    -2,
    -2,   557,     0,   537,    -2,    -2,    -2,    -2,    -2,    -2,
   609,   610,     0,   525,   529,     0,   526,   530,     0,    72,
     0,     0,   535,     0,   623,   429,   644,   645,   646,   647,
   648,   649,   650,   651,   229,     0,   232,   233,   234,   270,
   271,   272,   273,   274,   275,   276,   277,   278,   279,   280,
   281,   235,     0,     0,     0,     0,     0,    30,   286,   287,
   288,   289,   290,   291,    31,    32,    33,     0,     0,   617,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   612,   695,    38,    41,
     0,    44,   282,   283,   284,   285,    57,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   694,     0,   696,     0,     0,
     0,   116,     0,     0,     0,    58,   131,   144,   159,    74,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   109,   110,     0,   113,     0,   115,   112,     0,     0,
     0,   135,   508,   509,   136,   137,   138,   139,   456,   455,
   457,     0,   149,   150,   151,   152,   153,     0,     0,     0,
   163,   164,   165,   166,   167,   168,     0,   170,   171,   172,
   173,     0,   175,     0,     0,     0,   179,   180,   181,   182,
     0,   184,   185,   186,   187,   189,   190,   191,   192,   194,
   195,   196,   197,     0,   326,   200,   201,   202,   203,   204,
   205,     0,     0,     0,     0,     0,   213,   214,     0,   216,
   217,   218,   219,     0,   222,   223,   224,   225,   226,     0,
   344,   349,   351,     0,     0,     0,     0,     0,     0,     0,
     0,   362,     0,     0,     0,     0,     0,     0,     0,     0,
   470,   471,   472,   345,   382,   384,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   346,   414,     0,
     0,     0,     0,     0,     0,     0,   347,   425,     0,     0,
     0,   241,   242,   243,   244,   245,   246,     0,   295,   296,
   297,   298,   473,   474,   475,   476,   477,   478,   479,   480,
   481,   482,   483,   484,   485,   486,   487,   488,   489,   490,
   491,   492,   493,   494,   495,   496,   497,   498,   299,     0,
     0,     0,     0,     0,     0,     0,     0,   308,   309,     0,
     0,   442,   443,   312,     0,     0,     0,     0,     0,     0,
   321,    14,    16,    18,    20,   338,   339,   340,   341,     0,
   343,     0,     0,   616,   618,    70,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   230,   231,     0,     0,
     0,   239,   240,     0,     0,     0,    -2,   559,   560,   632,
   561,   633,   562,   634,     0,     0,   564,   636,   565,   637,
   567,   639,   568,   640,   569,   641,   570,   642,     0,     0,
    95,   577,   664,   578,   665,     0,     0,    -2,   582,   668,
   583,   669,   584,   670,     0,     0,     0,     0,     0,     0,
     0,     0,   589,   675,   590,   676,     0,     0,   598,   681,
   599,   682,   600,   683,   601,   684,     0,     0,   535,     0,
   617,     0,    48,   625,   626,   627,   628,   630,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
    49,     0,     0,   119,   120,    36,    79,     0,    81,     0,
     0,     0,     0,     0,     0,     0,     0,   111,   114,     0,
     0,     0,   140,   141,     0,   154,   155,   162,   169,   174,
   176,   177,     0,     0,   198,   206,     0,     0,   209,   210,
   211,   212,   215,   220,   227,   350,   352,   354,     0,     0,
     0,     0,     0,   353,   355,     0,     0,     0,     0,     0,
   356,   357,   358,   359,   360,   361,   363,   364,   367,   368,
   377,   458,   459,   460,   461,   462,   378,   379,   380,     0,
   383,   385,   386,   387,   388,   389,   390,   391,   392,   393,
   394,   395,   396,   463,   464,   465,   397,   398,   399,   400,
   499,   500,   501,   401,     0,   402,     0,   407,   408,     0,
   410,   411,   412,     0,   415,   416,   417,   418,     0,   420,
     0,   422,   423,   424,   426,   427,   428,   247,   300,   301,
   302,   303,   304,   305,   306,   307,   310,   311,   313,   314,
   315,   316,   317,     0,     0,     0,    15,   342,   685,   602,
     0,     0,    75,    77,     0,   527,   531,   621,   624,   466,
   467,   522,     0,    73,     0,     0,   536,   236,     0,     0,
     0,    35,   524,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   616,   618,     0,     0,     0,     0,   631,
     0,     0,   667,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   117,     0,     0,     0,
     0,     0,   207,   208,   365,   369,   371,   373,   375,   366,
   370,   372,   374,   376,   381,   403,   404,   405,   406,   409,
   413,     0,   421,   318,   319,   320,   519,   520,   619,    71,
     0,     0,     0,     0,     0,   237,   238,     0,   563,   635,
   571,   573,   572,    -2,    -2,   580,     0,     0,   586,   672,
   587,   673,   588,   674,   594,   596,   595,    -2,     0,   536,
     0,     0,     0,     0,     0,    50,     0,   121,     0,     0,
     0,    89,    90,    91,     0,     0,    94,     0,     0,     0,
     0,     0,   419,     0,    76,    78,     0,   528,   532,   622,
     0,     0,     0,   619,     0,     0,   643,   666,   680,    54,
     0,     0,    88,     0,     0,     0,     0,     0,     0,     0,
   521,   620,     0,   585,   671,     0,    42,    80,    82,     0,
     0,     0,   134,   148,   178,   183,     0,    34,   620,     0,
     0,     0,   523,    92,    93,     0,     0,     0,     0,     0,
     0,     0,   127 };
typedef struct { char *t_name; int t_val; } yytoktype;
#ifndef YYDEBUG
#	define YYDEBUG	1	/* allow debugging */
#endif

#if YYDEBUG

yytoktype yytoks[] =
{
	"ABS",	257,
	"ACOS",	258,
	"ASIN",	259,
	"ATAN",	260,
	"ATAN2",	261,
	"CEIL",	262,
	"COS",	263,
	"DEG",	264,
	"DX",	265,
	"DY",	266,
	"ERF",	267,
	"ERFC",	268,
	"EXP",	269,
	"FLOOR",	270,
	"HYPOT",	271,
	"INDEX",	272,
	"INT",	273,
	"INVN",	274,
	"INVT",	275,
	"IRAND",	276,
	"LGAMMA",	277,
	"LN",	278,
	"LOG",	279,
	"LOGISTIC",	280,
	"MAXP",	281,
	"MINP",	282,
	"MOD",	283,
	"NORM",	284,
	"NORMP",	285,
	"PI",	286,
	"RAD",	287,
	"RAND",	288,
	"RNORM",	289,
	"SETNO",	290,
	"SIN",	291,
	"SQR",	292,
	"SQRT",	293,
	"TAN",	294,
	"INUM",	295,
	"VX1",	296,
	"VX2",	297,
	"VY1",	298,
	"VY2",	299,
	"WX1",	300,
	"WX2",	301,
	"WY1",	302,
	"WY2",	303,
	"DELAYP",	304,
	"DOUBLEBUFFER",	305,
	"DOWN",	306,
	"ABSOLUTE",	307,
	"ABORT",	308,
	"ACTIVATE",	309,
	"ACTIVE",	310,
	"ALT",	311,
	"ALTERNATE",	312,
	"ALTXAXIS",	313,
	"ALTYAXIS",	314,
	"ANGLE",	315,
	"ANNOTATE",	316,
	"APPEND",	317,
	"AREA",	318,
	"ARROW",	319,
	"AUTO",	320,
	"AUTOSCALE",	321,
	"AUTOTICKS",	322,
	"AVG",	323,
	"AXIS",	324,
	"AXES",	325,
	"BACKBUFFER",	326,
	"BACKGROUND",	327,
	"BAR",	328,
	"BATCH",	329,
	"BLOCK",	330,
	"BIN",	331,
	"BOTH",	332,
	"BOTTOM",	333,
	"BOX",	334,
	"BOXPLOT",	335,
	"CD",	336,
	"CELLS",	337,
	"CENTER",	338,
	"CHAR",	339,
	"CHRSTR",	340,
	"CLEAR",	341,
	"CLICK",	342,
	"CMAP",	343,
	"COLOR",	344,
	"COMMENT",	345,
	"COPY",	346,
	"CYCLE",	347,
	"DECIMAL",	348,
	"DEF",	349,
	"DEFAULT",	350,
	"DELETE",	351,
	"DEVICE",	352,
	"DFT",	353,
	"DIFFERENCE",	354,
	"DISK",	355,
	"DRAW2",	356,
	"DROP",	357,
	"DXDX",	358,
	"DXP",	359,
	"DYDY",	360,
	"DYP",	361,
	"ECHO",	362,
	"EDIT",	363,
	"ELSE",	364,
	"END",	365,
	"ERRORBAR",	366,
	"EXIT",	367,
	"EXPONENTIAL",	368,
	"FALSEP",	369,
	"FFT",	370,
	"FILEP",	371,
	"FILL",	372,
	"FIND",	373,
	"FIXEDPOINT",	374,
	"FLUSH",	375,
	"FOCUS",	376,
	"FOLLOWS",	377,
	"FONTP",	378,
	"FOREGROUND",	379,
	"FORMAT",	380,
	"FRONTBUFFER",	381,
	"FRAMEP",	382,
	"GETP",	383,
	"GRAPH",	384,
	"GRAPHNO",	385,
	"GRAPHS",	386,
	"GRAPHTYPE",	387,
	"GRID",	388,
	"HARDCOPY",	389,
	"HBAR",	390,
	"HBOXPLOT",	391,
	"HGAP",	392,
	"HIDDEN",	393,
	"HORIZONTAL",	394,
	"HPGLL",	395,
	"HPGLP",	396,
	"HISTO",	397,
	"IF",	398,
	"IGNORE",	399,
	"IHL",	400,
	"IMAGE",	401,
	"IN",	402,
	"INIT",	403,
	"INITGRAPHICS",	404,
	"INOUT",	405,
	"INTEGRATE",	406,
	"INTERP",	407,
	"INVDFT",	408,
	"INVFFT",	409,
	"JUST",	410,
	"KILL",	411,
	"LABEL",	412,
	"LAYOUT",	413,
	"LEAVE",	414,
	"LEAVEGRAPHICS",	415,
	"LEFT",	416,
	"LEGEND",	417,
	"LENGTH",	418,
	"LEVEL",	419,
	"LEVELS",	420,
	"LINE",	421,
	"LINESTYLE",	422,
	"LINETO",	423,
	"LINEWIDTH",	424,
	"LINK",	425,
	"LOAD",	426,
	"LOCATOR",	427,
	"LOCTYPE",	428,
	"LOGX",	429,
	"LOGY",	430,
	"LOGXY",	431,
	"MAJOR",	432,
	"MIFL",	433,
	"MIFP",	434,
	"MINOR",	435,
	"MISSINGP",	436,
	"MOVE",	437,
	"MOVE2",	438,
	"MOVETO",	439,
	"NEGATE",	440,
	"NO",	441,
	"NONE",	442,
	"NORMAL",	443,
	"NXY",	444,
	"OFF",	445,
	"OFFSETX",	446,
	"OFFSETY",	447,
	"ON",	448,
	"OP",	449,
	"ORIENT",	450,
	"OUT",	451,
	"PAGE",	452,
	"PARA",	453,
	"PARALLEL",	454,
	"PARAMETERS",	455,
	"PARAMS",	456,
	"PATTERN",	457,
	"PERIMETER",	458,
	"PERP",	459,
	"PERPENDICULAR",	460,
	"PIE",	461,
	"PIPE",	462,
	"PLACE",	463,
	"POINT",	464,
	"POLAR",	465,
	"POWER",	466,
	"PREC",	467,
	"PREPEND",	468,
	"PRINT",	469,
	"PS",	470,
	"PSCOLORP",	471,
	"PSMONOP",	472,
	"PSCOLORL",	473,
	"PSMONOL",	474,
	"PUSH",	475,
	"POP",	476,
	"PUTP",	477,
	"RAWSPICE",	478,
	"READ",	479,
	"REDRAW",	480,
	"REGRESS",	481,
	"REGNUM",	482,
	"REGIONS",	483,
	"RENDER",	484,
	"REVERSE",	485,
	"RIGHT",	486,
	"RISER",	487,
	"ROT",	488,
	"RUNAVG",	489,
	"RUNMED",	490,
	"RUNSTD",	491,
	"RUNMIN",	492,
	"RUNMAX",	493,
	"SAMPLE",	494,
	"SAVEALL",	495,
	"SCALE",	496,
	"SCIENTIFIC",	497,
	"SET",	498,
	"SETNUM",	499,
	"SETS",	500,
	"SIGN",	501,
	"SIZE",	502,
	"SKIP",	503,
	"SLEEP",	504,
	"SLICE",	505,
	"SOURCE",	506,
	"SPEC",	507,
	"SPECIFIED",	508,
	"SPECTRUM",	509,
	"STACK",	510,
	"STACKEDBAR",	511,
	"STACKEDHBAR",	512,
	"STACKEDLINE",	513,
	"STAGGER",	514,
	"START",	515,
	"STARTTYPE",	516,
	"STATUS",	517,
	"STOP",	518,
	"STRING",	519,
	"SUBTITLE",	520,
	"SWAPBUFFER",	521,
	"SYMBOL",	522,
	"TICKP",	523,
	"TICKLABEL",	524,
	"TICKMARKS",	525,
	"TITLE",	526,
	"TO",	527,
	"TOP",	528,
	"TRUEP",	529,
	"TYPE",	530,
	"UP",	531,
	"VELOCITY",	532,
	"VERTICAL",	533,
	"VGAP",	534,
	"VIEW",	535,
	"WITH",	536,
	"WORLD",	537,
	"WRITE",	538,
	"X",	539,
	"X0",	540,
	"X1",	541,
	"XAXES",	542,
	"XAXIS",	543,
	"XCOR",	544,
	"XMAX",	545,
	"XMIN",	546,
	"XY",	547,
	"XYARC",	548,
	"XYBOX",	549,
	"XYBOXPLOT",	550,
	"XYFIXED",	551,
	"XYHILO",	552,
	"XYRT",	553,
	"XYSEG",	554,
	"XYSTRING",	555,
	"XYDX",	556,
	"XYDY",	557,
	"XYDXDX",	558,
	"XYDYDY",	559,
	"XYDXDY",	560,
	"XYX2Y2",	561,
	"XYXX",	562,
	"XYYY",	563,
	"XYZ",	564,
	"XYZW",	565,
	"XYUV",	566,
	"Y",	567,
	"Y0",	568,
	"Y1",	569,
	"Y2",	570,
	"Y3",	571,
	"Y4",	572,
	"Y5",	573,
	"YAXES",	574,
	"YAXIS",	575,
	"YES",	576,
	"YMAX",	577,
	"YMIN",	578,
	"ZEROXAXIS",	579,
	"ZEROYAXIS",	580,
	"ABOVE",	581,
	"BELOW",	582,
	"POLYI",	583,
	"POLYO",	584,
	"GENERAL",	585,
	"DDMMYY",	586,
	"MMDDYY",	587,
	"MMYY",	588,
	"MMDD",	589,
	"MONTHDAY",	590,
	"DAYMONTH",	591,
	"MONTHS",	592,
	"MONTHL",	593,
	"DAYOFWEEKS",	594,
	"DAYOFWEEKL",	595,
	"DAYOFYEAR",	596,
	"HMS",	597,
	"MMDDHMS",	598,
	"MMDDYYHMS",	599,
	"DEGREESLON",	600,
	"DEGREESMMLON",	601,
	"DEGREESMMSSLON",	602,
	"MMSSLON",	603,
	"DEGREESLAT",	604,
	"DEGREESMMLAT",	605,
	"DEGREESMMSSLAT",	606,
	"MMSSLAT",	607,
	"DOT",	608,
	"STAR",	609,
	"PLUS",	610,
	"CROSS",	611,
	"CIRCLE",	612,
	"SQUARE",	613,
	"DIAMOND",	614,
	"TRIANGLE1",	615,
	"TRIANGLE2",	616,
	"TRIANGLE3",	617,
	"TRIANGLE4",	618,
	"SPLINE",	619,
	"LANDSCAPE",	620,
	"PORTRAIT",	621,
	"FREE",	622,
	"FIXED",	623,
	"STATUSBAR",	624,
	"LOCATORBAR",	625,
	"TOOLBAR",	626,
	"VAR",	627,
	"NUMBER",	628,
	"FITPARM",	629,
	"=",	61,
	"OR",	630,
	"AND",	631,
	"GT",	632,
	"LT",	633,
	"LE",	634,
	"GE",	635,
	"EQ",	636,
	"NE",	637,
	"+",	43,
	"-",	45,
	"*",	42,
	"/",	47,
	"%",	37,
	"^",	94,
	"UMINUS",	638,
	"NOT",	639,
	"-unknown-",	-1	/* ends search */
};

char * yyreds[] =
{
	"-no such reduction-",
      "list : /* empty */",
      "list : asgn '\n'",
      "list : vasgn '\n'",
      "list : rasgn '\n'",
      "list : expr '\n'",
      "list : vexpr '\n'",
      "list : parmset '\n'",
      "list : regionset '\n'",
      "list : setaxis '\n'",
      "list : setvelocity '\n'",
      "list : set_setprop '\n'",
      "list : setprint '\n'",
      "list : error '\n'",
      "setprint : PRINT printer CHRSTR",
      "setprint : PRINT TO printer CHRSTR",
      "setprint : PRINT TO printer",
      "setprint : DEVICE NUMBER",
      "setprint : HARDCOPY DEVICE NUMBER",
      "setprint : HARDCOPY",
      "setprint : PS LINEWIDTH NUMBER",
      "printer : PSMONOP",
      "printer : PSMONOL",
      "printer : MIFP",
      "printer : MIFL",
      "printer : HPGLP",
      "printer : HPGLL",
      "printer : HARDCOPY",
      "printer : FILEP",
      "regionset : REGNUM onoff",
      "regionset : REGNUM TYPE regiontype",
      "regionset : REGNUM COLOR NUMBER",
      "regionset : REGNUM LINESTYLE NUMBER",
      "regionset : REGNUM LINEWIDTH NUMBER",
      "regionset : REGNUM LINE expr ',' expr ',' expr ',' expr",
      "regionset : REGNUM XY expr ',' expr",
      "regionset : LINK REGNUM TO GRAPHNO",
      "parmset : REDRAW",
      "parmset : AUTO REDRAW onoff",
      "parmset : CD CHRSTR",
      "parmset : ECHO CHRSTR",
      "parmset : BACKGROUND COLOR NUMBER",
      "parmset : CMAP NUMBER ',' NUMBER ',' NUMBER ',' NUMBER",
      "parmset : EXIT",
      "parmset : PAGE LAYOUT pagelayout",
      "parmset : STATUSBAR onoff",
      "parmset : TOOLBAR onoff",
      "parmset : LOCATORBAR onoff",
      "parmset : DRAW2 expr ',' expr",
      "parmset : MOVE2 expr ',' expr",
      "parmset : SYMBOL expr ',' expr ',' NUMBER",
      "parmset : COLOR NUMBER",
      "parmset : LINEWIDTH NUMBER",
      "parmset : LINESTYLE NUMBER",
      "parmset : WRITE STRING expr ',' expr ',' CHRSTR",
      "parmset : PAGE direction",
      "parmset : PAGE NUMBER",
      "parmset : PAGE INOUT NUMBER",
      "parmset : LINK PAGE onoff",
      "parmset : DOUBLEBUFFER torf",
      "parmset : FRONTBUFFER torf",
      "parmset : BACKBUFFER torf",
      "parmset : SWAPBUFFER",
      "parmset : SLEEP NUMBER",
      "parmset : DELAYP NUMBER",
      "parmset : ABORT torf",
      "parmset : GETP CHRSTR",
      "parmset : PUTP CHRSTR",
      "parmset : WITH GRAPHNO",
      "parmset : WITH SETNUM",
      "parmset : SETNUM LINK sourcetype CHRSTR",
      "parmset : GRAPHNO '.' SETNUM LINK sourcetype CHRSTR",
      "parmset : SETNUM LINK onoff",
      "parmset : GRAPHNO '.' SETNUM LINK onoff",
      "parmset : ACTIVATE SETNUM NUMBER",
      "parmset : SETNUM POINT expr ',' expr",
      "parmset : GRAPHNO '.' SETNUM POINT expr ',' expr",
      "parmset : SETNUM DROP NUMBER ',' NUMBER",
      "parmset : GRAPHNO '.' SETNUM DROP NUMBER ',' NUMBER",
      "parmset : COPY SETNUM TO SETNUM",
      "parmset : COPY GRAPHNO '.' SETNUM TO GRAPHNO '.' SETNUM",
      "parmset : MOVE SETNUM TO SETNUM",
      "parmset : MOVE GRAPHNO '.' SETNUM TO GRAPHNO '.' SETNUM",
      "parmset : KILL SETNUM",
      "parmset : KILL SETS",
      "parmset : KILL GRAPHNO",
      "parmset : KILL GRAPHS",
      "parmset : FLUSH",
      "parmset : LOAD VAR NUMBER ',' expr ',' expr",
      "parmset : REGRESS '(' SETNUM ',' NUMBER ')'",
      "parmset : runtype '(' SETNUM ',' NUMBER ')'",
      "parmset : ffttype '(' SETNUM ',' NUMBER ')'",
      "parmset : SPLINE '(' SETNUM ',' expr ',' expr ',' NUMBER ')'",
      "parmset : HISTO '(' SETNUM ',' expr ',' expr ',' NUMBER ')'",
      "parmset : DIFFERENCE '(' SETNUM ',' NUMBER ')'",
      "parmset : INT '(' SETNUM ')'",
      "parmset : AUTOSCALE",
      "parmset : AUTOSCALE XAXES",
      "parmset : AUTOSCALE YAXES",
      "parmset : AUTOSCALE SETNUM",
      "parmset : LOCATOR onoff",
      "parmset : FOCUS GRAPHNO",
      "parmset : FOCUS onoff",
      "parmset : FOCUS SET",
      "parmset : FOCUS FOLLOWS",
      "parmset : FOCUS CLICK",
      "parmset : SOURCE sourcetype",
      "parmset : TYPE xytype",
      "parmset : READ CHRSTR",
      "parmset : READ BATCH CHRSTR",
      "parmset : READ BLOCK CHRSTR",
      "parmset : READ BLOCK sourcetype CHRSTR",
      "parmset : BLOCK xytype CHRSTR",
      "parmset : READ xytype CHRSTR",
      "parmset : READ xytype sourcetype CHRSTR",
      "parmset : READ IMAGE CHRSTR",
      "parmset : WRITE IMAGE CHRSTR",
      "parmset : IMAGE XY NUMBER ',' NUMBER",
      "parmset : WRITE SETNUM",
      "parmset : WRITE SETNUM FORMAT CHRSTR",
      "parmset : WRITE SETNUM FILEP CHRSTR",
      "parmset : WRITE SETNUM FILEP CHRSTR FORMAT CHRSTR",
      "parmset : SAVEALL CHRSTR",
      "parmset : PUSH",
      "parmset : POP",
      "parmset : CYCLE",
      "parmset : STACK NUMBER",
      "parmset : STACK WORLD expr ',' expr ',' expr ',' expr TICKP expr ',' expr ',' expr ',' expr",
      "parmset : CLEAR STACK",
      "parmset : CLEAR BOX",
      "parmset : WITH BOX",
      "parmset : WITH BOX NUMBER",
      "parmset : BOX onoff",
      "parmset : BOX GRAPHNO",
      "parmset : BOX expr ',' expr ',' expr ',' expr",
      "parmset : BOX LOCTYPE worldview",
      "parmset : BOX LINESTYLE NUMBER",
      "parmset : BOX LINEWIDTH NUMBER",
      "parmset : BOX COLOR NUMBER",
      "parmset : BOX FILL filltype",
      "parmset : BOX FILL COLOR NUMBER",
      "parmset : BOX FILL PATTERN NUMBER",
      "parmset : BOX DEF",
      "parmset : WITH LINE",
      "parmset : WITH LINE NUMBER",
      "parmset : CLEAR LINE",
      "parmset : LINE onoff",
      "parmset : LINE GRAPHNO",
      "parmset : LINE expr ',' expr ',' expr ',' expr",
      "parmset : LINE LOCTYPE worldview",
      "parmset : LINE LINEWIDTH NUMBER",
      "parmset : LINE LINESTYLE NUMBER",
      "parmset : LINE COLOR NUMBER",
      "parmset : LINE ARROW NUMBER",
      "parmset : LINE ARROW SIZE NUMBER",
      "parmset : LINE ARROW TYPE NUMBER",
      "parmset : LINE DEF",
      "parmset : CLEAR STRING",
      "parmset : WITH STRING",
      "parmset : WITH STRING NUMBER",
      "parmset : STRING onoff",
      "parmset : STRING GRAPHNO",
      "parmset : STRING expr ',' expr",
      "parmset : STRING LOCTYPE worldview",
      "parmset : STRING LINEWIDTH NUMBER",
      "parmset : STRING COLOR NUMBER",
      "parmset : STRING ROT NUMBER",
      "parmset : STRING FONTP NUMBER",
      "parmset : STRING JUST NUMBER",
      "parmset : STRING CHAR SIZE NUMBER",
      "parmset : STRING DEF CHRSTR",
      "parmset : DEFAULT LINESTYLE NUMBER",
      "parmset : DEFAULT LINEWIDTH NUMBER",
      "parmset : DEFAULT COLOR NUMBER",
      "parmset : DEFAULT CHAR SIZE NUMBER",
      "parmset : DEFAULT FONTP NUMBER",
      "parmset : DEFAULT FONTP SOURCE NUMBER",
      "parmset : DEFAULT SYMBOL SIZE NUMBER",
      "parmset : WORLD expr ',' expr ',' expr ',' expr",
      "parmset : WORLD XMIN expr",
      "parmset : WORLD XMAX expr",
      "parmset : WORLD YMIN expr",
      "parmset : WORLD YMAX expr",
      "parmset : VIEW expr ',' expr ',' expr ',' expr",
      "parmset : VIEW XMIN NUMBER",
      "parmset : VIEW XMAX NUMBER",
      "parmset : VIEW YMIN NUMBER",
      "parmset : VIEW YMAX NUMBER",
      "parmset : TITLE CHRSTR",
      "parmset : TITLE FONTP NUMBER",
      "parmset : TITLE SIZE NUMBER",
      "parmset : TITLE COLOR NUMBER",
      "parmset : TITLE LINEWIDTH NUMBER",
      "parmset : SUBTITLE CHRSTR",
      "parmset : SUBTITLE FONTP NUMBER",
      "parmset : SUBTITLE SIZE NUMBER",
      "parmset : SUBTITLE COLOR NUMBER",
      "parmset : SUBTITLE LINEWIDTH NUMBER",
      "parmset : GRAPHS MAXP SETS NUMBER",
      "parmset : LEGEND onoff",
      "parmset : LEGEND LOCTYPE worldview",
      "parmset : LEGEND LAYOUT NUMBER",
      "parmset : LEGEND VGAP NUMBER",
      "parmset : LEGEND HGAP NUMBER",
      "parmset : LEGEND LENGTH NUMBER",
      "parmset : LEGEND BOX onoff",
      "parmset : LEGEND BOX FILL onoff",
      "parmset : LEGEND BOX FILL WITH colpat",
      "parmset : LEGEND BOX FILL colpat NUMBER",
      "parmset : LEGEND BOX COLOR NUMBER",
      "parmset : LEGEND BOX LINESTYLE NUMBER",
      "parmset : LEGEND BOX LINEWIDTH NUMBER",
      "parmset : LEGEND expr ',' expr",
      "parmset : LEGEND X1 expr",
      "parmset : LEGEND Y1 expr",
      "parmset : LEGEND CHAR SIZE NUMBER",
      "parmset : LEGEND FONTP NUMBER",
      "parmset : LEGEND LINESTYLE NUMBER",
      "parmset : LEGEND LINEWIDTH NUMBER",
      "parmset : LEGEND COLOR NUMBER",
      "parmset : LEGEND STRING NUMBER CHRSTR",
      "parmset : FRAMEP onoff",
      "parmset : FRAMEP TYPE NUMBER",
      "parmset : FRAMEP LINESTYLE NUMBER",
      "parmset : FRAMEP LINEWIDTH NUMBER",
      "parmset : FRAMEP COLOR NUMBER",
      "parmset : FRAMEP FILL onoff",
      "parmset : FRAMEP BACKGROUND COLOR NUMBER",
      "parmset : GRAPHNO onoff",
      "parmset : GRAPHNO LABEL onoff",
      "parmset : GRAPHNO AUTOSCALE TYPE AUTO",
      "parmset : GRAPHNO AUTOSCALE TYPE SPEC",
      "parmset : GRAPHNO AUTOSCALE torf",
      "parmset : GRAPHNO HIDDEN torf",
      "parmset : GRAPHNO TYPE graphtype",
      "parmset : GRAPHNO FIXEDPOINT onoff",
      "parmset : GRAPHNO FIXEDPOINT FORMAT formatchoice formatchoice",
      "parmset : GRAPHNO FIXEDPOINT PREC NUMBER ',' NUMBER",
      "parmset : GRAPHNO FIXEDPOINT XY expr ',' expr",
      "parmset : GRAPHNO FIXEDPOINT TYPE NUMBER",
      "parmset : GRAPHNO MAXP SETS NUMBER",
      "setvelocity : VELOCITY SCALE NUMBER",
      "setvelocity : VELOCITY LEGEND onoff",
      "setvelocity : VELOCITY LINEWIDTH NUMBER",
      "setvelocity : VELOCITY LINESTYLE NUMBER",
      "setvelocity : VELOCITY COLOR NUMBER",
      "setvelocity : VELOCITY LOCTYPE worldview",
      "setvelocity : VELOCITY ARROW TYPE NUMBER",
      "xytype : XY",
      "xytype : XYARC",
      "xytype : XYBOX",
      "xytype : XYBOXPLOT",
      "xytype : XYHILO",
      "xytype : XYRT",
      "xytype : XYSEG",
      "xytype : XYSTRING",
      "xytype : XYDX",
      "xytype : XYDY",
      "xytype : XYDXDX",
      "xytype : XYDYDY",
      "xytype : XYDXDY",
      "xytype : XYX2Y2",
      "xytype : XYXX",
      "xytype : XYYY",
      "xytype : XYZ",
      "xytype : XYZW",
      "xytype : XYUV",
      "xytype : NXY",
      "xytype : BIN",
      "xytype : RAWSPICE",
      "graphtype : XY",
      "graphtype : LOGX",
      "graphtype : LOGY",
      "graphtype : LOGXY",
      "graphtype : BAR",
      "graphtype : HBAR",
      "graphtype : STACKEDBAR",
      "graphtype : STACKEDHBAR",
      "graphtype : POLAR",
      "graphtype : XYFIXED",
      "graphtype : BOXPLOT",
      "graphtype : HBOXPLOT",
      "pagelayout : FREE",
      "pagelayout : LANDSCAPE",
      "pagelayout : PORTRAIT",
      "pagelayout : FIXED",
      "regiontype : ABOVE",
      "regiontype : BELOW",
      "regiontype : LEFT",
      "regiontype : RIGHT",
      "regiontype : POLYI",
      "regiontype : POLYO",
      "set_setprop : selectsets setprop",
      "setprop : onoff",
      "setprop : IGNORE",
      "setprop : TYPE xytype",
      "setprop : MISSINGP expr",
      "setprop : PREC NUMBER",
      "setprop : FORMAT formatchoice",
      "setprop : SYMBOL expr",
      "setprop : SYMBOL FILL NUMBER",
      "setprop : SYMBOL CENTER torf",
      "setprop : SYMBOL SIZE expr",
      "setprop : SYMBOL CHAR NUMBER",
      "setprop : SYMBOL SKIP NUMBER",
      "setprop : SYMBOL COLOR expr",
      "setprop : SYMBOL LINEWIDTH NUMBER",
      "setprop : SYMBOL LINESTYLE NUMBER",
      "setprop : prop NUMBER",
      "setprop : FILL NUMBER",
      "setprop : FILL WITH colpat",
      "setprop : FILL colpat NUMBER",
      "setprop : SKIP NUMBER",
      "setprop : ERRORBAR LENGTH NUMBER",
      "setprop : ERRORBAR TYPE opchoice",
      "setprop : ERRORBAR LINEWIDTH NUMBER",
      "setprop : ERRORBAR LINESTYLE NUMBER",
      "setprop : ERRORBAR RISER onoff",
      "setprop : ERRORBAR RISER LINEWIDTH NUMBER",
      "setprop : ERRORBAR RISER LINESTYLE NUMBER",
      "setprop : XYZ expr ',' expr",
      "setprop : COMMENT CHRSTR",
      "setaxis : axis",
      "setaxis : axis axisfeature",
      "setaxis : allaxes",
      "setaxis : GRAPHS axis",
      "setaxis : GRAPHS axis axisfeature",
      "setaxis : GRAPHS allaxes",
      "axis : XAXIS",
      "axis : YAXIS",
      "axis : ALTXAXIS",
      "axis : ALTYAXIS",
      "axis : ZEROXAXIS",
      "axis : ZEROYAXIS",
      "allaxes : AXES axesprops",
      "allaxes : XAXES axesprops",
      "allaxes : YAXES axesprops",
      "axesprops : onoff",
      "axesprops : COLOR NUMBER",
      "axesprops : LINEWIDTH NUMBER",
      "axesprops : LINESTYLE NUMBER",
      "axesprops : FONTP NUMBER",
      "axesprops : CHAR SIZE NUMBER",
      "axesprops : GRID onoff",
      "axisfeature : TICKP tickdesc",
      "axisfeature : TICKLABEL ticklabeldesc",
      "axisfeature : LABEL axislabeldesc",
      "axisfeature : BAR axisbardesc",
      "axisfeature : onoff",
      "tickdesc : tickattr",
      "tickdesc : tickdesc tickattr",
      "tickattr : onoff",
      "tickattr : MAJOR onoff",
      "tickattr : MINOR onoff",
      "tickattr : MAJOR expr",
      "tickattr : MINOR expr",
      "tickattr : OFFSETX expr",
      "tickattr : OFFSETY expr",
      "tickattr : ALT onoff",
      "tickattr : MINP expr",
      "tickattr : MAXP expr",
      "tickattr : DEFAULT NUMBER",
      "tickattr : inoutchoice",
      "tickattr : LOG onoff",
      "tickattr : SIZE NUMBER",
      "tickattr : MAJOR SIZE NUMBER",
      "tickattr : MINOR SIZE NUMBER",
      "tickattr : COLOR NUMBER",
      "tickattr : LINEWIDTH NUMBER",
      "tickattr : MAJOR COLOR NUMBER",
      "tickattr : MINOR COLOR NUMBER",
      "tickattr : MAJOR LINEWIDTH NUMBER",
      "tickattr : MINOR LINEWIDTH NUMBER",
      "tickattr : MAJOR LINESTYLE NUMBER",
      "tickattr : MINOR LINESTYLE NUMBER",
      "tickattr : MAJOR GRID onoff",
      "tickattr : MINOR GRID onoff",
      "tickattr : OP opchoice",
      "tickattr : TYPE AUTO",
      "tickattr : TYPE SPEC",
      "tickattr : SPEC NUMBER",
      "tickattr : NUMBER ',' expr",
      "ticklabeldesc : ticklabelattr",
      "ticklabeldesc : ticklabeldesc ticklabelattr",
      "ticklabelattr : onoff",
      "ticklabelattr : TYPE AUTO",
      "ticklabelattr : TYPE SPEC",
      "ticklabelattr : PREC NUMBER",
      "ticklabelattr : FORMAT formatchoice",
      "ticklabelattr : FORMAT NUMBER",
      "ticklabelattr : APPEND CHRSTR",
      "ticklabelattr : PREPEND CHRSTR",
      "ticklabelattr : LAYOUT HORIZONTAL",
      "ticklabelattr : LAYOUT VERTICAL",
      "ticklabelattr : LAYOUT SPEC",
      "ticklabelattr : ANGLE NUMBER",
      "ticklabelattr : JUST justchoice",
      "ticklabelattr : SKIP NUMBER",
      "ticklabelattr : STAGGER NUMBER",
      "ticklabelattr : OP opchoice",
      "ticklabelattr : SIGN signchoice",
      "ticklabelattr : START expr",
      "ticklabelattr : STOP expr",
      "ticklabelattr : START TYPE SPEC",
      "ticklabelattr : START TYPE AUTO",
      "ticklabelattr : STOP TYPE SPEC",
      "ticklabelattr : STOP TYPE AUTO",
      "ticklabelattr : VGAP NUMBER",
      "ticklabelattr : HGAP NUMBER",
      "ticklabelattr : CHAR SIZE NUMBER",
      "ticklabelattr : FONTP NUMBER",
      "ticklabelattr : COLOR NUMBER",
      "ticklabelattr : LINEWIDTH NUMBER",
      "ticklabelattr : NUMBER ',' CHRSTR",
      "axislabeldesc : CHRSTR",
      "axislabeldesc : LAYOUT PERP",
      "axislabeldesc : LAYOUT PARA",
      "axislabeldesc : PLACE AUTO",
      "axislabeldesc : PLACE SPEC",
      "axislabeldesc : PLACE NUMBER ',' NUMBER",
      "axislabeldesc : JUST justchoice",
      "axislabeldesc : CHAR SIZE NUMBER",
      "axislabeldesc : FONTP NUMBER",
      "axislabeldesc : COLOR NUMBER",
      "axislabeldesc : LINEWIDTH NUMBER",
      "axisbardesc : onoff",
      "axisbardesc : COLOR NUMBER",
      "axisbardesc : LINESTYLE NUMBER",
      "axisbardesc : LINEWIDTH NUMBER",
      "selectsets : GRAPHNO '.' SETNUM",
      "selectsets : SETNUM",
      "selectsets : SETS",
      "selectsets : GRAPHNO SETS",
      "selectsets : GRAPHS SETS",
      "selectsets : GRAPHS SETNUM",
      "prop : LINESTYLE",
      "prop : LINEWIDTH",
      "prop : FONTP",
      "prop : COLOR",
      "prop : SIZE",
      "onoff : ON",
      "onoff : OFF",
      "colpat : COLOR",
      "colpat : PATTERN",
      "runtype : RUNAVG",
      "runtype : RUNSTD",
      "runtype : RUNMED",
      "runtype : RUNMAX",
      "runtype : RUNMIN",
      "ffttype : DFT",
      "ffttype : FFT",
      "ffttype : INVDFT",
      "ffttype : INVFFT",
      "sourcetype : DISK",
      "sourcetype : PIPE",
      "filltype : PATTERN",
      "filltype : COLOR",
      "filltype : NONE",
      "opchoice : TOP",
      "opchoice : BOTTOM",
      "opchoice : LEFT",
      "opchoice : RIGHT",
      "opchoice : BOTH",
      "justchoice : RIGHT",
      "justchoice : LEFT",
      "justchoice : CENTER",
      "extremetype : MINP",
      "extremetype : MAXP",
      "torf : TRUEP",
      "torf : FALSEP",
      "inoutchoice : IN",
      "inoutchoice : OUT",
      "inoutchoice : BOTH",
      "formatchoice : DECIMAL",
      "formatchoice : EXPONENTIAL",
      "formatchoice : POWER",
      "formatchoice : GENERAL",
      "formatchoice : DDMMYY",
      "formatchoice : MMDDYY",
      "formatchoice : MMYY",
      "formatchoice : MMDD",
      "formatchoice : MONTHDAY",
      "formatchoice : DAYMONTH",
      "formatchoice : MONTHS",
      "formatchoice : MONTHL",
      "formatchoice : DAYOFWEEKS",
      "formatchoice : DAYOFWEEKL",
      "formatchoice : DAYOFYEAR",
      "formatchoice : HMS",
      "formatchoice : MMDDHMS",
      "formatchoice : MMDDYYHMS",
      "formatchoice : DEGREESLON",
      "formatchoice : DEGREESMMLON",
      "formatchoice : DEGREESMMSSLON",
      "formatchoice : MMSSLON",
      "formatchoice : DEGREESLAT",
      "formatchoice : DEGREESMMLAT",
      "formatchoice : DEGREESMMSSLAT",
      "formatchoice : MMSSLAT",
      "signchoice : NORMAL",
      "signchoice : ABSOLUTE",
      "signchoice : NEGATE",
      "direction : UP",
      "direction : DOWN",
      "direction : RIGHT",
      "direction : LEFT",
      "direction : IN",
      "direction : OUT",
      "worldview : WORLD",
      "worldview : VIEW",
      "vector : X",
      "vector : Y",
      "vector : X0",
      "vector : Y0",
      "vector : Y1",
      "vector : Y2",
      "vector : Y3",
      "vector : Y4",
      "vector : Y5",
      "asgn : VAR '[' expr ']' '=' expr",
      "asgn : vector '[' expr ']' '=' expr",
      "asgn : SETNUM '.' vector '[' expr ']' '=' expr",
      "asgn : SETNUM '.' SYMBOL '=' expr",
      "asgn : GRAPHNO '.' SETNUM '.' vector '[' expr ']' '=' expr",
      "rasgn : REGNUM '.' vector '=' expr",
      "vasgn : VAR '=' vexpr",
      "vasgn : vector '=' vexpr",
      "vasgn : SETNUM '.' vector '=' vexpr",
      "vasgn : GRAPHNO '.' SETNUM '.' vector '=' vexpr",
      "vasgn : VAR '=' expr",
      "vasgn : vector '=' expr",
      "vasgn : SETNUM '.' vector '=' expr",
      "vasgn : GRAPHNO '.' SETNUM '.' vector '=' expr",
      "vexpr : VAR",
      "vexpr : vector",
      "vexpr : SETNUM '.' vector",
      "vexpr : GRAPHNO '.' SETNUM '.' vector",
      "vexpr : expr",
      "vexpr : expr '+' expr",
      "vexpr : vexpr '+' vexpr",
      "vexpr : expr '+' vexpr",
      "vexpr : vexpr '+' expr",
      "vexpr : expr '-' expr",
      "vexpr : vexpr '-' vexpr",
      "vexpr : expr '-' vexpr",
      "vexpr : vexpr '-' expr",
      "vexpr : expr '*' expr",
      "vexpr : vexpr '*' vexpr",
      "vexpr : expr '*' vexpr",
      "vexpr : vexpr '*' expr",
      "vexpr : expr '/' expr",
      "vexpr : vexpr '/' vexpr",
      "vexpr : expr '/' vexpr",
      "vexpr : vexpr '/' expr",
      "vexpr : expr '^' expr",
      "vexpr : expr '^' vexpr",
      "vexpr : vexpr '^' expr",
      "vexpr : vexpr '^' vexpr",
      "vexpr : ABS '(' expr ')'",
      "vexpr : ABS '(' vexpr ')'",
      "vexpr : ACOS '(' vexpr ')'",
      "vexpr : ASIN '(' vexpr ')'",
      "vexpr : ATAN '(' vexpr ')'",
      "vexpr : ATAN2 '(' vexpr ',' vexpr ')'",
      "vexpr : CEIL '(' vexpr ')'",
      "vexpr : COS '(' vexpr ')'",
      "vexpr : DEG",
      "vexpr : ERF '(' vexpr ')'",
      "vexpr : ERFC '(' vexpr ')'",
      "vexpr : EXP '(' vexpr ')'",
      "vexpr : FLOOR '(' vexpr ')'",
      "vexpr : HYPOT '(' vexpr ',' vexpr ')'",
      "vexpr : HYPOT '(' expr ',' vexpr ')'",
      "vexpr : HYPOT '(' vexpr ',' expr ')'",
      "vexpr : HYPOT '(' expr ',' expr ')'",
      "vexpr : INDEX",
      "vexpr : SETNO",
      "vexpr : INT '(' vexpr ')'",
      "vexpr : INVN '(' vexpr ')'",
      "vexpr : INVT '(' expr ',' NUMBER ')'",
      "vexpr : INVT '(' vexpr ',' NUMBER ')'",
      "vexpr : IRAND '(' NUMBER ')'",
      "vexpr : LGAMMA '(' vexpr ')'",
      "vexpr : LN '(' vexpr ')'",
      "vexpr : LOG '(' vexpr ')'",
      "vexpr : LOGISTIC '(' vexpr ',' expr ',' expr ')'",
      "vexpr : MAXP '(' vexpr ',' vexpr ')'",
      "vexpr : MINP '(' vexpr ',' vexpr ')'",
      "vexpr : MOD '(' vexpr ',' vexpr ')'",
      "vexpr : NORM '(' vexpr ')'",
      "vexpr : NORMP '(' vexpr ')'",
      "vexpr : PI",
      "vexpr : RAD",
      "vexpr : RAND",
      "vexpr : RNORM '(' vexpr ',' vexpr ')'",
      "vexpr : RNORM '(' expr ',' vexpr ')'",
      "vexpr : RNORM '(' vexpr ',' expr ')'",
      "vexpr : RNORM '(' expr ',' expr ')'",
      "vexpr : SIN '(' vexpr ')'",
      "vexpr : SQR '(' vexpr ')'",
      "vexpr : SQRT '(' vexpr ')'",
      "vexpr : TAN '(' vexpr ')'",
      "vexpr : vexpr '?' vexpr ':' vexpr",
      "vexpr : vexpr GT vexpr",
      "vexpr : vexpr LT vexpr",
      "vexpr : vexpr LE vexpr",
      "vexpr : vexpr GE vexpr",
      "vexpr : vexpr EQ vexpr",
      "vexpr : vexpr NE vexpr",
      "vexpr : vexpr AND vexpr",
      "vexpr : vexpr OR vexpr",
      "vexpr : NOT vexpr",
      "vexpr : '(' vexpr ')'",
      "vexpr : '-' vexpr",
      "expr : NUMBER",
      "expr : FITPARM",
      "expr : VAR '[' expr ']'",
      "expr : REGNUM '.' vector",
      "expr : vector '[' expr ']'",
      "expr : SETNUM '.' vector '[' expr ']'",
      "expr : GRAPHNO '.' SETNUM '.' vector '[' expr ']'",
      "expr : SETNUM '.' vector '.' extremetype",
      "expr : GRAPHNO '.' SETNUM '.' vector '.' extremetype",
      "expr : SETNUM '.' LENGTH",
      "expr : SETNUM '.' vector '.' AVG",
      "expr : expr '+' expr",
      "expr : expr '-' expr",
      "expr : expr '*' expr",
      "expr : expr '/' expr",
      "expr : expr '%' expr",
      "expr : expr '^' expr",
      "expr : ABS '(' expr ')'",
      "expr : ACOS '(' expr ')'",
      "expr : ASIN '(' expr ')'",
      "expr : ATAN '(' expr ')'",
      "expr : ATAN2 '(' expr ',' expr ')'",
      "expr : CEIL '(' expr ')'",
      "expr : COS '(' expr ')'",
      "expr : DEG",
      "expr : ERF '(' expr ')'",
      "expr : ERFC '(' expr ')'",
      "expr : EXP '(' expr ')'",
      "expr : FLOOR '(' expr ')'",
      "expr : HYPOT '(' expr ',' expr ')'",
      "expr : GRAPHNO '.' VX1",
      "expr : GRAPHNO '.' VX2",
      "expr : GRAPHNO '.' VY1",
      "expr : GRAPHNO '.' VY2",
      "expr : GRAPHNO '.' WX1",
      "expr : GRAPHNO '.' WX2",
      "expr : GRAPHNO '.' WY1",
      "expr : GRAPHNO '.' WY2",
      "expr : VX1",
      "expr : VX2",
      "expr : VY1",
      "expr : VY2",
      "expr : WX1",
      "expr : WX2",
      "expr : WY1",
      "expr : WY2",
      "expr : DX",
      "expr : DY",
      "expr : INDEX",
      "expr : SETNO",
      "expr : INT '(' expr ')'",
      "expr : INVN '(' expr ')'",
      "expr : INVT '(' expr ',' NUMBER ')'",
      "expr : IRAND '(' NUMBER ')'",
      "expr : LGAMMA '(' expr ')'",
      "expr : LN '(' expr ')'",
      "expr : LOG '(' expr ')'",
      "expr : LOGISTIC '(' expr ',' expr ',' expr ')'",
      "expr : MAXP '(' expr ',' expr ')'",
      "expr : MINP '(' expr ',' expr ')'",
      "expr : MOD '(' expr ',' expr ')'",
      "expr : NORM '(' expr ')'",
      "expr : NORMP '(' expr ')'",
      "expr : PI",
      "expr : RAD",
      "expr : RAND",
      "expr : RNORM '(' expr ',' expr ')'",
      "expr : SIN '(' expr ')'",
      "expr : SQR '(' expr ')'",
      "expr : SQRT '(' expr ')'",
      "expr : TAN '(' expr ')'",
      "expr : expr '?' expr ':' expr",
      "expr : expr GT expr",
      "expr : expr LT expr",
      "expr : expr LE expr",
      "expr : expr GE expr",
      "expr : expr EQ expr",
      "expr : expr NE expr",
      "expr : expr AND expr",
      "expr : expr OR expr",
      "expr : NOT expr",
      "expr : '(' expr ')'",
      "expr : '-' expr",
};
#endif /* YYDEBUG */
/* @(#)27       1.7.1.1  com/cmd/lang/yacc/yaccpar, cmdlang, bos320, 9209320f 2/19/92 16:36:02 */
/*
 * COMPONENT_NAME: (CMDLANG) Language Utilities
 *
 * FUNCTIONS: yyparse
 * ORIGINS: 03
 */
/*
** Skeleton parser driver for yacc output
*/

/*
** yacc user known macros and defines
*/
#ifdef YYSPLIT
#   define YYERROR      return(-2)
#else
#   define YYERROR      goto yyerrlab
#endif
#ifdef YACC_MSG
#ifndef _XOPEN_SOURCE
#define _XOPEN_SOURCE
#endif
#include <nl_types.h>
nl_catd catd;
#endif
#define YYACCEPT        return(0)
#define YYABORT         return(1)
#ifndef YACC_MSG
#define YYBACKUP( newtoken, newvalue )\
{\
        if ( yychar >= 0 || ( yyr2[ yytmp ] >> 1 ) != 1 )\
        {\
                yyerror( "syntax error - cannot backup" );\
                YYERROR;\
        }\
        yychar = newtoken;\
        yystate = *yyps;\
        yylval = newvalue;\
        goto yynewstate;\
}
#else
#define YYBACKUP( newtoken, newvalue )\
{\
        if ( yychar >= 0 || ( yyr2[ yytmp ] >> 1 ) != 1 )\
        {\
                catd=catopen("yacc_user.cat",0);\
                yyerror(catgets(catd,1,1,"syntax error - cannot backup" ));\
                YYERROR;\
        }\
        yychar = newtoken;\
        yystate = *yyps;\
        yylval = newvalue;\
        goto yynewstate;\
}
#endif
#define YYRECOVERING()  (!!yyerrflag)
#ifndef YYDEBUG
#       define YYDEBUG  1       /* make debugging available */
#endif

/*
** user known globals
*/
int yydebug;                    /* set to 1 to get debugging */

/*
** driver internal defines
*/
#define YYFLAG          (-1000)

#ifdef YYSPLIT
#   define YYSCODE { \
                        extern int (*_yyf[])(); \
                        register int yyret; \
                        if (_yyf[yytmp]) \
                            if ((yyret=(*_yyf[yytmp])()) == -2) \
                                    goto yyerrlab; \
                                else if (yyret>=0) return(yyret); \
                   }
#endif

/*
** global variables used by the parser
*/
YYSTYPE yyv[ YYMAXDEPTH ];      /* value stack */
int yys[ YYMAXDEPTH ];          /* state stack */

YYSTYPE *yypv;                  /* top of value stack */
YYSTYPE *yypvt;                 /* top of value stack for $vars */
int *yyps;                      /* top of state stack */

int yystate;                    /* current state */
int yytmp;                      /* extra var (lasts between blocks) */

int yynerrs;                    /* number of errors */
int yyerrflag;                  /* error recovery flag */
int yychar;                     /* current input token number */

#ifdef __cplusplus
 #ifdef _CPP_IOSTREAMS
  #include <iostream.h>
  extern void yyerror (char *); /* error message routine -- iostream version */
 #else
  #include <stdio.h>
  extern "C" void yyerror (char *); /* error message routine -- stdio version */
 #endif /* _CPP_IOSTREAMS */
 extern "C" int yylex(void);        /* return the next token */
#endif /* __cplusplus */


/*
** yyparse - return 0 if worked, 1 if syntax error not recovered from
*/
#ifdef __cplusplus
extern "C"
#endif /* __cplusplus */
int
yyparse()
{
        /*
        ** Initialize externals - yyparse may be called more than once
        */
        yypv = &yyv[-1];
        yyps = &yys[-1];
        yystate = 0;
        yytmp = 0;
        yynerrs = 0;
        yyerrflag = 0;
        yychar = -1;
#ifdef YACC_MSG
        catd=catopen("yacc_user.cat",0);
#endif
        goto yystack;
        {
                register YYSTYPE *yy_pv;        /* top of value stack */
                register int *yy_ps;            /* top of state stack */
                register int yy_state;          /* current state */
                register int  yy_n;             /* internal state number info */

                /*
                ** get globals into registers.
                ** branch to here only if YYBACKUP was called.
                */
        yynewstate:
                yy_pv = yypv;
                yy_ps = yyps;
                yy_state = yystate;
                goto yy_newstate;

                /*
                ** get globals into registers.
                ** either we just started, or we just finished a reduction
                */
        yystack:
                yy_pv = yypv;
                yy_ps = yyps;
                yy_state = yystate;

                /*
                ** top of for (;;) loop while no reductions done
                */
        yy_stack:
                /*
                ** put a state and value onto the stacks
                */
#if YYDEBUG
                /*
                ** if debugging, look up token value in list of value vs.
                ** name pairs.  0 and negative (-1) are special values.
                ** Note: linear search is used since time is not a real
                ** consideration while debugging.
                */
                if ( yydebug )
                {
                        register int yy_i;

#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                        cout << "State " << yy_state << " token ";
                        if ( yychar == 0 )
                                cout << "end-of-file" << endl;
                        else if ( yychar < 0 )
                                cout << "-none-" << endl;
#else
                        printf( "State %d, token ", yy_state );
                        if ( yychar == 0 )
                                printf( "end-of-file\n" );
                        else if ( yychar < 0 )
                                printf( "-none-\n" );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                        else
                        {
                                for ( yy_i = 0; yytoks[yy_i].t_val >= 0;
                                        yy_i++ )
                                {
                                        if ( yytoks[yy_i].t_val == yychar )
                                                break;
                                }
#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                cout << yytoks[yy_i].t_name << endl;
#else
                                printf( "%s\n", yytoks[yy_i].t_name );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                        }
                }
#endif /* YYDEBUG */
                if ( ++yy_ps >= &yys[ YYMAXDEPTH ] )    /* room on stack? */
                {
#ifndef YACC_MSG
                        yyerror( "yacc stack overflow" );
#else
                        yyerror(catgets(catd,1,2,"yacc stack overflow" ));
#endif
                        YYABORT;
                }
                *yy_ps = yy_state;
                *++yy_pv = yyval;

                /*
                ** we have a new state - find out what to do
                */
        yy_newstate:
                if ( ( yy_n = yypact[ yy_state ] ) <= YYFLAG )
                        goto yydefault;         /* simple state */
#if YYDEBUG
                /*
                ** if debugging, need to mark whether new token grabbed
                */
                yytmp = yychar < 0;
#endif
                if ( ( yychar < 0 ) && ( ( yychar = yylex() ) < 0 ) )
                        yychar = 0;             /* reached EOF */
#if YYDEBUG
                if ( yydebug && yytmp )
                {
                        register int yy_i;

#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                        cout << "Received token " << endl;
                        if ( yychar == 0 )
                                cout << "end-of-file" << endl;
                        else if ( yychar < 0 )
                                cout << "-none-" << endl;
#else
                        printf( "Received token " );
                        if ( yychar == 0 )
                                printf( "end-of-file\n" );
                        else if ( yychar < 0 )
                                printf( "-none-\n" );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                        else
                        {
                                for ( yy_i = 0; yytoks[yy_i].t_val >= 0;
                                        yy_i++ )
                                {
                                        if ( yytoks[yy_i].t_val == yychar )
                                                break;
                                }
#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                cout << yytoks[yy_i].t_name << endl;
#else
                                printf( "%s\n", yytoks[yy_i].t_name );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                        }
                }
#endif /* YYDEBUG */
                if ( ( ( yy_n += yychar ) < 0 ) || ( yy_n >= YYLAST ) )
                        goto yydefault;
                if ( yychk[ yy_n = yyact[ yy_n ] ] == yychar )  /*valid shift*/
                {
                        yychar = -1;
                        yyval = yylval;
                        yy_state = yy_n;
                        if ( yyerrflag > 0 )
                                yyerrflag--;
                        goto yy_stack;
                }

        yydefault:
                if ( ( yy_n = yydef[ yy_state ] ) == -2 )
                {
#if YYDEBUG
                        yytmp = yychar < 0;
#endif
                        if ( ( yychar < 0 ) && ( ( yychar = yylex() ) < 0 ) )
                                yychar = 0;             /* reached EOF */
#if YYDEBUG
                        if ( yydebug && yytmp )
                        {
                                register int yy_i;

#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                cout << "Received token " << endl;
                                if ( yychar == 0 )
                                        cout << "end-of-file" << endl;
                                else if ( yychar < 0 )
                                        cout << "-none-" << endl;
#else
                                printf( "Received token " );
                                if ( yychar == 0 )
                                        printf( "end-of-file\n" );
                                else if ( yychar < 0 )
                                        printf( "-none-\n" );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                                else
                                {
                                        for ( yy_i = 0;
                                                yytoks[yy_i].t_val >= 0;
                                                yy_i++ )
                                        {
                                                if ( yytoks[yy_i].t_val
                                                        == yychar )
                                                {
                                                        break;
                                                }
                                        }
#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                        cout << yytoks[yy_i].t_name << endl;
#else
                                        printf( "%s\n", yytoks[yy_i].t_name );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                                }
                        }
#endif /* YYDEBUG */
                        /*
                        ** look through exception table
                        */
                        {
                                register int *yyxi = yyexca;

                                while ( ( *yyxi != -1 ) ||
                                        ( yyxi[1] != yy_state ) )
                                {
                                        yyxi += 2;
                                }
                                while ( ( *(yyxi += 2) >= 0 ) &&
                                        ( *yyxi != yychar ) )
                                        ;
                                if ( ( yy_n = yyxi[1] ) < 0 )
                                        YYACCEPT;
                        }
                }

                /*
                ** check for syntax error
                */
                if ( yy_n == 0 )        /* have an error */
                {
                        /* no worry about speed here! */
                        switch ( yyerrflag )
                        {
                        case 0:         /* new error */
#ifndef YACC_MSG
                                yyerror( "syntax error" );
#else
                                yyerror(catgets(catd,1,3,"syntax error" ));
#endif
                                goto skip_init;
                        yyerrlab:
                                /*
                                ** get globals into registers.
                                ** we have a user generated syntax type error
                                */
                                yy_pv = yypv;
                                yy_ps = yyps;
                                yy_state = yystate;
                                yynerrs++;
                        skip_init:
                        case 1:
                        case 2:         /* incompletely recovered error */
                                        /* try again... */
                                yyerrflag = 3;
                                /*
                                ** find state where "error" is a legal
                                ** shift action
                                */
                                while ( yy_ps >= yys )
                                {
                                        yy_n = yypact[ *yy_ps ] + YYERRCODE;
                                        if ( yy_n >= 0 && yy_n < YYLAST &&
                                                yychk[yyact[yy_n]] == YYERRCODE)                                        {
                                                /*
                                                ** simulate shift of "error"
                                                */
                                                yy_state = yyact[ yy_n ];
                                                goto yy_stack;
                                        }
                                        /*
                                        ** current state has no shift on
                                        ** "error", pop stack
                                        */
#if YYDEBUG
                                        if ( yydebug )
#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                            cout << "Error recovery pops state "
                                                 << (*yy_ps)
                                                 << ", uncovers state "
                                                 << yy_ps[-1] << endl;
#else
#       define _POP_ "Error recovery pops state %d, uncovers state %d\n"
                                                printf( _POP_, *yy_ps,
                                                        yy_ps[-1] );
#       undef _POP_
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
#endif
                                        yy_ps--;
                                        yy_pv--;
                                }
                                /*
                                ** there is no state on stack with "error" as
                                ** a valid shift.  give up.
                                */
                                YYABORT;
                        case 3:         /* no shift yet; eat a token */
#if YYDEBUG
                                /*
                                ** if debugging, look up token in list of
                                ** pairs.  0 and negative shouldn't occur,
                                ** but since timing doesn't matter when
                                ** debugging, it doesn't hurt to leave the
                                ** tests here.
                                */
                                if ( yydebug )
                                {
                                        register int yy_i;

#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                        cout << "Error recovery discards ";
                                        if ( yychar == 0 )
                                            cout << "token end-of-file" << endl;
                                        else if ( yychar < 0 )
                                            cout << "token -none-" << endl;
#else
                                        printf( "Error recovery discards " );
                                        if ( yychar == 0 )
                                                printf( "token end-of-file\n" );
                                        else if ( yychar < 0 )
                                                printf( "token -none-\n" );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                                        else
                                        {
                                                for ( yy_i = 0;
                                                        yytoks[yy_i].t_val >= 0;
                                                        yy_i++ )
                                                {
                                                        if ( yytoks[yy_i].t_val
                                                                == yychar )
                                                        {
                                                                break;
                                                        }
                                                }
#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                                                cout << "token " <<
                                                    yytoks[yy_i].t_name <<
                                                    endl;
#else
                                                printf( "token %s\n",
                                                        yytoks[yy_i].t_name );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
                                        }
                                }
#endif /* YYDEBUG */
                                if ( yychar == 0 )      /* reached EOF. quit */
                                        YYABORT;
                                yychar = -1;
                                goto yy_newstate;
                        }
                }/* end if ( yy_n == 0 ) */
                /*
                ** reduction by production yy_n
                ** put stack tops, etc. so things right after switch
                */
#if YYDEBUG
                /*
                ** if debugging, print the string that is the user's
                ** specification of the reduction which is just about
                ** to be done.
                */
                if ( yydebug )
#if defined(__cplusplus) && defined(_CPP_IOSTREAMS)
                        cout << "Reduce by (" << yy_n << ") \"" <<
                            yyreds[ yy_n ] << "\"\n";
#else
                        printf( "Reduce by (%d) \"%s\"\n",
                                yy_n, yyreds[ yy_n ] );
#endif /* defined(__cplusplus) && defined(_CPP_IOSTREAMS) */
#endif
                yytmp = yy_n;                   /* value to switch over */
                yypvt = yy_pv;                  /* $vars top of value stack */
                /*
                ** Look in goto table for next state
                ** Sorry about using yy_state here as temporary
                ** register variable, but why not, if it works...
                ** If yyr2[ yy_n ] doesn't have the low order bit
                ** set, then there is no action to be done for
                ** this reduction.  So, no saving & unsaving of
                ** registers done.  The only difference between the
                ** code just after the if and the body of the if is
                ** the goto yy_stack in the body.  This way the test
                ** can be made before the choice of what to do is needed.
                */
                {
                        /* length of production doubled with extra bit */
                        register int yy_len = yyr2[ yy_n ];

                        if ( !( yy_len & 01 ) )
                        {
                                yy_len >>= 1;
                                yyval = ( yy_pv -= yy_len )[1]; /* $$ = $1 */
                                yy_state = yypgo[ yy_n = yyr1[ yy_n ] ] +
                                        *( yy_ps -= yy_len ) + 1;
                                if ( yy_state >= YYLAST ||
                                        yychk[ yy_state =
                                        yyact[ yy_state ] ] != -yy_n )
                                {
                                        yy_state = yyact[ yypgo[ yy_n ] ];
                                }
                                goto yy_stack;
                        }
                        yy_len >>= 1;
                        yyval = ( yy_pv -= yy_len )[1]; /* $$ = $1 */
                        yy_state = yypgo[ yy_n = yyr1[ yy_n ] ] +
                                *( yy_ps -= yy_len ) + 1;
                        if ( yy_state >= YYLAST ||
                                yychk[ yy_state = yyact[ yy_state ] ] != -yy_n )
                        {
                                yy_state = yyact[ yypgo[ yy_n ] ];
                        }
                }
                                        /* save until reenter driver code */
                yystate = yy_state;
                yyps = yy_ps;
                yypv = yy_pv;
        }
        /*
        ** code supplied by user is placed in this switch
        */

                switch(yytmp){

case 5:
# line 504 "pars.yacc"
{
	    result = yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 6:
# line 507 "pars.yacc"
{
	    result = *yypvt[-1].ptr;
	} /*NOTREACHED*/ break;
case 13:
# line 516 "pars.yacc"
{
	    return 1;
	} /*NOTREACHED*/ break;
case 14:
# line 522 "pars.yacc"
{
	    if (yypvt[-1].pset == FILEP) {
		set_printer(FILEP, yypvt[-0].pset);
	    }
	    else {
		set_printer(yypvt[-1].pset, yypvt[-0].pset);
	    }
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 15:
# line 531 "pars.yacc"
{
	    if (yypvt[-1].pset == FILEP) {
		set_printer(FILEP, yypvt[-0].pset);
	    }
	    else {
		set_printer(yypvt[-1].pset, yypvt[-0].pset);
	    }
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 16:
# line 540 "pars.yacc"
{
	    if (yypvt[-0].pset == FILEP) {
		set_printer(FILEP, NULL);
	    }
	    else {
		set_printer(yypvt[-0].pset, NULL);
	    }
	} /*NOTREACHED*/ break;
case 17:
# line 548 "pars.yacc"
{
	    tdevice = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 18:
# line 551 "pars.yacc"
{
	    hdevice = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 19:
# line 554 "pars.yacc"
{
	    do_hardcopy();
	} /*NOTREACHED*/ break;
case 20:
# line 558 "pars.yacc"
{ 
	    extern int pslwfactor; /* fudge factor for linewidths in the PS driver */
	    pslwfactor = yypvt[-0].val; 
	} /*NOTREACHED*/ break;
case 21:
# line 565 "pars.yacc"
{ yyval.pset = GR_PS_P; } /*NOTREACHED*/ break;
case 22:
# line 566 "pars.yacc"
{ yyval.pset = GR_PS_L; } /*NOTREACHED*/ break;
case 23:
# line 567 "pars.yacc"
{ yyval.pset = GR_MIF_P; } /*NOTREACHED*/ break;
case 24:
# line 568 "pars.yacc"
{ yyval.pset = GR_MIF_L; } /*NOTREACHED*/ break;
case 25:
# line 569 "pars.yacc"
{ yyval.pset = GR_HPGL_P; } /*NOTREACHED*/ break;
case 26:
# line 570 "pars.yacc"
{ yyval.pset = GR_HPGL_L; } /*NOTREACHED*/ break;
case 27:
# line 571 "pars.yacc"
{ yyval.pset = hdevice; } /*NOTREACHED*/ break;
case 28:
# line 572 "pars.yacc"
{ yyval.pset = FILEP; } /*NOTREACHED*/ break;
case 29:
# line 576 "pars.yacc"
{
	    rg[yypvt[-1].pset].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 30:
# line 579 "pars.yacc"
{
	    rg[yypvt[-2].pset].type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 31:
# line 582 "pars.yacc"
{
	    rg[yypvt[-2].pset].color = checkon(COLOR, rg[yypvt[-2].pset].color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 32:
# line 585 "pars.yacc"
{
	    rg[yypvt[-2].pset].lines = checkon(LINESTYLE, rg[yypvt[-2].pset].lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 33:
# line 588 "pars.yacc"
{
	    rg[yypvt[-2].pset].linew = checkon(LINEWIDTH, rg[yypvt[-2].pset].linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 34:
# line 592 "pars.yacc"
{
	    rg[yypvt[-8].pset].x1 = yypvt[-6].val;
	    rg[yypvt[-8].pset].y1 = yypvt[-4].val;
	    rg[yypvt[-8].pset].x2 = yypvt[-2].val;
	    rg[yypvt[-8].pset].y2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 35:
# line 599 "pars.yacc"
{
	    if (rg[yypvt[-4].pset].x == NULL || rg[yypvt[-4].pset].n == 0) {
		rg[yypvt[-4].pset].n = 0;
		rg[yypvt[-4].pset].x = (double *) calloc(1, sizeof(double));
		rg[yypvt[-4].pset].y = (double *) calloc(1, sizeof(double));
	    } else {
		rg[yypvt[-4].pset].x = (double *) realloc(rg[yypvt[-4].pset].x, (rg[yypvt[-4].pset].n + 1) * sizeof(double));
		rg[yypvt[-4].pset].y = (double *) realloc(rg[yypvt[-4].pset].y, (rg[yypvt[-4].pset].n + 1) * sizeof(double));
	    }
	    rg[yypvt[-4].pset].x[rg[yypvt[-4].pset].n] = yypvt[-2].val;
	    rg[yypvt[-4].pset].y[rg[yypvt[-4].pset].n] = yypvt[-0].val;
	    rg[yypvt[-4].pset].n++;
	} /*NOTREACHED*/ break;
case 36:
# line 612 "pars.yacc"
{
	    rg[yypvt[-2].pset].linkto[yypvt[-0].pset] = TRUE;
	} /*NOTREACHED*/ break;
case 37:
# line 618 "pars.yacc"
{
	    drawgraph();
	} /*NOTREACHED*/ break;
case 38:
# line 621 "pars.yacc"
{
	    auto_redraw = (yypvt[-0].pset == ON);
	} /*NOTREACHED*/ break;
case 39:
# line 624 "pars.yacc"
{
	    char buf[MAXPATHLEN];
	    strcpy(buf, (char *) yypvt[-0].pset);
	    expand_tilde(buf); 
	    if (chdir(buf) >= 0) {
		strcpy(workingdir, buf);
	    	if (inwin) {
		    set_title(workingdir);
	        }
	    }
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 40:
# line 636 "pars.yacc"
{
	    if (inwin) {
		set_left_footer(yypvt[-0].pset);
	    }
	    else {
		printf("%s\n", yypvt[-0].pset);
	    }
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 41:
# line 645 "pars.yacc"
{
	    setbgcolor((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 42:
# line 648 "pars.yacc"
{
	    xlibsetcmap((int) yypvt[-6].val, (int) yypvt[-4].val, (int) yypvt[-2].val, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 43:
# line 651 "pars.yacc"
{
	    exit(0);
	} /*NOTREACHED*/ break;
case 44:
# line 655 "pars.yacc"
{
            set_pagelayout(yypvt[-0].pset);
        } /*NOTREACHED*/ break;
case 45:
# line 659 "pars.yacc"
{
            set_toolbars(yypvt[-1].pset, yypvt[-0].pset == ON);
        } /*NOTREACHED*/ break;
case 46:
# line 663 "pars.yacc"
{
            set_toolbars(yypvt[-1].pset, yypvt[-0].pset == ON);
        } /*NOTREACHED*/ break;
case 47:
# line 667 "pars.yacc"
{
            set_toolbars(yypvt[-1].pset, yypvt[-0].pset == ON);
        } /*NOTREACHED*/ break;
case 48:
# line 671 "pars.yacc"
{
	    if (inwin) {
		my_draw2((double) yypvt[-2].val, (double) yypvt[-0].val);
		flush_pending();
	    }
	} /*NOTREACHED*/ break;
case 49:
# line 677 "pars.yacc"
{
	    if (inwin) {
		my_move2((double) yypvt[-2].val, (double) yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 50:
# line 682 "pars.yacc"
{
	    if (inwin) {
		double x = (double) yypvt[-4].val;
		double y = (double) yypvt[-2].val;
		drawpolysym(&x, &y, 1, (int) yypvt[-0].val, 0, 0, 1.0);
		flush_pending();
	    }
	} /*NOTREACHED*/ break;
case 51:
# line 690 "pars.yacc"
{
	    if (inwin) {
		setcolor((int) yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 52:
# line 695 "pars.yacc"
{
	    if (inwin) {
		setlinewidth((int) yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 53:
# line 700 "pars.yacc"
{
	    if (inwin) {
		setlinestyle((int) yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 54:
# line 705 "pars.yacc"
{
	} /*NOTREACHED*/ break;
case 55:
# line 709 "pars.yacc"
{
	    switch (yypvt[-0].pset) {
	    case UP:
		gwindup_proc();
		break;
	    case DOWN:
		gwinddown_proc();
		break;
	    case RIGHT:
		gwindright_proc();
		break;
	    case LEFT:
		gwindleft_proc();
		break;
	    case IN:
		gwindshrink_proc();
		break;
	    case OUT:
		gwindexpand_proc();
		break;
	    }
	} /*NOTREACHED*/ break;
case 56:
# line 731 "pars.yacc"
{
	    scroll_proc((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 57:
# line 734 "pars.yacc"
{
	    scrollinout_proc((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 58:
# line 737 "pars.yacc"
{
	    scrolling_islinked = yypvt[-0].pset == ON;
	} /*NOTREACHED*/ break;
case 59:
# line 740 "pars.yacc"
{
	    my_doublebuffer(yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 60:
# line 743 "pars.yacc"
{
	    my_frontbuffer(yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 61:
# line 746 "pars.yacc"
{
	    my_backbuffer(yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 62:
# line 749 "pars.yacc"
{
	    my_swapbuffer();
	} /*NOTREACHED*/ break;
case 63:
# line 752 "pars.yacc"
{
	    sleep((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 64:
# line 755 "pars.yacc"
{	/* TODO add delay function */
	} /*NOTREACHED*/ break;
case 65:
# line 757 "pars.yacc"
{		/* TODO add abort flag and function */
	} /*NOTREACHED*/ break;
case 66:
# line 760 "pars.yacc"
{
	    gotparams = TRUE;
	    strcpy(paramfile, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 67:
# line 766 "pars.yacc"
{
	    if (!fexists((char *) yypvt[-0].pset)) {
		FILE *pp = fopen((char *) yypvt[-0].pset, "w");
		if (pp != NULL) {
		    putparms(cg, pp, 0);
		    fclose(pp);
		} else {
		    errwin("Unable to write parameter file");
		}
	    }
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 68:
# line 778 "pars.yacc"
{
	    cg = (int) yypvt[-0].pset;
	    g[cg].parmsread = TRUE;
	    change_gno = cg;
	} /*NOTREACHED*/ break;
case 69:
# line 783 "pars.yacc"
{
	    curset = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 70:
# line 788 "pars.yacc"
{
	    set_hotlink(cg, yypvt[-3].pset, 1, (char *) yypvt[-0].pset, yypvt[-1].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 71:
# line 792 "pars.yacc"
{
	    set_hotlink(yypvt[-5].pset, yypvt[-3].pset, 1, (char *) yypvt[-0].pset, yypvt[-1].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 72:
# line 796 "pars.yacc"
{
	    set_hotlink(cg, yypvt[-2].pset, yypvt[-0].pset == ON, NULL);
	} /*NOTREACHED*/ break;
case 73:
# line 799 "pars.yacc"
{
	    set_hotlink(yypvt[-4].pset, yypvt[-2].pset, yypvt[-0].pset == ON, NULL, 0);
	} /*NOTREACHED*/ break;
case 74:
# line 803 "pars.yacc"
{
	    do_activateset(cg, yypvt[-1].pset, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 75:
# line 806 "pars.yacc"
{
	    add_point(cg, yypvt[-4].pset, yypvt[-2].val, yypvt[-0].val, 0.0, 0.0, XY);
	} /*NOTREACHED*/ break;
case 76:
# line 809 "pars.yacc"
{
	    add_point(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].val, yypvt[-0].val, 0.0, 0.0, XY);
	} /*NOTREACHED*/ break;
case 77:
# line 813 "pars.yacc"
{
	    int start = (int) yypvt[-2].val - 1;
	    int stop = (int) yypvt[-0].val - 1;
	    int dist = stop - start + 1;
	    if (dist > 0 && start >= 0) {
	        droppoints(cg, yypvt[-4].pset, start, stop, dist);
	    }
	} /*NOTREACHED*/ break;
case 78:
# line 821 "pars.yacc"
{
	    int start = (int) yypvt[-2].val - 1;
	    int stop = (int) yypvt[-0].val - 1;
	    int dist = stop - start + 1;
	    if (dist > 0 && start >= 0) {
	        droppoints(yypvt[-6].pset, yypvt[-4].pset, start, stop, dist);
	    }
	} /*NOTREACHED*/ break;
case 79:
# line 829 "pars.yacc"
{
	    do_copyset(cg, yypvt[-2].pset, cg, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 80:
# line 832 "pars.yacc"
{
	    do_copyset(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 81:
# line 835 "pars.yacc"
{
	    do_moveset(cg, yypvt[-2].pset, cg, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 82:
# line 838 "pars.yacc"
{
	    do_moveset(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 83:
# line 842 "pars.yacc"
{
	    killset(cg, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 84:
# line 846 "pars.yacc"
{
	    int i;
	    for (i = 0; i < g[cg].maxplot; i++) {
		killset(cg, i);
	    }
	} /*NOTREACHED*/ break;
case 85:
# line 853 "pars.yacc"
{
	    kill_graph(yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 86:
# line 857 "pars.yacc"
{
	    kill_graph(maxgraph);
	} /*NOTREACHED*/ break;
case 87:
# line 861 "pars.yacc"
{
	    wipeout(0);
	} /*NOTREACHED*/ break;
case 88:
# line 865 "pars.yacc"
{
	    int i;
	    for (i = 0; i < (int) yypvt[-4].val; i++) {
		yypvt[-5].ptr[i] = yypvt[-2].val + yypvt[-0].val * i;
	    }
	} /*NOTREACHED*/ break;
case 89:
# line 872 "pars.yacc"
{
	    int setno = yypvt[-3].pset, ideg = (int) yypvt[-1].val;
	    do_regress(setno, ideg, 0, -1, 0);
	} /*NOTREACHED*/ break;
case 90:
# line 877 "pars.yacc"
{
	    do_running_command(yypvt[-5].pset, yypvt[-3].pset, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 91:
# line 881 "pars.yacc"
{
	    do_fourier_command(yypvt[-5].pset, yypvt[-3].pset, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 92:
# line 885 "pars.yacc"
{
	    do_spline(yypvt[-7].pset, yypvt[-5].val, yypvt[-3].val, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 93:
# line 889 "pars.yacc"
{
	    do_histo_command(yypvt[-7].pset, -1, -1, yypvt[-5].val, yypvt[-3].val, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 94:
# line 893 "pars.yacc"
{
	    do_differ(yypvt[-3].pset, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 95:
# line 897 "pars.yacc"
{
	    do_int(yypvt[-1].pset, 0);
	} /*NOTREACHED*/ break;
case 96:
# line 901 "pars.yacc"
{
	    if (activeset(cg)) {
		defaultgraph(cg);
		default_axis(cg, g[cg].auto_type, X_AXIS);
		default_axis(cg, g[cg].auto_type, ZX_AXIS);
		default_axis(cg, g[cg].auto_type, Y_AXIS);
		default_axis(cg, g[cg].auto_type, ZY_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("No active sets!");
	    }
	} /*NOTREACHED*/ break;
case 97:
# line 915 "pars.yacc"
{
	    if (activeset(cg)) {
		defaultx(cg, -1);
		default_axis(cg, g[cg].auto_type, X_AXIS);
		default_axis(cg, g[cg].auto_type, ZX_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("No active sets!");
	    }
	} /*NOTREACHED*/ break;
case 98:
# line 927 "pars.yacc"
{
	    if (activeset(cg)) {
		defaulty(cg, -1);
		default_axis(cg, g[cg].auto_type, Y_AXIS);
		default_axis(cg, g[cg].auto_type, ZY_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("No active sets!");
	    }
	} /*NOTREACHED*/ break;
case 99:
# line 939 "pars.yacc"
{
	    if (isactive_set(cg, yypvt[-0].pset)) {
		defaultsetgraph(cg, yypvt[-0].pset);
		default_axis(cg, g[cg].auto_type, X_AXIS);
		default_axis(cg, g[cg].auto_type, ZX_AXIS);
		default_axis(cg, g[cg].auto_type, Y_AXIS);
		default_axis(cg, g[cg].auto_type, ZY_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("Set not active");
	    }
	} /*NOTREACHED*/ break;
case 100:
# line 953 "pars.yacc"
{
	    extern int go_locateflag;
	    go_locateflag = (yypvt[-0].pset == ON);
	} /*NOTREACHED*/ break;
case 101:
# line 958 "pars.yacc"
{
	    draw_focus(cg);
	    cg = (int) yypvt[-0].pset;
	    defineworld(g[cg].w.xg1, g[cg].w.yg1, g[cg].w.xg2, g[cg].w.yg2, 
			islogx(cg), islogy(cg));
	    viewport(g[cg].v.xv1, g[cg].v.yv1, g[cg].v.xv2, g[cg].v.yv2);
	    draw_focus(cg);
	    update_all(cg);
	} /*NOTREACHED*/ break;
case 102:
# line 967 "pars.yacc"
{
	    draw_focus_flag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 103:
# line 970 "pars.yacc"
{
	    focus_policy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 104:
# line 973 "pars.yacc"
{
	    focus_policy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 105:
# line 976 "pars.yacc"
{
	    focus_policy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 106:
# line 979 "pars.yacc"
{
	    cursource = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 107:
# line 982 "pars.yacc"
{
	    curtype = yypvt[-0].pset;
	    change_type = curtype;
	} /*NOTREACHED*/ break;
case 108:
# line 987 "pars.yacc"
{
	    gotread = TRUE;
	    readtype = curtype;
	    readsrc = cursource;
	    strcpy(readfile, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 109:
# line 995 "pars.yacc"
{
	    gotbatch = TRUE;
	    strcpy(batchfile, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 110:
# line 1001 "pars.yacc"
{
	    getdata(cg, (char *) yypvt[-0].pset, DISK, BLOCK);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 111:
# line 1006 "pars.yacc"
{
	    getdata(cg, (char *) yypvt[-0].pset, yypvt[-1].pset, BLOCK);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 112:
# line 1011 "pars.yacc"
{
	    create_set_fromblock(cg, yypvt[-1].pset, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 113:
# line 1016 "pars.yacc"
{
	    gotread = TRUE;
	    readtype = yypvt[-1].pset;
	    readsrc = cursource;
	    strcpy(readfile, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 114:
# line 1024 "pars.yacc"
{
	    gotread = TRUE;
	    strcpy(readfile, (char *) yypvt[-0].pset);
	    readtype = yypvt[-2].pset;
	    readsrc = yypvt[-1].pset;
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 115:
# line 1032 "pars.yacc"
{
	    read_image((char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 116:
# line 1037 "pars.yacc"
{
	    write_image((char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 117:
# line 1042 "pars.yacc"
{
	    imagex = (int) yypvt[-2].val;
	    imagey = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 118:
# line 1047 "pars.yacc"
{
	    outputset(cg, yypvt[-0].pset, (char *) NULL, (char *) NULL);
	} /*NOTREACHED*/ break;
case 119:
# line 1051 "pars.yacc"
{
	    outputset(cg, yypvt[-2].pset, (char *) NULL, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 120:
# line 1056 "pars.yacc"
{
	    outputset(cg, yypvt[-2].pset, (char *) yypvt[-0].pset, (char *) NULL);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 121:
# line 1061 "pars.yacc"
{
	    outputset(cg, yypvt[-4].pset, (char *) yypvt[-2].pset, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-2].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 122:
# line 1067 "pars.yacc"
{
            extern char sformat[];
            do_writesets(maxgraph, -1, 1, (char *) yypvt[-0].pset, sformat);
            free((char *) yypvt[-0].pset);
        } /*NOTREACHED*/ break;
case 123:
# line 1072 "pars.yacc"
{
	    push_world();
	} /*NOTREACHED*/ break;
case 124:
# line 1075 "pars.yacc"
{
	    pop_world();
	} /*NOTREACHED*/ break;
case 125:
# line 1078 "pars.yacc"
{
	    cycle_world_stack();
	} /*NOTREACHED*/ break;
case 126:
# line 1081 "pars.yacc"
{
	    if ((int) yypvt[-0].val > 0)
		show_world_stack((int) yypvt[-0].val - 1);
	} /*NOTREACHED*/ break;
case 127:
# line 1086 "pars.yacc"
{
	    add_world(cg, yypvt[-14].val, yypvt[-12].val, yypvt[-10].val, yypvt[-8].val, yypvt[-6].val, yypvt[-4].val, yypvt[-2].val, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 128:
# line 1089 "pars.yacc"
{
	    clear_world_stack();
	} /*NOTREACHED*/ break;
case 129:
# line 1092 "pars.yacc"
{
	    do_clear_boxes();
	} /*NOTREACHED*/ break;
case 130:
# line 1095 "pars.yacc"
{
	    curbox = next_box();
	} /*NOTREACHED*/ break;
case 131:
# line 1098 "pars.yacc"
{
	    curbox = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 132:
# line 1101 "pars.yacc"
{
	    boxes[curbox].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 133:
# line 1104 "pars.yacc"
{
	    boxes[curbox].gno = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 134:
# line 1108 "pars.yacc"
{
	    if (curbox >= 0 && curbox < MAXBOXES) {
		boxes[curbox].x1 = yypvt[-6].val;
		boxes[curbox].y1 = yypvt[-4].val;
		boxes[curbox].x2 = yypvt[-2].val;
		boxes[curbox].y2 = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 135:
# line 1116 "pars.yacc"
{
	    box_loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 136:
# line 1119 "pars.yacc"
{
	    box_lines = checkon(LINESTYLE, box_lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 137:
# line 1122 "pars.yacc"
{
	    box_linew = checkon(LINEWIDTH, box_linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 138:
# line 1125 "pars.yacc"
{
	    box_color = checkon(COLOR, box_color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 139:
# line 1128 "pars.yacc"
{
	    box_fill = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 140:
# line 1131 "pars.yacc"
{
	    box_fillcolor = checkon(COLOR, box_fillcolor, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 141:
# line 1134 "pars.yacc"
{
	    box_fillpat = checkon(PATTERN, box_fillpat, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 142:
# line 1138 "pars.yacc"
{
	    if (curbox >= 0 && curbox < MAXBOXES) {
		boxes[curbox].lines = box_lines;
		boxes[curbox].linew = box_linew;
		boxes[curbox].color = box_color;
		boxes[curbox].fill = box_fill;
		boxes[curbox].fillcolor = box_fillcolor;
		boxes[curbox].fillpattern = box_fillpat;
		boxes[curbox].loctype = box_loctype;
	    }
	} /*NOTREACHED*/ break;
case 143:
# line 1149 "pars.yacc"
{
	    curline = next_line();
	} /*NOTREACHED*/ break;
case 144:
# line 1152 "pars.yacc"
{
	    curline = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 145:
# line 1155 "pars.yacc"
{
	    do_clear_lines();
	} /*NOTREACHED*/ break;
case 146:
# line 1158 "pars.yacc"
{
	    lines[curline].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 147:
# line 1161 "pars.yacc"
{
	    lines[curline].gno = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 148:
# line 1165 "pars.yacc"
{
	    lines[curline].x1 = yypvt[-6].val;
	    lines[curline].y1 = yypvt[-4].val;
	    lines[curline].x2 = yypvt[-2].val;
	    lines[curline].y2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 149:
# line 1171 "pars.yacc"
{
	    line_loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 150:
# line 1174 "pars.yacc"
{
	    line_linew = checkon(LINEWIDTH, line_linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 151:
# line 1177 "pars.yacc"
{
	    line_lines = checkon(LINESTYLE, line_lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 152:
# line 1180 "pars.yacc"
{
	    line_color = checkon(COLOR, line_color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 153:
# line 1183 "pars.yacc"
{
	    line_arrow = checkon(ARROW, line_arrow, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 154:
# line 1186 "pars.yacc"
{
	    line_asize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 155:
# line 1189 "pars.yacc"
{
	    line_atype = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 156:
# line 1193 "pars.yacc"
{
	    if (curline >= 0 && curline < MAXLINES) {
		lines[curline].lines = line_lines;
		lines[curline].linew = line_linew;
		lines[curline].color = line_color;
		lines[curline].arrow = line_arrow;
		lines[curline].asize = line_asize;
		lines[curline].atype = line_atype;
		lines[curline].loctype = line_loctype;
	    }
	} /*NOTREACHED*/ break;
case 157:
# line 1204 "pars.yacc"
{
	    do_clear_text();
	} /*NOTREACHED*/ break;
case 158:
# line 1207 "pars.yacc"
{
	    curstring = next_string();
	} /*NOTREACHED*/ break;
case 159:
# line 1210 "pars.yacc"
{
	    curstring = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 160:
# line 1213 "pars.yacc"
{
	    pstr[curstring].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 161:
# line 1216 "pars.yacc"
{
	    pstr[curstring].gno = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 162:
# line 1220 "pars.yacc"
{
	    pstr[curstring].x = yypvt[-2].val;
	    pstr[curstring].y = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 163:
# line 1224 "pars.yacc"
{
	    string_loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 164:
# line 1227 "pars.yacc"
{
	    string_linew = checkon(LINEWIDTH, string_linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 165:
# line 1230 "pars.yacc"
{
	    string_color = checkon(COLOR, string_color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 166:
# line 1233 "pars.yacc"
{
	    string_rot = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 167:
# line 1236 "pars.yacc"
{
	    string_font = checkon(FONTP, string_font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 168:
# line 1239 "pars.yacc"
{
	    string_just = checkon(JUST, string_just, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 169:
# line 1242 "pars.yacc"
{
	    string_size = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 170:
# line 1246 "pars.yacc"
{
	    set_plotstr_string(&pstr[curstring], (char *) yypvt[-0].pset);
	    pstr[curstring].linew = string_linew;
	    pstr[curstring].color = string_color;
	    pstr[curstring].font = string_font;
	    pstr[curstring].just = string_just;
	    pstr[curstring].loctype = string_loctype;
	    pstr[curstring].rot = string_rot;
	    pstr[curstring].charsize = string_size;
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 171:
# line 1257 "pars.yacc"
{
	    grdefaults.lines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 172:
# line 1260 "pars.yacc"
{
	    grdefaults.linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 173:
# line 1263 "pars.yacc"
{
	    grdefaults.color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 174:
# line 1266 "pars.yacc"
{
	    grdefaults.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 175:
# line 1269 "pars.yacc"
{
	    grdefaults.font = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 176:
# line 1272 "pars.yacc"
{
	    grdefaults.fontsrc = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 177:
# line 1275 "pars.yacc"
{
	    grdefaults.symsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 178:
# line 1279 "pars.yacc"
{
	    g[cg].w.xg1 = yypvt[-6].val;
	    g[cg].w.yg1 = yypvt[-4].val;
	    g[cg].w.xg2 = yypvt[-2].val;
	    g[cg].w.yg2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 179:
# line 1285 "pars.yacc"
{
	    g[cg].w.xg1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 180:
# line 1288 "pars.yacc"
{
	    g[cg].w.xg2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 181:
# line 1291 "pars.yacc"
{
	    g[cg].w.yg1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 182:
# line 1294 "pars.yacc"
{
	    g[cg].w.yg2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 183:
# line 1298 "pars.yacc"
{
	    g[cg].v.xv1 = yypvt[-6].val;
	    g[cg].v.yv1 = yypvt[-4].val;
	    g[cg].v.xv2 = yypvt[-2].val;
	    g[cg].v.yv2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 184:
# line 1304 "pars.yacc"
{
	    g[cg].v.xv1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 185:
# line 1307 "pars.yacc"
{
	    g[cg].v.xv2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 186:
# line 1310 "pars.yacc"
{
	    g[cg].v.yv1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 187:
# line 1313 "pars.yacc"
{
	    g[cg].v.yv2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 188:
# line 1316 "pars.yacc"
{
	    set_plotstr_string(&g[cg].labs.title, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 189:
# line 1320 "pars.yacc"
{
	    g[cg].labs.title.font = checkon(FONTP, g[cg].labs.title.font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 190:
# line 1323 "pars.yacc"
{
	    g[cg].labs.title.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 191:
# line 1326 "pars.yacc"
{
	    g[cg].labs.title.color = checkon(COLOR, g[cg].labs.title.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 192:
# line 1330 "pars.yacc"
{
	    g[cg].labs.title.linew = checkon(LINEWIDTH, g[cg].labs.title.linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 193:
# line 1333 "pars.yacc"
{
	    set_plotstr_string(&g[cg].labs.stitle, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 194:
# line 1338 "pars.yacc"
{
	    g[cg].labs.stitle.font = checkon(FONTP, g[cg].labs.stitle.font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 195:
# line 1341 "pars.yacc"
{
	    g[cg].labs.stitle.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 196:
# line 1345 "pars.yacc"
{
	    g[cg].labs.stitle.color = checkon(COLOR, g[cg].labs.stitle.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 197:
# line 1349 "pars.yacc"
{
	    g[cg].labs.stitle.linew = checkon(LINEWIDTH, g[cg].labs.stitle.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 198:
# line 1352 "pars.yacc"
{
	    realloc_plots((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 199:
# line 1355 "pars.yacc"
{
	    g[cg].l.active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 200:
# line 1358 "pars.yacc"
{
	    g[cg].l.loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 201:
# line 1361 "pars.yacc"
{
	    g[cg].l.layout = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 202:
# line 1364 "pars.yacc"
{
	    g[cg].l.vgap = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 203:
# line 1367 "pars.yacc"
{
	    g[cg].l.hgap = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 204:
# line 1370 "pars.yacc"
{
	    g[cg].l.len = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 205:
# line 1373 "pars.yacc"
{
	    g[cg].l.box = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 206:
# line 1376 "pars.yacc"
{
	    g[cg].l.boxfill = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 207:
# line 1379 "pars.yacc"
{
	    g[cg].l.boxfillusing = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 208:
# line 1383 "pars.yacc"
{
	    if (yypvt[-1].pset == COLOR) {
		g[cg].l.boxfillcolor = (int) yypvt[-0].val;
	    } else {
		g[cg].l.boxfillpat = (int) yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 209:
# line 1390 "pars.yacc"
{
	    g[cg].l.boxlcolor = checkon(COLOR, g[cg].l.boxlcolor, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 210:
# line 1393 "pars.yacc"
{
	    g[cg].l.boxlines = checkon(LINESTYLE, g[cg].l.boxlines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 211:
# line 1396 "pars.yacc"
{
	    g[cg].l.boxlinew = checkon(LINEWIDTH, g[cg].l.boxlinew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 212:
# line 1399 "pars.yacc"
{
	    g[cg].l.legx = yypvt[-2].val;
	    g[cg].l.legy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 213:
# line 1403 "pars.yacc"
{
	    g[cg].l.legx = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 214:
# line 1406 "pars.yacc"
{
	    g[cg].l.legy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 215:
# line 1409 "pars.yacc"
{
	    g[cg].l.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 216:
# line 1412 "pars.yacc"
{
	    g[cg].l.font = checkon(FONTP, g[cg].l.font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 217:
# line 1415 "pars.yacc"
{
	    g[cg].l.lines = checkon(LINESTYLE, g[cg].l.lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 218:
# line 1418 "pars.yacc"
{
	    g[cg].l.linew = checkon(LINEWIDTH, g[cg].l.linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 219:
# line 1421 "pars.yacc"
{
	    g[cg].l.color = checkon(COLOR, g[cg].l.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 220:
# line 1424 "pars.yacc"
{
	    set_plotstr_string(&g[cg].l.str[(int) yypvt[-1].val], (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 221:
# line 1428 "pars.yacc"
{
	    g[cg].f.active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 222:
# line 1431 "pars.yacc"
{
	    g[cg].f.type = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 223:
# line 1434 "pars.yacc"
{
	    g[cg].f.lines = checkon(LINESTYLE, g[cg].f.lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 224:
# line 1437 "pars.yacc"
{
	    g[cg].f.linew = checkon(LINEWIDTH, g[cg].f.linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 225:
# line 1440 "pars.yacc"
{
	    g[cg].f.color = checkon(COLOR, g[cg].f.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 226:
# line 1443 "pars.yacc"
{
	    g[cg].f.fillbg = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 227:
# line 1446 "pars.yacc"
{
	    g[cg].f.bgcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 228:
# line 1449 "pars.yacc"
{
	    g[yypvt[-1].pset].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 229:
# line 1452 "pars.yacc"
{
	    g[yypvt[-2].pset].label = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 230:
# line 1455 "pars.yacc"
{
	    g[yypvt[-3].pset].auto_type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 231:
# line 1458 "pars.yacc"
{
	    g[yypvt[-3].pset].auto_type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 232:
# line 1461 "pars.yacc"
{
	    g[yypvt[-2].pset].parmsread = (yypvt[-0].pset == FALSEP);
	} /*NOTREACHED*/ break;
case 233:
# line 1464 "pars.yacc"
{
	    g[yypvt[-2].pset].hidden = (yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 234:
# line 1467 "pars.yacc"
{
	    g[yypvt[-2].pset].type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 235:
# line 1470 "pars.yacc"
{
	    g[yypvt[-2].pset].pointset = (yypvt[-0].pset == ON);
	} /*NOTREACHED*/ break;
case 236:
# line 1474 "pars.yacc"
{
	    g[yypvt[-4].pset].fx = yypvt[-1].pset;
	    g[yypvt[-4].pset].fy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 237:
# line 1479 "pars.yacc"
{
	    g[yypvt[-5].pset].px = yypvt[-2].val;
	    g[yypvt[-5].pset].py = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 238:
# line 1484 "pars.yacc"
{
	    g[yypvt[-5].pset].dsx = yypvt[-2].val;
	    g[yypvt[-5].pset].dsy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 239:
# line 1488 "pars.yacc"
{
	    g[yypvt[-3].pset].pt_type = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 240:
# line 1491 "pars.yacc"
{
	    realloc_graph_plots(yypvt[-3].pset, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 241:
# line 1497 "pars.yacc"
{ g[cg].vp.vscale = yypvt[-0].val; } /*NOTREACHED*/ break;
case 242:
# line 1498 "pars.yacc"
{ g[cg].vp.active = yypvt[-0].pset; } /*NOTREACHED*/ break;
case 243:
# line 1499 "pars.yacc"
{ g[cg].vp.linew = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 244:
# line 1500 "pars.yacc"
{ g[cg].vp.lines = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 245:
# line 1501 "pars.yacc"
{ g[cg].vp.color = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 246:
# line 1502 "pars.yacc"
{ g[cg].vp.loctype = yypvt[-0].pset; } /*NOTREACHED*/ break;
case 247:
# line 1503 "pars.yacc"
{ g[cg].vp.arrowtype = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 248:
# line 1507 "pars.yacc"
{
	    yyval.pset = XY;
	} /*NOTREACHED*/ break;
case 249:
# line 1510 "pars.yacc"
{
	    yyval.pset = XYARC;
	} /*NOTREACHED*/ break;
case 250:
# line 1513 "pars.yacc"
{
	    yyval.pset = XYBOX;
	} /*NOTREACHED*/ break;
case 251:
# line 1516 "pars.yacc"
{
	    yyval.pset = XYBOXPLOT;
	} /*NOTREACHED*/ break;
case 252:
# line 1519 "pars.yacc"
{
	    yyval.pset = XYHILO;
	} /*NOTREACHED*/ break;
case 253:
# line 1522 "pars.yacc"
{
	    yyval.pset = XYRT;
	} /*NOTREACHED*/ break;
case 254:
# line 1525 "pars.yacc"
{
	    yyval.pset = XYSEG;
	} /*NOTREACHED*/ break;
case 255:
# line 1528 "pars.yacc"
{
	    yyval.pset = XYSTRING;
	} /*NOTREACHED*/ break;
case 256:
# line 1531 "pars.yacc"
{
	    yyval.pset = XYDX;
	} /*NOTREACHED*/ break;
case 257:
# line 1534 "pars.yacc"
{
	    yyval.pset = XYDY;
	} /*NOTREACHED*/ break;
case 258:
# line 1537 "pars.yacc"
{
	    yyval.pset = XYDXDX;
	} /*NOTREACHED*/ break;
case 259:
# line 1540 "pars.yacc"
{
	    yyval.pset = XYDYDY;
	} /*NOTREACHED*/ break;
case 260:
# line 1543 "pars.yacc"
{
	    yyval.pset = XYDXDY;
	} /*NOTREACHED*/ break;
case 261:
# line 1546 "pars.yacc"
{
	    yyval.pset = XYX2Y2;
	} /*NOTREACHED*/ break;
case 262:
# line 1549 "pars.yacc"
{
	    yyval.pset = XYXX;
	} /*NOTREACHED*/ break;
case 263:
# line 1552 "pars.yacc"
{
	    yyval.pset = XYYY;
	} /*NOTREACHED*/ break;
case 264:
# line 1555 "pars.yacc"
{
	    yyval.pset = XYZ;
	} /*NOTREACHED*/ break;
case 265:
# line 1558 "pars.yacc"
{
	    yyval.pset = XYZW;
	} /*NOTREACHED*/ break;
case 266:
# line 1561 "pars.yacc"
{
	    yyval.pset = XYUV;
	} /*NOTREACHED*/ break;
case 267:
# line 1564 "pars.yacc"
{
	    yyval.pset = NXY;
	} /*NOTREACHED*/ break;
case 268:
# line 1567 "pars.yacc"
{
	    yyval.pset = BIN;
	} /*NOTREACHED*/ break;
case 269:
# line 1570 "pars.yacc"
{
	    yyval.pset = RAWSPICE;
	} /*NOTREACHED*/ break;
case 270:
# line 1576 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 271:
# line 1579 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 272:
# line 1582 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 273:
# line 1585 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 274:
# line 1588 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 275:
# line 1591 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 276:
# line 1594 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 277:
# line 1597 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 278:
# line 1600 "pars.yacc"
{
	    yyval.pset = XY;		/* not active */
	} /*NOTREACHED*/ break;
case 279:
# line 1603 "pars.yacc"
{
	    yyval.pset = XY;		/* not active */
	} /*NOTREACHED*/ break;
case 280:
# line 1606 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 281:
# line 1609 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 282:
# line 1615 "pars.yacc"
{
            yyval.pset = FREE;
        } /*NOTREACHED*/ break;
case 283:
# line 1618 "pars.yacc"
{
            yyval.pset = LANDSCAPE;
        } /*NOTREACHED*/ break;
case 284:
# line 1621 "pars.yacc"
{
            yyval.pset = PORTRAIT;
        } /*NOTREACHED*/ break;
case 285:
# line 1624 "pars.yacc"
{
            yyval.pset = FIXED;
        } /*NOTREACHED*/ break;
case 293:
# line 1654 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ACTIVE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 294:
# line 1657 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ACTIVE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 295:
# line 1660 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, TYPE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 296:
# line 1663 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, MISSINGP, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 297:
# line 1666 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, PREC, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 298:
# line 1669 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FORMAT, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 299:
# line 1672 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, TYPE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 300:
# line 1675 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, FILL, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 301:
# line 1678 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, CENTER, (yypvt[-0].pset == TRUEP), 0);
	} /*NOTREACHED*/ break;
case 302:
# line 1681 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, SIZE, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 303:
# line 1684 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, CHAR, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 304:
# line 1687 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, SKIP, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 305:
# line 1690 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, COLOR, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 306:
# line 1693 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, LINEWIDTH, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 307:
# line 1696 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, LINESTYLE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 308:
# line 1699 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, yypvt[-1].pset, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 309:
# line 1702 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FILL, TYPE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 310:
# line 1705 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FILL, WITH, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 311:
# line 1708 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FILL, yypvt[-1].pset, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 312:
# line 1711 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SKIP, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 313:
# line 1714 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, LENGTH, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 314:
# line 1717 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, TYPE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 315:
# line 1720 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, LINEWIDTH, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 316:
# line 1723 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, LINESTYLE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 317:
# line 1726 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, RISER, ACTIVE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 318:
# line 1729 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, RISER, LINEWIDTH, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 319:
# line 1732 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, RISER, LINESTYLE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 320:
# line 1735 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, XYZ, yypvt[-2].val, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 321:
# line 1738 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, COMMENT, (char *) yypvt[-0].pset, 0);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 337:
# line 1769 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-0].pset, 0.0);
	} /*NOTREACHED*/ break;
case 338:
# line 1772 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 339:
# line 1775 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 340:
# line 1778 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 341:
# line 1781 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 342:
# line 1784 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-2].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 343:
# line 1787 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 348:
# line 1797 "pars.yacc"
{
	    g[cg].t[naxis].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 351:
# line 1809 "pars.yacc"
{
	    g[cg].t[naxis].t_flag = yypvt[-0].pset;
	    g[cg].t[naxis].t_mflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 352:
# line 1813 "pars.yacc"
{
	    g[cg].t[naxis].t_flag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 353:
# line 1816 "pars.yacc"
{
	    g[cg].t[naxis].t_mflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 354:
# line 1819 "pars.yacc"
{
	    g[cg].t[naxis].tmajor = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 355:
# line 1822 "pars.yacc"
{
	    g[cg].t[naxis].tminor = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 356:
# line 1825 "pars.yacc"
{
	    g[cg].t[naxis].offsx = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 357:
# line 1828 "pars.yacc"
{
	    g[cg].t[naxis].offsy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 358:
# line 1831 "pars.yacc"
{
	    g[cg].t[naxis].alt = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 359:
# line 1834 "pars.yacc"
{
	    g[cg].t[naxis].tmin = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 360:
# line 1837 "pars.yacc"
{
	    g[cg].t[naxis].tmax = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 361:
# line 1840 "pars.yacc"
{
	    g[cg].t[naxis].t_num = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 362:
# line 1843 "pars.yacc"
{
	    g[cg].t[naxis].t_inout = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 363:
# line 1846 "pars.yacc"
{
	    g[cg].t[naxis].t_log = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 364:
# line 1849 "pars.yacc"
{
	    g[cg].t[naxis].t_size = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 365:
# line 1852 "pars.yacc"
{
	    g[cg].t[naxis].t_size = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 366:
# line 1855 "pars.yacc"
{
	    g[cg].t[naxis].t_msize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 367:
# line 1858 "pars.yacc"
{
	    g[cg].t[naxis].t_color = g[cg].t[naxis].t_mcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 368:
# line 1861 "pars.yacc"
{
	    g[cg].t[naxis].t_linew = g[cg].t[naxis].t_mlinew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 369:
# line 1864 "pars.yacc"
{
	    g[cg].t[naxis].t_color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 370:
# line 1867 "pars.yacc"
{
	    g[cg].t[naxis].t_mcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 371:
# line 1870 "pars.yacc"
{
	    g[cg].t[naxis].t_linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 372:
# line 1873 "pars.yacc"
{
	    g[cg].t[naxis].t_mlinew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 373:
# line 1876 "pars.yacc"
{
	    g[cg].t[naxis].t_lines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 374:
# line 1879 "pars.yacc"
{
	    g[cg].t[naxis].t_mlines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 375:
# line 1882 "pars.yacc"
{
	    g[cg].t[naxis].t_gridflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 376:
# line 1885 "pars.yacc"
{
	    g[cg].t[naxis].t_mgridflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 377:
# line 1888 "pars.yacc"
{
	    g[cg].t[naxis].t_op = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 378:
# line 1891 "pars.yacc"
{
	    g[cg].t[naxis].t_type = AUTO;
	} /*NOTREACHED*/ break;
case 379:
# line 1894 "pars.yacc"
{
	    g[cg].t[naxis].t_type = SPEC;
	} /*NOTREACHED*/ break;
case 380:
# line 1897 "pars.yacc"
{
	    g[cg].t[naxis].t_spec = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 381:
# line 1900 "pars.yacc"
{
	    g[cg].t[naxis].t_specloc[(int) yypvt[-2].val] = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 384:
# line 1911 "pars.yacc"
{
	    g[cg].t[naxis].tl_flag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 385:
# line 1914 "pars.yacc"
{
	    g[cg].t[naxis].tl_type = AUTO;
	} /*NOTREACHED*/ break;
case 386:
# line 1917 "pars.yacc"
{
	    g[cg].t[naxis].tl_type = SPEC;
	} /*NOTREACHED*/ break;
case 387:
# line 1920 "pars.yacc"
{
	    g[cg].t[naxis].tl_prec = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 388:
# line 1923 "pars.yacc"
{
	    g[cg].t[naxis].tl_format = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 389:
# line 1926 "pars.yacc"
{
	    g[cg].t[naxis].tl_format = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 390:
# line 1929 "pars.yacc"
{
	    strcpy(g[cg].t[naxis].tl_appstr, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 391:
# line 1933 "pars.yacc"
{
	    strcpy(g[cg].t[naxis].tl_prestr, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 392:
# line 1937 "pars.yacc"
{
	    g[cg].t[naxis].tl_layout = HORIZONTAL;
	} /*NOTREACHED*/ break;
case 393:
# line 1940 "pars.yacc"
{
	    g[cg].t[naxis].tl_layout = VERTICAL;
	} /*NOTREACHED*/ break;
case 394:
# line 1943 "pars.yacc"
{
	    g[cg].t[naxis].tl_layout = SPEC;
	} /*NOTREACHED*/ break;
case 395:
# line 1946 "pars.yacc"
{
	    g[cg].t[naxis].tl_angle = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 396:
# line 1949 "pars.yacc"
{
	    g[cg].t[naxis].tl_just = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 397:
# line 1952 "pars.yacc"
{
	    g[cg].t[naxis].tl_skip = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 398:
# line 1955 "pars.yacc"
{
	    g[cg].t[naxis].tl_staggered = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 399:
# line 1958 "pars.yacc"
{
	    g[cg].t[naxis].tl_op = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 400:
# line 1961 "pars.yacc"
{
	    g[cg].t[naxis].tl_sign = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 401:
# line 1964 "pars.yacc"
{
	    g[cg].t[naxis].tl_start = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 402:
# line 1967 "pars.yacc"
{
	    g[cg].t[naxis].tl_stop = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 403:
# line 1970 "pars.yacc"
{
	    g[cg].t[naxis].tl_starttype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 404:
# line 1973 "pars.yacc"
{
	    g[cg].t[naxis].tl_starttype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 405:
# line 1976 "pars.yacc"
{
	    g[cg].t[naxis].tl_stoptype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 406:
# line 1979 "pars.yacc"
{
	    g[cg].t[naxis].tl_stoptype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 407:
# line 1982 "pars.yacc"
{
	    g[cg].t[naxis].tl_vgap = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 408:
# line 1985 "pars.yacc"
{
	    g[cg].t[naxis].tl_hgap = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 409:
# line 1988 "pars.yacc"
{
	    g[cg].t[naxis].tl_charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 410:
# line 1991 "pars.yacc"
{
	    g[cg].t[naxis].tl_font = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 411:
# line 1994 "pars.yacc"
{
	    g[cg].t[naxis].tl_color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 412:
# line 1997 "pars.yacc"
{
	    g[cg].t[naxis].tl_linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 413:
# line 2000 "pars.yacc"
{
	    set_plotstr_string(&g[cg].t[naxis].t_speclab[(int) yypvt[-2].val], (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 414:
# line 2007 "pars.yacc"
{
	    set_plotstr_string(&g[cg].t[naxis].label, (char *) yypvt[-0].pset);
	    free((char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 415:
# line 2011 "pars.yacc"
{
	    g[cg].t[naxis].label_layout = PERP;
	} /*NOTREACHED*/ break;
case 416:
# line 2014 "pars.yacc"
{
	    g[cg].t[naxis].label_layout = PARA;
	} /*NOTREACHED*/ break;
case 417:
# line 2017 "pars.yacc"
{
	    g[cg].t[naxis].label_place = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 418:
# line 2020 "pars.yacc"
{
	    g[cg].t[naxis].label_place = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 419:
# line 2023 "pars.yacc"
{
	    g[cg].t[naxis].label.x = yypvt[-2].val;
	    g[cg].t[naxis].label.y = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 420:
# line 2027 "pars.yacc"
{
	    g[cg].t[naxis].label.just = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 421:
# line 2030 "pars.yacc"
{
	    g[cg].t[naxis].label.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 422:
# line 2033 "pars.yacc"
{
	    g[cg].t[naxis].label.font = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 423:
# line 2036 "pars.yacc"
{
	    g[cg].t[naxis].label.color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 424:
# line 2039 "pars.yacc"
{
	    g[cg].t[naxis].label.linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 425:
# line 2045 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbar = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 426:
# line 2048 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbarcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 427:
# line 2051 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbarlines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 428:
# line 2054 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbarlinew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 429:
# line 2061 "pars.yacc"
{
	    whichgraph = yypvt[-2].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 430:
# line 2066 "pars.yacc"
{
	    whichgraph = cg;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 431:
# line 2071 "pars.yacc"
{
	    whichgraph = cg;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 432:
# line 2076 "pars.yacc"
{
	    whichgraph = yypvt[-1].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 433:
# line 2081 "pars.yacc"
{
	    whichgraph = yypvt[-1].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 434:
# line 2086 "pars.yacc"
{
	    whichgraph = yypvt[-1].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 435:
# line 2093 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 436:
# line 2096 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 437:
# line 2099 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 438:
# line 2102 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 439:
# line 2105 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 440:
# line 2111 "pars.yacc"
{
	    yyval.pset = ON;
	} /*NOTREACHED*/ break;
case 441:
# line 2114 "pars.yacc"
{
	    yyval.pset = OFF;
	} /*NOTREACHED*/ break;
case 442:
# line 2120 "pars.yacc"
{
	    yyval.pset = COLOR;
	} /*NOTREACHED*/ break;
case 443:
# line 2123 "pars.yacc"
{
	    yyval.pset = PATTERN;
	} /*NOTREACHED*/ break;
case 444:
# line 2129 "pars.yacc"
{
	    yyval.pset = RUNAVG;
	} /*NOTREACHED*/ break;
case 445:
# line 2132 "pars.yacc"
{
	    yyval.pset = RUNSTD;
	} /*NOTREACHED*/ break;
case 446:
# line 2135 "pars.yacc"
{
	    yyval.pset = RUNMED;
	} /*NOTREACHED*/ break;
case 447:
# line 2138 "pars.yacc"
{
	    yyval.pset = RUNMAX;
	} /*NOTREACHED*/ break;
case 448:
# line 2141 "pars.yacc"
{
	    yyval.pset = RUNMIN;
	} /*NOTREACHED*/ break;
case 449:
# line 2147 "pars.yacc"
{
	    yyval.pset = DFT;
	} /*NOTREACHED*/ break;
case 450:
# line 2150 "pars.yacc"
{
	    yyval.pset = FFT;
	} /*NOTREACHED*/ break;
case 451:
# line 2153 "pars.yacc"
{
	    yyval.pset = INVDFT;
	} /*NOTREACHED*/ break;
case 452:
# line 2156 "pars.yacc"
{
	    yyval.pset = INVFFT;
	} /*NOTREACHED*/ break;
case 453:
# line 2162 "pars.yacc"
{
	    yyval.pset = DISK;
	} /*NOTREACHED*/ break;
case 454:
# line 2165 "pars.yacc"
{
	    yyval.pset = PIPE;
	} /*NOTREACHED*/ break;
case 455:
# line 2171 "pars.yacc"
{
	    yyval.pset = PATTERN;
	} /*NOTREACHED*/ break;
case 456:
# line 2174 "pars.yacc"
{
	    yyval.pset = COLOR;
	} /*NOTREACHED*/ break;
case 457:
# line 2177 "pars.yacc"
{
	    yyval.pset = NONE;
	} /*NOTREACHED*/ break;
case 458:
# line 2183 "pars.yacc"
{
	    yyval.pset = TOP;
	} /*NOTREACHED*/ break;
case 459:
# line 2186 "pars.yacc"
{
	    yyval.pset = BOTTOM;
	} /*NOTREACHED*/ break;
case 460:
# line 2189 "pars.yacc"
{
	    yyval.pset = LEFT;
	} /*NOTREACHED*/ break;
case 461:
# line 2192 "pars.yacc"
{
	    yyval.pset = RIGHT;
	} /*NOTREACHED*/ break;
case 462:
# line 2195 "pars.yacc"
{
	    yyval.pset = BOTH;
	} /*NOTREACHED*/ break;
case 463:
# line 2201 "pars.yacc"
{
	    yyval.pset = RIGHT;
	} /*NOTREACHED*/ break;
case 464:
# line 2204 "pars.yacc"
{
	    yyval.pset = LEFT;
	} /*NOTREACHED*/ break;
case 465:
# line 2207 "pars.yacc"
{
	    yyval.pset = CENTER;
	} /*NOTREACHED*/ break;
case 466:
# line 2213 "pars.yacc"
{
	    yyval.pset = MINP;
	} /*NOTREACHED*/ break;
case 467:
# line 2216 "pars.yacc"
{
	    yyval.pset = MAXP;
	} /*NOTREACHED*/ break;
case 468:
# line 2222 "pars.yacc"
{
	    yyval.pset = TRUEP;
	} /*NOTREACHED*/ break;
case 469:
# line 2225 "pars.yacc"
{
	    yyval.pset = FALSEP;
	} /*NOTREACHED*/ break;
case 470:
# line 2231 "pars.yacc"
{
	    yyval.pset = IN;
	} /*NOTREACHED*/ break;
case 471:
# line 2234 "pars.yacc"
{
	    yyval.pset = OUT;
	} /*NOTREACHED*/ break;
case 472:
# line 2237 "pars.yacc"
{
	    yyval.pset = BOTH;
	} /*NOTREACHED*/ break;
case 473:
# line 2243 "pars.yacc"
{
	    yyval.pset = DECIMAL;
	} /*NOTREACHED*/ break;
case 474:
# line 2246 "pars.yacc"
{
	    yyval.pset = EXPONENTIAL;
	} /*NOTREACHED*/ break;
case 475:
# line 2249 "pars.yacc"
{
	    yyval.pset = POWER;
	} /*NOTREACHED*/ break;
case 476:
# line 2252 "pars.yacc"
{
	    yyval.pset = GENERAL;
	} /*NOTREACHED*/ break;
case 477:
# line 2255 "pars.yacc"
{
	    yyval.pset = DDMMYY;
	} /*NOTREACHED*/ break;
case 478:
# line 2258 "pars.yacc"
{
	    yyval.pset = MMDDYY;
	} /*NOTREACHED*/ break;
case 479:
# line 2261 "pars.yacc"
{
	    yyval.pset = MMYY;
	} /*NOTREACHED*/ break;
case 480:
# line 2264 "pars.yacc"
{
	    yyval.pset = MMDD;
	} /*NOTREACHED*/ break;
case 481:
# line 2267 "pars.yacc"
{
	    yyval.pset = MONTHDAY;
	} /*NOTREACHED*/ break;
case 482:
# line 2270 "pars.yacc"
{
	    yyval.pset = DAYMONTH;
	} /*NOTREACHED*/ break;
case 483:
# line 2273 "pars.yacc"
{
	    yyval.pset = MONTHS;
	} /*NOTREACHED*/ break;
case 484:
# line 2276 "pars.yacc"
{
	    yyval.pset = MONTHL;
	} /*NOTREACHED*/ break;
case 485:
# line 2279 "pars.yacc"
{
	    yyval.pset = DAYOFWEEKS;
	} /*NOTREACHED*/ break;
case 486:
# line 2282 "pars.yacc"
{
	    yyval.pset = DAYOFWEEKL;
	} /*NOTREACHED*/ break;
case 487:
# line 2285 "pars.yacc"
{
	    yyval.pset = DAYOFYEAR;
	} /*NOTREACHED*/ break;
case 488:
# line 2288 "pars.yacc"
{
	    yyval.pset = HMS;
	} /*NOTREACHED*/ break;
case 489:
# line 2291 "pars.yacc"
{
	    yyval.pset = MMDDHMS;
	} /*NOTREACHED*/ break;
case 490:
# line 2294 "pars.yacc"
{
	    yyval.pset = MMDDYYHMS;
	} /*NOTREACHED*/ break;
case 491:
# line 2297 "pars.yacc"
{
	    yyval.pset = DEGREESLON;
	} /*NOTREACHED*/ break;
case 492:
# line 2300 "pars.yacc"
{
	    yyval.pset = DEGREESMMLON;
	} /*NOTREACHED*/ break;
case 493:
# line 2303 "pars.yacc"
{
	    yyval.pset = DEGREESMMSSLON;
	} /*NOTREACHED*/ break;
case 494:
# line 2306 "pars.yacc"
{
	    yyval.pset = MMSSLON;
	} /*NOTREACHED*/ break;
case 495:
# line 2309 "pars.yacc"
{
	    yyval.pset = DEGREESLAT;
	} /*NOTREACHED*/ break;
case 496:
# line 2312 "pars.yacc"
{
	    yyval.pset = DEGREESMMLAT;
	} /*NOTREACHED*/ break;
case 497:
# line 2315 "pars.yacc"
{
	    yyval.pset = DEGREESMMSSLAT;
	} /*NOTREACHED*/ break;
case 498:
# line 2318 "pars.yacc"
{
	    yyval.pset = MMSSLAT;
	} /*NOTREACHED*/ break;
case 499:
# line 2324 "pars.yacc"
{
	    yyval.pset = NORMAL;
	} /*NOTREACHED*/ break;
case 500:
# line 2327 "pars.yacc"
{
	    yyval.pset = ABSOLUTE;
	} /*NOTREACHED*/ break;
case 501:
# line 2330 "pars.yacc"
{
	    yyval.pset = NEGATE;
	} /*NOTREACHED*/ break;
case 502:
# line 2336 "pars.yacc"
{
	    yyval.pset = UP;
	} /*NOTREACHED*/ break;
case 503:
# line 2339 "pars.yacc"
{
	    yyval.pset = DOWN;
	} /*NOTREACHED*/ break;
case 504:
# line 2342 "pars.yacc"
{
	    yyval.pset = RIGHT;
	} /*NOTREACHED*/ break;
case 505:
# line 2345 "pars.yacc"
{
	    yyval.pset = LEFT;
	} /*NOTREACHED*/ break;
case 506:
# line 2348 "pars.yacc"
{
	    yyval.pset = IN;
	} /*NOTREACHED*/ break;
case 507:
# line 2351 "pars.yacc"
{
	    yyval.pset = OUT;
	} /*NOTREACHED*/ break;
case 508:
# line 2357 "pars.yacc"
{
	    yyval.pset = WORLD;
	} /*NOTREACHED*/ break;
case 509:
# line 2360 "pars.yacc"
{
	    yyval.pset = VIEW;
	} /*NOTREACHED*/ break;
case 510:
# line 2366 "pars.yacc"
{ yyval.pset = X; } /*NOTREACHED*/ break;
case 511:
# line 2367 "pars.yacc"
{ yyval.pset = Y; } /*NOTREACHED*/ break;
case 512:
# line 2368 "pars.yacc"
{ yyval.pset = X0; } /*NOTREACHED*/ break;
case 513:
# line 2369 "pars.yacc"
{ yyval.pset = Y0; } /*NOTREACHED*/ break;
case 514:
# line 2370 "pars.yacc"
{ yyval.pset = Y1; } /*NOTREACHED*/ break;
case 515:
# line 2371 "pars.yacc"
{ yyval.pset = Y2; } /*NOTREACHED*/ break;
case 516:
# line 2372 "pars.yacc"
{ yyval.pset = Y3; } /*NOTREACHED*/ break;
case 517:
# line 2373 "pars.yacc"
{ yyval.pset = Y4; } /*NOTREACHED*/ break;
case 518:
# line 2374 "pars.yacc"
{ yyval.pset = Y5; } /*NOTREACHED*/ break;
case 519:
# line 2379 "pars.yacc"
{
	    int itmp = (int) yypvt[-3].val - 1;
	    if (itmp >= ls) {
		yyerror("subscript out of range");
		return 1;
	    } else {
		yypvt[-5].ptr[itmp] = yypvt[-0].val;
		result = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 520:
# line 2390 "pars.yacc"
{
	    int itmp = (int) yypvt[-3].val - 1;
	    double *ptr = getvptr(cg, curset, yypvt[-3].val);
	    if (ptr != NULL) {
	        ptr[itmp] = yypvt[-0].val;
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(cg, curset);
	    update_set_status(cg, curset);
	} /*NOTREACHED*/ break;
case 521:
# line 2405 "pars.yacc"
{
	    int itmp = (int) yypvt[-3].val - 1;
	    double *ptr = getvptr(cg, yypvt[-7].pset, yypvt[-5].pset);
	    if (ptr != NULL) {
	        ptr[itmp] = yypvt[-0].val;
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(cg, yypvt[-7].pset);
	    update_set_status(cg, yypvt[-7].pset);
	} /*NOTREACHED*/ break;
case 522:
# line 2420 "pars.yacc"
{
	    set_prop(cg, SET, SETNUM, yypvt[-4].pset, SYMBOL, TYPE, (int) yypvt[-0].val, 0);
	    result = 0;
	} /*NOTREACHED*/ break;
case 523:
# line 2432 "pars.yacc"
{
	    int itmp = (int) yypvt[-3].val - 1;
	    double *ptr = getvptr(yypvt[-9].pset, yypvt[-7].pset, yypvt[-5].pset);
	    if (ptr != NULL) {
	        ptr[itmp] = yypvt[-0].val;
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(yypvt[-9].pset, yypvt[-7].pset);
	    update_set_status(yypvt[-9].pset, yypvt[-7].pset);
	} /*NOTREACHED*/ break;
case 524:
# line 2450 "pars.yacc"
{
	    if (yypvt[-2].pset == X) {
		*xx = yypvt[-0].val;
	    } else {
		*yy = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 525:
# line 2461 "pars.yacc"
{
	    int i;
	    for (i = 0; i < lxy; i++) {
		yypvt[-2].ptr[i] = yypvt[-0].ptr[i];
	    }
	    result = yypvt[-0].ptr[0];
	} /*NOTREACHED*/ break;
case 526:
# line 2469 "pars.yacc"
{
	    int i;
	    double *ptr;
	    if (!isactive_set(cg, curset)) {
		activateset(cg, curset);
		setlength(cg, curset, lxy);
		setcomment(cg, curset, "Created");
	    }
	    ptr = getvptr(cg, curset, yypvt[-2].pset);
	    if (ptr != NULL) {
	        for (i = 0; i < lxy; i++) {
		    ptr[i] = yypvt[-0].ptr[i];
	        }
	        result = yypvt[-0].ptr[0];
	        updatesetminmax(cg, curset);
	        update_set_status(cg, curset);
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 527:
# line 2491 "pars.yacc"
{
	    int i;
	    double *ptr;
	    if (!isactive_set(cg, yypvt[-4].pset)) {
		activateset(cg, yypvt[-4].pset);
		setlength(cg, yypvt[-4].pset, lxy);
		setcomment(cg, yypvt[-4].pset, "Created");
	    }
	    ptr = getvptr(cg, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr != NULL) {
	        for (i = 0; i < lxy; i++) {
		    ptr[i] = yypvt[-0].ptr[i];
	        }
	        result = yypvt[-0].ptr[0];
	        updatesetminmax(cg, yypvt[-4].pset);
	        update_set_status(cg, yypvt[-4].pset);
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 528:
# line 2514 "pars.yacc"
{
	    int i;
	    double *ptr;
	    if (!isactive_set(yypvt[-6].pset, yypvt[-4].pset)) {
		activateset(yypvt[-6].pset, yypvt[-4].pset);
		setlength(yypvt[-6].pset, yypvt[-4].pset, lxy);
		setcomment(yypvt[-6].pset, yypvt[-4].pset, "Created");
	    }
	    ptr = getvptr(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr != NULL) {
	        for (i = 0; i < lxy; i++) {
		    ptr[i] = yypvt[-0].ptr[i];
	        }
	        result = yypvt[-0].ptr[0];
	        updatesetminmax(yypvt[-6].pset, yypvt[-4].pset);
	        update_set_status(yypvt[-6].pset, yypvt[-4].pset);
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 529:
# line 2537 "pars.yacc"
{
	    int i;
	    for (i = 0; i < lxy; i++) {
		yypvt[-2].ptr[i] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 530:
# line 2545 "pars.yacc"
{
	    int i;
	    double *ptr;
	    if (!isactive_set(cg, curset)) {
		activateset(cg, curset);
		setlength(cg, curset, lxy);
		setcomment(cg, curset, "Created");
	    }
	    ptr = getvptr(cg, curset, yypvt[-2].pset);
	    if (ptr != NULL) {
	        for (i = 0; i < lxy; i++) {
		    ptr[i] = yypvt[-0].val;
	        }
	        result = yypvt[-0].val;
	        updatesetminmax(cg, curset);
	        update_set_status(cg, curset);
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 531:
# line 2568 "pars.yacc"
{
	    int i;
	    double *ptr;
	    if (!isactive_set(cg, yypvt[-4].pset)) {
		activateset(cg, yypvt[-4].pset);
		setlength(cg, yypvt[-4].pset, lxy);
		setcomment(cg, yypvt[-4].pset, "Created");
	    }
	    ptr = getvptr(cg, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr != NULL) {
	        for (i = 0; i < lxy; i++) {
		    ptr[i] = yypvt[-0].val;
	        }
	        result = yypvt[-0].val;
	        updatesetminmax(cg, yypvt[-4].pset);
	        update_set_status(cg, yypvt[-4].pset);
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 532:
# line 2591 "pars.yacc"
{
	    int i;
	    double *ptr;
	    if (!isactive_set(yypvt[-6].pset, yypvt[-4].pset)) {
		activateset(yypvt[-6].pset, yypvt[-4].pset);
		setlength(yypvt[-6].pset, yypvt[-4].pset, lxy);
		setcomment(yypvt[-6].pset, yypvt[-4].pset, "Created");
	    }
	    ptr = getvptr(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr != NULL) {
	        for (i = 0; i < lxy; i++) {
		    ptr[i] = yypvt[-0].val;
	        }
	        result = yypvt[-0].val;
	        updatesetminmax(yypvt[-6].pset, yypvt[-4].pset);
	        update_set_status(yypvt[-6].pset, yypvt[-4].pset);
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 533:
# line 2617 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 534:
# line 2626 "pars.yacc"
{
	    int i;
	    double *ptr = getvptr(cg, curset, yypvt[-0].pset);
	    if (ptr == NULL) {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 535:
# line 2640 "pars.yacc"
{
	    int i;
	    double *ptr = getvptr(cg, yypvt[-2].pset, yypvt[-0].pset);
	    if (ptr == NULL) {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 536:
# line 2654 "pars.yacc"
{
	    int i;
	    double *ptr = getvptr(yypvt[-4].pset, yypvt[-2].pset, yypvt[-0].pset);
	    if (ptr == NULL) {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 537:
# line 2668 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 538:
# line 2677 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val + yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 539:
# line 2686 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] + yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 540:
# line 2695 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val + yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 541:
# line 2704 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] + yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 542:
# line 2713 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val - yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 543:
# line 2722 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] - yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 544:
# line 2731 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val - yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 545:
# line 2740 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] - yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 546:
# line 2749 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val * yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 547:
# line 2758 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] * yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 548:
# line 2767 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val * yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 549:
# line 2776 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] * yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 550:
# line 2785 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    if (yypvt[-0].val == 0.0) {
		yyerror("Divide by Zero");
		return 1;
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val / yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 551:
# line 2798 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		if (yypvt[-0].ptr[i] == 0.0) {
		    yyerror("Divide by Zero");
		    return 1;
		}
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] / yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 552:
# line 2813 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		if (yypvt[-0].ptr[i] == 0.0) {
		    yyerror("Divide by Zero");
		    return 1;
		}
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val / yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 553:
# line 2828 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    if (yypvt[-0].val == 0.0) {
		yyerror("Divide by Zero");
		return 1;
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] / yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 554:
# line 2841 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].val, yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 555:
# line 2850 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].val, yypvt[-0].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 556:
# line 2859 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].ptr[i], yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 557:
# line 2868 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].ptr[i], yypvt[-0].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 558:
# line 2877 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fabs(yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 559:
# line 2886 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fabs(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 560:
# line 2895 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = acos(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 561:
# line 2904 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = asin(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 562:
# line 2913 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = atan(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 563:
# line 2922 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = atan2(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 564:
# line 2931 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = ceil(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 565:
# line 2940 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = cos(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 566:
# line 2949 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] *= M_PI / 180.0;
	    }
	} /*NOTREACHED*/ break;
case 567:
# line 2958 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = erf(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 568:
# line 2967 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = erfc(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 569:
# line 2976 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = exp(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 570:
# line 2985 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = floor(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 571:
# line 2994 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = my_hypot(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 572:
# line 3003 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = my_hypot(yypvt[-3].val, yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 573:
# line 3012 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = my_hypot(yypvt[-3].ptr[i], yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 574:
# line 3021 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = my_hypot(yypvt[-3].val, yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 575:
# line 3030 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = i + 1;
	    }
	} /*NOTREACHED*/ break;
case 576:
# line 3039 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].func;
	    }
	} /*NOTREACHED*/ break;
case 577:
# line 3048 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = (int) yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 578:
# line 3057 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = invnorm(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 579:
# line 3066 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = invt(yypvt[-3].val, (int) yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 580:
# line 3075 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = invt(yypvt[-3].ptr[i], (int) yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 581:
# line 3084 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = lrand48() % (long) (yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 582:
# line 3093 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = lgamma(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 583:
# line 3102 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = log(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 584:
# line 3111 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = log10(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 585:
# line 3120 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = 1.0 / (1.0 + exp(-(yypvt[-5].ptr[i] - yypvt[-3].val)/ yypvt[-1].val));
	    }
	} /*NOTREACHED*/ break;
case 586:
# line 3129 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-3].ptr[i] >= yypvt[-1].ptr[i] ? yypvt[-3].ptr[i] : yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 587:
# line 3138 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-3].ptr[i] <= yypvt[-1].ptr[i] ? yypvt[-3].ptr[i] : yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 588:
# line 3147 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fmod(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 589:
# line 3156 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fx(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 590:
# line 3165 "pars.yacc"
{
	    int i;
	    double tmp;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = normp(yypvt[-1].ptr[i], &tmp);
	    }
	} /*NOTREACHED*/ break;
case 591:
# line 3175 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = M_PI;
	    }
	} /*NOTREACHED*/ break;
case 592:
# line 3184 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = M_PI / 180.0;
	    }
	} /*NOTREACHED*/ break;
case 593:
# line 3193 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = (double) drand48();
	    }
	} /*NOTREACHED*/ break;
case 594:
# line 3202 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 595:
# line 3211 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].val, yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 596:
# line 3220 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].ptr[i], yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 597:
# line 3229 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].val, yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 598:
# line 3238 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = sin(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 599:
# line 3247 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-1].ptr[i] * yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 600:
# line 3256 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = sqrt(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 601:
# line 3265 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = tan(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 602:
# line 3273 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
	        if ((int) yypvt[-4].ptr[i]) {
		    yyval.ptr[i] = yypvt[-2].ptr[i];
	        } else {
		    yyval.ptr[i] = yypvt[-0].ptr[i];
	        }
	    }
	} /*NOTREACHED*/ break;
case 603:
# line 3286 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] > yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 604:
# line 3295 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] < yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 605:
# line 3304 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] <= yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 606:
# line 3313 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] >= yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 607:
# line 3322 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] == yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 608:
# line 3331 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] != yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 609:
# line 3340 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] && yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 610:
# line 3349 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] || yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 611:
# line 3358 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = !(yypvt[-0].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 612:
# line 3367 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 613:
# line 3375 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = -yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 615:
# line 3386 "pars.yacc"
{
	    yyval.val = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 616:
# line 3389 "pars.yacc"
{
	    yyval.val = yypvt[-3].ptr[(int) yypvt[-1].val];
	} /*NOTREACHED*/ break;
case 617:
# line 3392 "pars.yacc"
{
	    yyval.val = (yypvt[-0].pset == X) ? *xx : *yy;
	} /*NOTREACHED*/ break;
case 618:
# line 3395 "pars.yacc"
{
	    double *ptr = getvptr(cg, curset, yypvt[-3].pset);
	    if (ptr != NULL) {
		yyval.val = ptr[(int) yypvt[-1].val - 1];
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 619:
# line 3405 "pars.yacc"
{
	    double *ptr = getvptr(cg, yypvt[-5].pset, yypvt[-3].pset);
	    if (ptr != NULL) {
		yyval.val = ptr[(int) yypvt[-1].val - 1];
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 620:
# line 3415 "pars.yacc"
{
	    double *ptr = getvptr(yypvt[-7].pset, yypvt[-5].pset, yypvt[-3].pset);
	    if (ptr != NULL) {
		yyval.val = ptr[(int) yypvt[-1].val - 1];
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 621:
# line 3425 "pars.yacc"
{
	    double *ptr = getvptr(cg, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr == NULL) {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    switch (yypvt[-0].pset) {
	    case MINP:
		yyval.val = vmin(ptr, g[cg].p[yypvt[-4].pset].len);
		break;
	    case MAXP:
		yyval.val = vmax(ptr, g[cg].p[yypvt[-4].pset].len);
		break;
	    }
	} /*NOTREACHED*/ break;
case 622:
# line 3440 "pars.yacc"
{
	    double *ptr = getvptr(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr == NULL) {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	    switch (yypvt[-0].pset) {
	    case MINP:
		yyval.val = vmin(ptr, g[yypvt[-6].pset].p[yypvt[-4].pset].len);
		break;
	    case MAXP:
		yyval.val = vmax(ptr, g[yypvt[-6].pset].p[yypvt[-4].pset].len);
		break;
	    }
	} /*NOTREACHED*/ break;
case 623:
# line 3455 "pars.yacc"
{
	    yyval.val = g[cg].p[yypvt[-2].pset].len;
	} /*NOTREACHED*/ break;
case 624:
# line 3459 "pars.yacc"
{
	    double bar, sd;
	    double *ptr = getvptr(cg, yypvt[-4].pset, yypvt[-2].pset);
	    if (ptr != NULL) {
		stasum(ptr, getsetlength(cg, yypvt[-4].pset), &bar, &sd, 0);
	        yyval.val = bar;
	    }
	    else {
		yyerror("NULL variable, check set type");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 625:
# line 3471 "pars.yacc"
{
	    yyval.val = yypvt[-2].val + yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 626:
# line 3474 "pars.yacc"
{
	    yyval.val = yypvt[-2].val - yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 627:
# line 3477 "pars.yacc"
{
	    yyval.val = yypvt[-2].val * yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 628:
# line 3481 "pars.yacc"
{
	    if (yypvt[-0].val != 0.0) {
		yyval.val = yypvt[-2].val / yypvt[-0].val;
	    } else {
		yyerror("Divide by Zero");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 629:
# line 3489 "pars.yacc"
{
	    yyval.val = fmod(yypvt[-2].val, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 630:
# line 3492 "pars.yacc"
{
	    yyval.val = pow(yypvt[-2].val, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 631:
# line 3495 "pars.yacc"
{
	    yyval.val = fabs(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 632:
# line 3498 "pars.yacc"
{
	    yyval.val = acos(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 633:
# line 3501 "pars.yacc"
{
	    yyval.val = asin(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 634:
# line 3504 "pars.yacc"
{
	    yyval.val = atan(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 635:
# line 3507 "pars.yacc"
{
	    yyval.val = atan2(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 636:
# line 3510 "pars.yacc"
{
	    yyval.val = ceil(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 637:
# line 3513 "pars.yacc"
{
	    yyval.val = cos(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 638:
# line 3516 "pars.yacc"
{
	    yyval.val = 180.0 / M_PI;
	} /*NOTREACHED*/ break;
case 639:
# line 3519 "pars.yacc"
{
	    yyval.val = erf(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 640:
# line 3522 "pars.yacc"
{
	    yyval.val = erfc(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 641:
# line 3525 "pars.yacc"
{
	    yyval.val = exp(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 642:
# line 3528 "pars.yacc"
{
	    yyval.val = floor(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 643:
# line 3531 "pars.yacc"
{
	    yyval.val = my_hypot(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 644:
# line 3534 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.xv1;
	} /*NOTREACHED*/ break;
case 645:
# line 3537 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.xv2;
	} /*NOTREACHED*/ break;
case 646:
# line 3540 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.yv1;
	} /*NOTREACHED*/ break;
case 647:
# line 3543 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.yv2;
	} /*NOTREACHED*/ break;
case 648:
# line 3546 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.xg1;
	} /*NOTREACHED*/ break;
case 649:
# line 3549 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.xg2;
	} /*NOTREACHED*/ break;
case 650:
# line 3552 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.yg1;
	} /*NOTREACHED*/ break;
case 651:
# line 3555 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.yg2;
	} /*NOTREACHED*/ break;
case 652:
# line 3558 "pars.yacc"
{
	    yyval.val = g[cg].v.xv1;
	} /*NOTREACHED*/ break;
case 653:
# line 3561 "pars.yacc"
{
	    yyval.val = g[cg].v.xv2;
	} /*NOTREACHED*/ break;
case 654:
# line 3564 "pars.yacc"
{
	    yyval.val = g[cg].v.yv1;
	} /*NOTREACHED*/ break;
case 655:
# line 3567 "pars.yacc"
{
	    yyval.val = g[cg].v.yv2;
	} /*NOTREACHED*/ break;
case 656:
# line 3570 "pars.yacc"
{
	    yyval.val = g[cg].w.xg1;
	} /*NOTREACHED*/ break;
case 657:
# line 3573 "pars.yacc"
{
	    yyval.val = g[cg].w.xg2;
	} /*NOTREACHED*/ break;
case 658:
# line 3576 "pars.yacc"
{
	    yyval.val = g[cg].w.yg1;
	} /*NOTREACHED*/ break;
case 659:
# line 3579 "pars.yacc"
{
	    yyval.val = g[cg].w.yg2;
	} /*NOTREACHED*/ break;
case 660:
# line 3582 "pars.yacc"
{
	    yyval.val = g[cg].w.xg2 - g[cg].w.xg1;
	} /*NOTREACHED*/ break;
case 661:
# line 3585 "pars.yacc"
{
	    yyval.val = g[cg].w.yg2 - g[cg].w.yg1;
	} /*NOTREACHED*/ break;
case 662:
# line 3588 "pars.yacc"
{
	    yyval.val = setindex;
	} /*NOTREACHED*/ break;
case 663:
# line 3591 "pars.yacc"
{
	    yyval.val = setsetno;
	} /*NOTREACHED*/ break;
case 664:
# line 3594 "pars.yacc"
{
	    yyval.val = (long) yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 665:
# line 3597 "pars.yacc"
{
	    yyval.val = invnorm(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 666:
# line 3600 "pars.yacc"
{
	    yyval.val = invt(yypvt[-3].val, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 667:
# line 3603 "pars.yacc"
{
	    yyval.val = lrand48() % (long) (yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 668:
# line 3606 "pars.yacc"
{
	    yyval.val = lgamma(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 669:
# line 3609 "pars.yacc"
{
	    yyval.val = log(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 670:
# line 3612 "pars.yacc"
{
	    yyval.val = log10(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 671:
# line 3616 "pars.yacc"
{
	    yyval.val = 1.0 / (1.0 + exp(-(yypvt[-5].val - yypvt[-3].val)/ yypvt[-1].val));
	} /*NOTREACHED*/ break;
case 672:
# line 3619 "pars.yacc"
{
	    yyval.val = yypvt[-3].val >= yypvt[-1].val ? yypvt[-3].val : yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 673:
# line 3622 "pars.yacc"
{
	    yyval.val = yypvt[-3].val <= yypvt[-1].val ? yypvt[-3].val : yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 674:
# line 3625 "pars.yacc"
{
	    yyval.val = fmod(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 675:
# line 3628 "pars.yacc"
{
	    yyval.val = fx(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 676:
# line 3631 "pars.yacc"
{
	    double tmp;
	    yyval.val = normp(yypvt[-1].val, &tmp);
	} /*NOTREACHED*/ break;
case 677:
# line 3635 "pars.yacc"
{
	    yyval.val = M_PI;
	} /*NOTREACHED*/ break;
case 678:
# line 3638 "pars.yacc"
{
	    yyval.val = M_PI / 180.0;
	} /*NOTREACHED*/ break;
case 679:
# line 3641 "pars.yacc"
{
	    yyval.val = (double) drand48();
	} /*NOTREACHED*/ break;
case 680:
# line 3644 "pars.yacc"
{
	    yyval.val = rnorm(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 681:
# line 3647 "pars.yacc"
{
	    yyval.val = sin(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 682:
# line 3650 "pars.yacc"
{
	    yyval.val = pow(yypvt[-1].val, 2.0);
	} /*NOTREACHED*/ break;
case 683:
# line 3653 "pars.yacc"
{
	    yyval.val = sqrt(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 684:
# line 3656 "pars.yacc"
{
	    yyval.val = tan(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 685:
# line 3659 "pars.yacc"
{
	    if ((int) yypvt[-4].val) {
		yyval.val = yypvt[-2].val;
	    } else {
		yyval.val = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 686:
# line 3666 "pars.yacc"
{
	    yyval.val = yypvt[-2].val > yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 687:
# line 3669 "pars.yacc"
{
	    yyval.val = yypvt[-2].val < yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 688:
# line 3672 "pars.yacc"
{
	    yyval.val = yypvt[-2].val <= yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 689:
# line 3675 "pars.yacc"
{
	    yyval.val = yypvt[-2].val >= yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 690:
# line 3678 "pars.yacc"
{
	    yyval.val = yypvt[-2].val == yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 691:
# line 3681 "pars.yacc"
{
	    yyval.val = yypvt[-2].val != yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 692:
# line 3684 "pars.yacc"
{
	    yyval.val = yypvt[-2].val && yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 693:
# line 3687 "pars.yacc"
{
	    yyval.val = yypvt[-2].val || yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 694:
# line 3690 "pars.yacc"
{
	    yyval.val = !(yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 695:
# line 3693 "pars.yacc"
{
	    yyval.val = yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 696:
# line 3696 "pars.yacc"
{
	    yyval.val = -yypvt[-0].val;
	} /*NOTREACHED*/ break;
}


        goto yystack;           /* reset registers in driver code */
}
